from kubernetes_asyncio.client.models import V1ForNode
from kubernetes_asyncio.client.models import V1ForZone
from typing import Any

class V1EndpointHints:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, for_nodes: list[V1ForNode] | None = None, for_zones: list[V1ForZone] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def for_nodes(self) -> list[V1ForNode]: ...
    @for_nodes.setter
    def for_nodes(self, for_nodes: list[V1ForNode]) -> None: ...
    @property
    def for_zones(self) -> list[V1ForZone]: ...
    @for_zones.setter
    def for_zones(self, for_zones: list[V1ForZone]) -> None: ...
