from typing import Any

class V1CustomResourceSubresourceScale:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, label_selector_path: str | None = None, spec_replicas_path: str | None = None, status_replicas_path: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def label_selector_path(self) -> str: ...
    @label_selector_path.setter
    def label_selector_path(self, label_selector_path: str) -> None: ...
    @property
    def spec_replicas_path(self) -> str: ...
    @spec_replicas_path.setter
    def spec_replicas_path(self, spec_replicas_path: str) -> None: ...
    @property
    def status_replicas_path(self) -> str: ...
    @status_replicas_path.setter
    def status_replicas_path(self, status_replicas_path: str) -> None: ...
