from kubernetes_asyncio.client.models import V1NonResourceRule
from kubernetes_asyncio.client.models import V1ResourceRule
from typing import Any

class V1SubjectRulesReviewStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, evaluation_error: str | None = None, incomplete: bool | None = None, non_resource_rules: list[V1NonResourceRule] | None = None, resource_rules: list[V1ResourceRule] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def evaluation_error(self) -> str: ...
    @evaluation_error.setter
    def evaluation_error(self, evaluation_error: str) -> None: ...
    @property
    def incomplete(self) -> bool: ...
    @incomplete.setter
    def incomplete(self, incomplete: bool) -> None: ...
    @property
    def non_resource_rules(self) -> list[V1NonResourceRule]: ...
    @non_resource_rules.setter
    def non_resource_rules(self, non_resource_rules: list[V1NonResourceRule]) -> None: ...
    @property
    def resource_rules(self) -> list[V1ResourceRule]: ...
    @resource_rules.setter
    def resource_rules(self, resource_rules: list[V1ResourceRule]) -> None: ...
