from kubernetes_asyncio.client.models import V1PodDNSConfigOption
from typing import Any

class V1PodDNSConfig:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, nameservers: list[str] | None = None, options: list[V1PodDNSConfigOption] | None = None, searches: list[str] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def nameservers(self) -> list[str]: ...
    @nameservers.setter
    def nameservers(self, nameservers: list[str]) -> None: ...
    @property
    def options(self) -> list[V1PodDNSConfigOption]: ...
    @options.setter
    def options(self, options: list[V1PodDNSConfigOption]) -> None: ...
    @property
    def searches(self) -> list[str]: ...
    @searches.setter
    def searches(self, searches: list[str]) -> None: ...
