from typing import Any

class V1UserInfo:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, extra: dict[str, list[str]] | None = None, groups: list[str] | None = None, uid: str | None = None, username: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def extra(self) -> dict[str, list[str]]: ...
    @extra.setter
    def extra(self, extra: dict[str, list[str]]) -> None: ...
    @property
    def groups(self) -> list[str]: ...
    @groups.setter
    def groups(self, groups: list[str]) -> None: ...
    @property
    def uid(self) -> str: ...
    @uid.setter
    def uid(self, uid: str) -> None: ...
    @property
    def username(self) -> str: ...
    @username.setter
    def username(self, username: str) -> None: ...
