from kubernetes_asyncio.client.models import V1ContainerRestartRuleOnExitCodes
from typing import Any

class V1ContainerRestartRule:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, action: str | None = None, exit_codes: V1ContainerRestartRuleOnExitCodes | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def action(self) -> str: ...
    @action.setter
    def action(self, action: str) -> None: ...
    @property
    def exit_codes(self) -> V1ContainerRestartRuleOnExitCodes: ...
    @exit_codes.setter
    def exit_codes(self, exit_codes: V1ContainerRestartRuleOnExitCodes) -> None: ...
