from kubernetes_asyncio.client.models import V1ExecAction
from kubernetes_asyncio.client.models import V1HTTPGetAction
from kubernetes_asyncio.client.models import V1SleepAction
from kubernetes_asyncio.client.models import V1TCPSocketAction
from typing import Any

class V1LifecycleHandler:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, _exec: V1ExecAction | None = None, http_get: V1HTTPGetAction | None = None, sleep: V1SleepAction | None = None, tcp_socket: V1TCPSocketAction | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def _exec(self) -> V1ExecAction: ...
    @_exec.setter
    def _exec(self, _exec: V1ExecAction) -> None: ...
    @property
    def http_get(self) -> V1HTTPGetAction: ...
    @http_get.setter
    def http_get(self, http_get: V1HTTPGetAction) -> None: ...
    @property
    def sleep(self) -> V1SleepAction: ...
    @sleep.setter
    def sleep(self, sleep: V1SleepAction) -> None: ...
    @property
    def tcp_socket(self) -> V1TCPSocketAction: ...
    @tcp_socket.setter
    def tcp_socket(self, tcp_socket: V1TCPSocketAction) -> None: ...
