from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import V1APIResourceList
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class CustomObjectsApi:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def create_cluster_custom_object(self, group: str, version: str, plural: str, body: Any, **kwargs: Any) -> Awaitable[Any]: ...
    def create_cluster_custom_object_with_http_info(self, group: str, version: str, plural: str, body: Any, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def create_namespaced_custom_object(self, group: str, version: str, namespace: str, plural: str, body: Any, **kwargs: Any) -> Awaitable[Any]: ...
    def create_namespaced_custom_object_with_http_info(self, group: str, version: str, namespace: str, plural: str, body: Any, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def delete_cluster_custom_object(self, group: str, version: str, plural: str, name: str, **kwargs: Any) -> Awaitable[Any]: ...
    def delete_cluster_custom_object_with_http_info(self, group: str, version: str, plural: str, name: str, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def delete_collection_cluster_custom_object(self, group: str, version: str, plural: str, **kwargs: Any) -> Awaitable[Any]: ...
    def delete_collection_cluster_custom_object_with_http_info(self, group: str, version: str, plural: str, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_custom_object(self, group: str, version: str, namespace: str, plural: str, **kwargs: Any) -> Awaitable[Any]: ...
    def delete_collection_namespaced_custom_object_with_http_info(self, group: str, version: str, namespace: str, plural: str, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def delete_namespaced_custom_object(self, group: str, version: str, namespace: str, plural: str, name: str, **kwargs: Any) -> Awaitable[Any]: ...
    def delete_namespaced_custom_object_with_http_info(self, group: str, version: str, namespace: str, plural: str, name: str, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, group: str, version: str, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, group: str, version: str, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
    def get_cluster_custom_object(self, group: str, version: str, plural: str, name: str, **kwargs: Any) -> Awaitable[Any]: ...
    def get_cluster_custom_object_scale(self, group: str, version: str, plural: str, name: str, **kwargs: Any) -> Awaitable[Any]: ...
    def get_cluster_custom_object_scale_with_http_info(self, group: str, version: str, plural: str, name: str, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def get_cluster_custom_object_status(self, group: str, version: str, plural: str, name: str, **kwargs: Any) -> Awaitable[Any]: ...
    def get_cluster_custom_object_status_with_http_info(self, group: str, version: str, plural: str, name: str, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def get_cluster_custom_object_with_http_info(self, group: str, version: str, plural: str, name: str, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def get_namespaced_custom_object(self, group: str, version: str, namespace: str, plural: str, name: str, **kwargs: Any) -> Awaitable[Any]: ...
    def get_namespaced_custom_object_scale(self, group: str, version: str, namespace: str, plural: str, name: str, **kwargs: Any) -> Awaitable[Any]: ...
    def get_namespaced_custom_object_scale_with_http_info(self, group: str, version: str, namespace: str, plural: str, name: str, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def get_namespaced_custom_object_status(self, group: str, version: str, namespace: str, plural: str, name: str, **kwargs: Any) -> Awaitable[Any]: ...
    def get_namespaced_custom_object_status_with_http_info(self, group: str, version: str, namespace: str, plural: str, name: str, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def get_namespaced_custom_object_with_http_info(self, group: str, version: str, namespace: str, plural: str, name: str, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def list_cluster_custom_object(self, group: str, version: str, plural: str, **kwargs: Any) -> Awaitable[Any]: ...
    def list_cluster_custom_object_with_http_info(self, group: str, version: str, plural: str, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def list_custom_object_for_all_namespaces(self, group: str, version: str, resource_plural: str, **kwargs: Any) -> Awaitable[Any]: ...
    def list_custom_object_for_all_namespaces_with_http_info(self, group: str, version: str, resource_plural: str, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def list_namespaced_custom_object(self, group: str, version: str, namespace: str, plural: str, **kwargs: Any) -> Awaitable[Any]: ...
    def list_namespaced_custom_object_with_http_info(self, group: str, version: str, namespace: str, plural: str, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def patch_cluster_custom_object(self, group: str, version: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[Any]: ...
    def patch_cluster_custom_object_scale(self, group: str, version: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[Any]: ...
    def patch_cluster_custom_object_scale_with_http_info(self, group: str, version: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def patch_cluster_custom_object_status(self, group: str, version: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[Any]: ...
    def patch_cluster_custom_object_status_with_http_info(self, group: str, version: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def patch_cluster_custom_object_with_http_info(self, group: str, version: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def patch_namespaced_custom_object(self, group: str, version: str, namespace: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[Any]: ...
    def patch_namespaced_custom_object_scale(self, group: str, version: str, namespace: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[Any]: ...
    def patch_namespaced_custom_object_scale_with_http_info(self, group: str, version: str, namespace: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def patch_namespaced_custom_object_status(self, group: str, version: str, namespace: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[Any]: ...
    def patch_namespaced_custom_object_status_with_http_info(self, group: str, version: str, namespace: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def patch_namespaced_custom_object_with_http_info(self, group: str, version: str, namespace: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def replace_cluster_custom_object(self, group: str, version: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[Any]: ...
    def replace_cluster_custom_object_scale(self, group: str, version: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[Any]: ...
    def replace_cluster_custom_object_scale_with_http_info(self, group: str, version: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def replace_cluster_custom_object_status(self, group: str, version: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[Any]: ...
    def replace_cluster_custom_object_status_with_http_info(self, group: str, version: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def replace_cluster_custom_object_with_http_info(self, group: str, version: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def replace_namespaced_custom_object(self, group: str, version: str, namespace: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[Any]: ...
    def replace_namespaced_custom_object_scale(self, group: str, version: str, namespace: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[Any]: ...
    def replace_namespaced_custom_object_scale_with_http_info(self, group: str, version: str, namespace: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def replace_namespaced_custom_object_status(self, group: str, version: str, namespace: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[Any]: ...
    def replace_namespaced_custom_object_status_with_http_info(self, group: str, version: str, namespace: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
    def replace_namespaced_custom_object_with_http_info(self, group: str, version: str, namespace: str, plural: str, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[Any, int, CIMultiDictProxy]]: ...
