from kubernetes_asyncio.client.models import V1CrossVersionObjectReference
from typing import Any

class V1HorizontalPodAutoscalerSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, max_replicas: int | None = None, min_replicas: int | None = None, scale_target_ref: V1CrossVersionObjectReference | None = None, target_cpu_utilization_percentage: int | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def max_replicas(self) -> int: ...
    @max_replicas.setter
    def max_replicas(self, max_replicas: int) -> None: ...
    @property
    def min_replicas(self) -> int: ...
    @min_replicas.setter
    def min_replicas(self, min_replicas: int) -> None: ...
    @property
    def scale_target_ref(self) -> V1CrossVersionObjectReference: ...
    @scale_target_ref.setter
    def scale_target_ref(self, scale_target_ref: V1CrossVersionObjectReference) -> None: ...
    @property
    def target_cpu_utilization_percentage(self) -> int: ...
    @target_cpu_utilization_percentage.setter
    def target_cpu_utilization_percentage(self, target_cpu_utilization_percentage: int) -> None: ...
