from kubernetes_asyncio.client.models import V1PodAffinityTerm
from kubernetes_asyncio.client.models import V1WeightedPodAffinityTerm
from typing import Any

class V1PodAffinity:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, preferred_during_scheduling_ignored_during_execution: list[V1WeightedPodAffinityTerm] | None = None, required_during_scheduling_ignored_during_execution: list[V1PodAffinityTerm] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def preferred_during_scheduling_ignored_during_execution(self) -> list[V1WeightedPodAffinityTerm]: ...
    @preferred_during_scheduling_ignored_during_execution.setter
    def preferred_during_scheduling_ignored_during_execution(self, preferred_during_scheduling_ignored_during_execution: list[V1WeightedPodAffinityTerm]) -> None: ...
    @property
    def required_during_scheduling_ignored_during_execution(self) -> list[V1PodAffinityTerm]: ...
    @required_during_scheduling_ignored_during_execution.setter
    def required_during_scheduling_ignored_during_execution(self, required_during_scheduling_ignored_during_execution: list[V1PodAffinityTerm]) -> None: ...
