from kubernetes_asyncio.client.models import V1alpha3DeviceSelector
from typing import Any

class V1alpha3DeviceTaintSelector:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, device: str | None = None, device_class_name: str | None = None, driver: str | None = None, pool: str | None = None, selectors: list[V1alpha3DeviceSelector] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def device(self) -> str: ...
    @device.setter
    def device(self, device: str) -> None: ...
    @property
    def device_class_name(self) -> str: ...
    @device_class_name.setter
    def device_class_name(self, device_class_name: str) -> None: ...
    @property
    def driver(self) -> str: ...
    @driver.setter
    def driver(self, driver: str) -> None: ...
    @property
    def pool(self) -> str: ...
    @pool.setter
    def pool(self, pool: str) -> None: ...
    @property
    def selectors(self) -> list[V1alpha3DeviceSelector]: ...
    @selectors.setter
    def selectors(self, selectors: list[V1alpha3DeviceSelector]) -> None: ...
