from typing import Any

class V1AzureFilePersistentVolumeSource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, read_only: bool | None = None, secret_name: str | None = None, secret_namespace: str | None = None, share_name: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def read_only(self) -> bool: ...
    @read_only.setter
    def read_only(self, read_only: bool) -> None: ...
    @property
    def secret_name(self) -> str: ...
    @secret_name.setter
    def secret_name(self, secret_name: str) -> None: ...
    @property
    def secret_namespace(self) -> str: ...
    @secret_namespace.setter
    def secret_namespace(self, secret_namespace: str) -> None: ...
    @property
    def share_name(self) -> str: ...
    @share_name.setter
    def share_name(self, share_name: str) -> None: ...
