from kubernetes_asyncio.client.models import V1CounterSet
from kubernetes_asyncio.client.models import V1Device
from kubernetes_asyncio.client.models import V1NodeSelector
from kubernetes_asyncio.client.models import V1ResourcePool
from typing import Any

class V1ResourceSliceSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, all_nodes: bool | None = None, devices: list[V1Device] | None = None, driver: str | None = None, node_name: str | None = None, node_selector: V1NodeSelector | None = None, per_device_node_selection: bool | None = None, pool: V1ResourcePool | None = None, shared_counters: list[V1CounterSet] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def all_nodes(self) -> bool: ...
    @all_nodes.setter
    def all_nodes(self, all_nodes: bool) -> None: ...
    @property
    def devices(self) -> list[V1Device]: ...
    @devices.setter
    def devices(self, devices: list[V1Device]) -> None: ...
    @property
    def driver(self) -> str: ...
    @driver.setter
    def driver(self, driver: str) -> None: ...
    @property
    def node_name(self) -> str: ...
    @node_name.setter
    def node_name(self, node_name: str) -> None: ...
    @property
    def node_selector(self) -> V1NodeSelector: ...
    @node_selector.setter
    def node_selector(self, node_selector: V1NodeSelector) -> None: ...
    @property
    def per_device_node_selection(self) -> bool: ...
    @per_device_node_selection.setter
    def per_device_node_selection(self, per_device_node_selection: bool) -> None: ...
    @property
    def pool(self) -> V1ResourcePool: ...
    @pool.setter
    def pool(self, pool: V1ResourcePool) -> None: ...
    @property
    def shared_counters(self) -> list[V1CounterSet]: ...
    @shared_counters.setter
    def shared_counters(self, shared_counters: list[V1CounterSet]) -> None: ...
