from kubernetes_asyncio.client.models import V1DaemonSetCondition
from typing import Any

class V1DaemonSetStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, collision_count: int | None = None, conditions: list[V1DaemonSetCondition] | None = None, current_number_scheduled: int | None = None, desired_number_scheduled: int | None = None, number_available: int | None = None, number_misscheduled: int | None = None, number_ready: int | None = None, number_unavailable: int | None = None, observed_generation: int | None = None, updated_number_scheduled: int | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def collision_count(self) -> int: ...
    @collision_count.setter
    def collision_count(self, collision_count: int) -> None: ...
    @property
    def conditions(self) -> list[V1DaemonSetCondition]: ...
    @conditions.setter
    def conditions(self, conditions: list[V1DaemonSetCondition]) -> None: ...
    @property
    def current_number_scheduled(self) -> int: ...
    @current_number_scheduled.setter
    def current_number_scheduled(self, current_number_scheduled: int) -> None: ...
    @property
    def desired_number_scheduled(self) -> int: ...
    @desired_number_scheduled.setter
    def desired_number_scheduled(self, desired_number_scheduled: int) -> None: ...
    @property
    def number_available(self) -> int: ...
    @number_available.setter
    def number_available(self, number_available: int) -> None: ...
    @property
    def number_misscheduled(self) -> int: ...
    @number_misscheduled.setter
    def number_misscheduled(self, number_misscheduled: int) -> None: ...
    @property
    def number_ready(self) -> int: ...
    @number_ready.setter
    def number_ready(self, number_ready: int) -> None: ...
    @property
    def number_unavailable(self) -> int: ...
    @number_unavailable.setter
    def number_unavailable(self, number_unavailable: int) -> None: ...
    @property
    def observed_generation(self) -> int: ...
    @observed_generation.setter
    def observed_generation(self, observed_generation: int) -> None: ...
    @property
    def updated_number_scheduled(self) -> int: ...
    @updated_number_scheduled.setter
    def updated_number_scheduled(self, updated_number_scheduled: int) -> None: ...
