from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1Status
from kubernetes_asyncio.client.models import V1beta1VolumeAttributesClass
from kubernetes_asyncio.client.models import V1beta1VolumeAttributesClassList
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class StorageV1beta1Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def create_volume_attributes_class(self, body: V1beta1VolumeAttributesClass, **kwargs: Any) -> Awaitable[V1beta1VolumeAttributesClass]: ...
    def create_volume_attributes_class_with_http_info(self, body: V1beta1VolumeAttributesClass, **kwargs: Any) -> Awaitable[tuple[V1beta1VolumeAttributesClass, int, CIMultiDictProxy]]: ...
    def delete_collection_volume_attributes_class(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_volume_attributes_class_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_volume_attributes_class(self, name: str, **kwargs: Any) -> Awaitable[V1beta1VolumeAttributesClass]: ...
    def delete_volume_attributes_class_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1beta1VolumeAttributesClass, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
    def list_volume_attributes_class(self, **kwargs: Any) -> Awaitable[V1beta1VolumeAttributesClassList]: ...
    def list_volume_attributes_class_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1beta1VolumeAttributesClassList, int, CIMultiDictProxy]]: ...
    def patch_volume_attributes_class(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1beta1VolumeAttributesClass]: ...
    def patch_volume_attributes_class_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1beta1VolumeAttributesClass, int, CIMultiDictProxy]]: ...
    def read_volume_attributes_class(self, name: str, **kwargs: Any) -> Awaitable[V1beta1VolumeAttributesClass]: ...
    def read_volume_attributes_class_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1beta1VolumeAttributesClass, int, CIMultiDictProxy]]: ...
    def replace_volume_attributes_class(self, name: str, body: V1beta1VolumeAttributesClass, **kwargs: Any) -> Awaitable[V1beta1VolumeAttributesClass]: ...
    def replace_volume_attributes_class_with_http_info(self, name: str, body: V1beta1VolumeAttributesClass, **kwargs: Any) -> Awaitable[tuple[V1beta1VolumeAttributesClass, int, CIMultiDictProxy]]: ...
