from kubernetes_asyncio.client.models import V1StatusCause
from typing import Any

class V1StatusDetails:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, causes: list[V1StatusCause] | None = None, group: str | None = None, kind: str | None = None, name: str | None = None, retry_after_seconds: int | None = None, uid: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def causes(self) -> list[V1StatusCause]: ...
    @causes.setter
    def causes(self, causes: list[V1StatusCause]) -> None: ...
    @property
    def group(self) -> str: ...
    @group.setter
    def group(self, group: str) -> None: ...
    @property
    def kind(self) -> str: ...
    @kind.setter
    def kind(self, kind: str) -> None: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
    @property
    def retry_after_seconds(self) -> int: ...
    @retry_after_seconds.setter
    def retry_after_seconds(self, retry_after_seconds: int) -> None: ...
    @property
    def uid(self) -> str: ...
    @uid.setter
    def uid(self, uid: str) -> None: ...
