from kubernetes_asyncio.client.models import V1BoundObjectReference
from typing import Any

class V1TokenRequestSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, audiences: list[str] | None = None, bound_object_ref: V1BoundObjectReference | None = None, expiration_seconds: int | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def audiences(self) -> list[str]: ...
    @audiences.setter
    def audiences(self, audiences: list[str]) -> None: ...
    @property
    def bound_object_ref(self) -> V1BoundObjectReference: ...
    @bound_object_ref.setter
    def bound_object_ref(self, bound_object_ref: V1BoundObjectReference) -> None: ...
    @property
    def expiration_seconds(self) -> int: ...
    @expiration_seconds.setter
    def expiration_seconds(self, expiration_seconds: int) -> None: ...
