from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1IPAddress
from kubernetes_asyncio.client.models import V1IPAddressList
from kubernetes_asyncio.client.models import V1Ingress
from kubernetes_asyncio.client.models import V1IngressClass
from kubernetes_asyncio.client.models import V1IngressClassList
from kubernetes_asyncio.client.models import V1IngressList
from kubernetes_asyncio.client.models import V1NetworkPolicy
from kubernetes_asyncio.client.models import V1NetworkPolicyList
from kubernetes_asyncio.client.models import V1ServiceCIDR
from kubernetes_asyncio.client.models import V1ServiceCIDRList
from kubernetes_asyncio.client.models import V1Status
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class NetworkingV1Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def create_ingress_class(self, body: V1IngressClass, **kwargs: Any) -> Awaitable[V1IngressClass]: ...
    def create_ingress_class_with_http_info(self, body: V1IngressClass, **kwargs: Any) -> Awaitable[tuple[V1IngressClass, int, CIMultiDictProxy]]: ...
    def create_ip_address(self, body: V1IPAddress, **kwargs: Any) -> Awaitable[V1IPAddress]: ...
    def create_ip_address_with_http_info(self, body: V1IPAddress, **kwargs: Any) -> Awaitable[tuple[V1IPAddress, int, CIMultiDictProxy]]: ...
    def create_namespaced_ingress(self, namespace: str, body: V1Ingress, **kwargs: Any) -> Awaitable[V1Ingress]: ...
    def create_namespaced_ingress_with_http_info(self, namespace: str, body: V1Ingress, **kwargs: Any) -> Awaitable[tuple[V1Ingress, int, CIMultiDictProxy]]: ...
    def create_namespaced_network_policy(self, namespace: str, body: V1NetworkPolicy, **kwargs: Any) -> Awaitable[V1NetworkPolicy]: ...
    def create_namespaced_network_policy_with_http_info(self, namespace: str, body: V1NetworkPolicy, **kwargs: Any) -> Awaitable[tuple[V1NetworkPolicy, int, CIMultiDictProxy]]: ...
    def create_service_cidr(self, body: V1ServiceCIDR, **kwargs: Any) -> Awaitable[V1ServiceCIDR]: ...
    def create_service_cidr_with_http_info(self, body: V1ServiceCIDR, **kwargs: Any) -> Awaitable[tuple[V1ServiceCIDR, int, CIMultiDictProxy]]: ...
    def delete_collection_ingress_class(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_ingress_class_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_ip_address(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_ip_address_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_ingress(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_ingress_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_network_policy(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_network_policy_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_service_cidr(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_service_cidr_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_ingress_class(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_ingress_class_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_ip_address(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_ip_address_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_ingress(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_ingress_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_network_policy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_network_policy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_service_cidr(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_service_cidr_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
    def list_ingress_class(self, **kwargs: Any) -> Awaitable[V1IngressClassList]: ...
    def list_ingress_class_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1IngressClassList, int, CIMultiDictProxy]]: ...
    def list_ingress_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1IngressList]: ...
    def list_ingress_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1IngressList, int, CIMultiDictProxy]]: ...
    def list_ip_address(self, **kwargs: Any) -> Awaitable[V1IPAddressList]: ...
    def list_ip_address_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1IPAddressList, int, CIMultiDictProxy]]: ...
    def list_namespaced_ingress(self, namespace: str, **kwargs: Any) -> Awaitable[V1IngressList]: ...
    def list_namespaced_ingress_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1IngressList, int, CIMultiDictProxy]]: ...
    def list_namespaced_network_policy(self, namespace: str, **kwargs: Any) -> Awaitable[V1NetworkPolicyList]: ...
    def list_namespaced_network_policy_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1NetworkPolicyList, int, CIMultiDictProxy]]: ...
    def list_network_policy_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1NetworkPolicyList]: ...
    def list_network_policy_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1NetworkPolicyList, int, CIMultiDictProxy]]: ...
    def list_service_cidr(self, **kwargs: Any) -> Awaitable[V1ServiceCIDRList]: ...
    def list_service_cidr_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ServiceCIDRList, int, CIMultiDictProxy]]: ...
    def patch_ingress_class(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1IngressClass]: ...
    def patch_ingress_class_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1IngressClass, int, CIMultiDictProxy]]: ...
    def patch_ip_address(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1IPAddress]: ...
    def patch_ip_address_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1IPAddress, int, CIMultiDictProxy]]: ...
    def patch_namespaced_ingress(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Ingress]: ...
    def patch_namespaced_ingress_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Ingress]: ...
    def patch_namespaced_ingress_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Ingress, int, CIMultiDictProxy]]: ...
    def patch_namespaced_ingress_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Ingress, int, CIMultiDictProxy]]: ...
    def patch_namespaced_network_policy(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1NetworkPolicy]: ...
    def patch_namespaced_network_policy_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1NetworkPolicy, int, CIMultiDictProxy]]: ...
    def patch_service_cidr(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1ServiceCIDR]: ...
    def patch_service_cidr_status(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1ServiceCIDR]: ...
    def patch_service_cidr_status_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ServiceCIDR, int, CIMultiDictProxy]]: ...
    def patch_service_cidr_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ServiceCIDR, int, CIMultiDictProxy]]: ...
    def read_ingress_class(self, name: str, **kwargs: Any) -> Awaitable[V1IngressClass]: ...
    def read_ingress_class_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1IngressClass, int, CIMultiDictProxy]]: ...
    def read_ip_address(self, name: str, **kwargs: Any) -> Awaitable[V1IPAddress]: ...
    def read_ip_address_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1IPAddress, int, CIMultiDictProxy]]: ...
    def read_namespaced_ingress(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Ingress]: ...
    def read_namespaced_ingress_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Ingress]: ...
    def read_namespaced_ingress_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Ingress, int, CIMultiDictProxy]]: ...
    def read_namespaced_ingress_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Ingress, int, CIMultiDictProxy]]: ...
    def read_namespaced_network_policy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1NetworkPolicy]: ...
    def read_namespaced_network_policy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1NetworkPolicy, int, CIMultiDictProxy]]: ...
    def read_service_cidr(self, name: str, **kwargs: Any) -> Awaitable[V1ServiceCIDR]: ...
    def read_service_cidr_status(self, name: str, **kwargs: Any) -> Awaitable[V1ServiceCIDR]: ...
    def read_service_cidr_status_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1ServiceCIDR, int, CIMultiDictProxy]]: ...
    def read_service_cidr_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1ServiceCIDR, int, CIMultiDictProxy]]: ...
    def replace_ingress_class(self, name: str, body: V1IngressClass, **kwargs: Any) -> Awaitable[V1IngressClass]: ...
    def replace_ingress_class_with_http_info(self, name: str, body: V1IngressClass, **kwargs: Any) -> Awaitable[tuple[V1IngressClass, int, CIMultiDictProxy]]: ...
    def replace_ip_address(self, name: str, body: V1IPAddress, **kwargs: Any) -> Awaitable[V1IPAddress]: ...
    def replace_ip_address_with_http_info(self, name: str, body: V1IPAddress, **kwargs: Any) -> Awaitable[tuple[V1IPAddress, int, CIMultiDictProxy]]: ...
    def replace_namespaced_ingress(self, name: str, namespace: str, body: V1Ingress, **kwargs: Any) -> Awaitable[V1Ingress]: ...
    def replace_namespaced_ingress_status(self, name: str, namespace: str, body: V1Ingress, **kwargs: Any) -> Awaitable[V1Ingress]: ...
    def replace_namespaced_ingress_status_with_http_info(self, name: str, namespace: str, body: V1Ingress, **kwargs: Any) -> Awaitable[tuple[V1Ingress, int, CIMultiDictProxy]]: ...
    def replace_namespaced_ingress_with_http_info(self, name: str, namespace: str, body: V1Ingress, **kwargs: Any) -> Awaitable[tuple[V1Ingress, int, CIMultiDictProxy]]: ...
    def replace_namespaced_network_policy(self, name: str, namespace: str, body: V1NetworkPolicy, **kwargs: Any) -> Awaitable[V1NetworkPolicy]: ...
    def replace_namespaced_network_policy_with_http_info(self, name: str, namespace: str, body: V1NetworkPolicy, **kwargs: Any) -> Awaitable[tuple[V1NetworkPolicy, int, CIMultiDictProxy]]: ...
    def replace_service_cidr(self, name: str, body: V1ServiceCIDR, **kwargs: Any) -> Awaitable[V1ServiceCIDR]: ...
    def replace_service_cidr_status(self, name: str, body: V1ServiceCIDR, **kwargs: Any) -> Awaitable[V1ServiceCIDR]: ...
    def replace_service_cidr_status_with_http_info(self, name: str, body: V1ServiceCIDR, **kwargs: Any) -> Awaitable[tuple[V1ServiceCIDR, int, CIMultiDictProxy]]: ...
    def replace_service_cidr_with_http_info(self, name: str, body: V1ServiceCIDR, **kwargs: Any) -> Awaitable[tuple[V1ServiceCIDR, int, CIMultiDictProxy]]: ...
