from typing import Any

class V1SleepAction:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, seconds: int | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def seconds(self) -> int: ...
    @seconds.setter
    def seconds(self, seconds: int) -> None: ...
