from kubernetes_asyncio.client.models import V1alpha3CELDeviceSelector
from typing import Any

class V1alpha3DeviceSelector:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, cel: V1alpha3CELDeviceSelector | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def cel(self) -> V1alpha3CELDeviceSelector: ...
    @cel.setter
    def cel(self, cel: V1alpha3CELDeviceSelector) -> None: ...
