from kubernetes_asyncio.client.models import V1WebhookConversion
from typing import Any

class V1CustomResourceConversion:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, strategy: str | None = None, webhook: V1WebhookConversion | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def strategy(self) -> str: ...
    @strategy.setter
    def strategy(self, strategy: str) -> None: ...
    @property
    def webhook(self) -> V1WebhookConversion: ...
    @webhook.setter
    def webhook(self, webhook: V1WebhookConversion) -> None: ...
