from kubernetes_asyncio.client.models import V1beta1AllocatedDeviceStatus
from kubernetes_asyncio.client.models import V1beta1AllocationResult
from kubernetes_asyncio.client.models import V1beta1ResourceClaimConsumerReference
from typing import Any

class V1beta1ResourceClaimStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, allocation: V1beta1AllocationResult | None = None, devices: list[V1beta1AllocatedDeviceStatus] | None = None, reserved_for: list[V1beta1ResourceClaimConsumerReference] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def allocation(self) -> V1beta1AllocationResult: ...
    @allocation.setter
    def allocation(self, allocation: V1beta1AllocationResult) -> None: ...
    @property
    def devices(self) -> list[V1beta1AllocatedDeviceStatus]: ...
    @devices.setter
    def devices(self, devices: list[V1beta1AllocatedDeviceStatus]) -> None: ...
    @property
    def reserved_for(self) -> list[V1beta1ResourceClaimConsumerReference]: ...
    @reserved_for.setter
    def reserved_for(self, reserved_for: list[V1beta1ResourceClaimConsumerReference]) -> None: ...
