from kubernetes_asyncio.client.models import V1FieldSelectorRequirement
from typing import Any

class V1FieldSelectorAttributes:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, raw_selector: str | None = None, requirements: list[V1FieldSelectorRequirement] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def raw_selector(self) -> str: ...
    @raw_selector.setter
    def raw_selector(self, raw_selector: str) -> None: ...
    @property
    def requirements(self) -> list[V1FieldSelectorRequirement]: ...
    @requirements.setter
    def requirements(self, requirements: list[V1FieldSelectorRequirement]) -> None: ...
