from kubernetes_asyncio.client.models import V1LabelSelector
from typing import Any

class V1PodAffinityTerm:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, label_selector: V1LabelSelector | None = None, match_label_keys: list[str] | None = None, mismatch_label_keys: list[str] | None = None, namespace_selector: V1LabelSelector | None = None, namespaces: list[str] | None = None, topology_key: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def label_selector(self) -> V1LabelSelector: ...
    @label_selector.setter
    def label_selector(self, label_selector: V1LabelSelector) -> None: ...
    @property
    def match_label_keys(self) -> list[str]: ...
    @match_label_keys.setter
    def match_label_keys(self, match_label_keys: list[str]) -> None: ...
    @property
    def mismatch_label_keys(self) -> list[str]: ...
    @mismatch_label_keys.setter
    def mismatch_label_keys(self, mismatch_label_keys: list[str]) -> None: ...
    @property
    def namespace_selector(self) -> V1LabelSelector: ...
    @namespace_selector.setter
    def namespace_selector(self, namespace_selector: V1LabelSelector) -> None: ...
    @property
    def namespaces(self) -> list[str]: ...
    @namespaces.setter
    def namespaces(self, namespaces: list[str]) -> None: ...
    @property
    def topology_key(self) -> str: ...
    @topology_key.setter
    def topology_key(self, topology_key: str) -> None: ...
