from typing import Any

class V1NonResourceRule:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, non_resource_urls: list[str] | None = None, verbs: list[str] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def non_resource_urls(self) -> list[str]: ...
    @non_resource_urls.setter
    def non_resource_urls(self, non_resource_urls: list[str]) -> None: ...
    @property
    def verbs(self) -> list[str]: ...
    @verbs.setter
    def verbs(self, verbs: list[str]) -> None: ...
