from datetime import datetime
from typing import Any

class V1ContainerStateTerminated:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, container_id: str | None = None, exit_code: int | None = None, finished_at: datetime | None = None, message: str | None = None, reason: str | None = None, signal: int | None = None, started_at: datetime | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def container_id(self) -> str: ...
    @container_id.setter
    def container_id(self, container_id: str) -> None: ...
    @property
    def exit_code(self) -> int: ...
    @exit_code.setter
    def exit_code(self, exit_code: int) -> None: ...
    @property
    def finished_at(self) -> datetime: ...
    @finished_at.setter
    def finished_at(self, finished_at: datetime) -> None: ...
    @property
    def message(self) -> str: ...
    @message.setter
    def message(self, message: str) -> None: ...
    @property
    def reason(self) -> str: ...
    @reason.setter
    def reason(self, reason: str) -> None: ...
    @property
    def signal(self) -> int: ...
    @signal.setter
    def signal(self, signal: int) -> None: ...
    @property
    def started_at(self) -> datetime: ...
    @started_at.setter
    def started_at(self, started_at: datetime) -> None: ...
