from kubernetes_asyncio.client.models import V1ObjectReference
from typing import Any

class V1EndpointAddress:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, hostname: str | None = None, ip: str | None = None, node_name: str | None = None, target_ref: V1ObjectReference | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def hostname(self) -> str: ...
    @hostname.setter
    def hostname(self, hostname: str) -> None: ...
    @property
    def ip(self) -> str: ...
    @ip.setter
    def ip(self, ip: str) -> None: ...
    @property
    def node_name(self) -> str: ...
    @node_name.setter
    def node_name(self, node_name: str) -> None: ...
    @property
    def target_ref(self) -> V1ObjectReference: ...
    @target_ref.setter
    def target_ref(self, target_ref: V1ObjectReference) -> None: ...
