from kubernetes_asyncio.client.models import V1EndpointConditions
from kubernetes_asyncio.client.models import V1EndpointHints
from kubernetes_asyncio.client.models import V1ObjectReference
from typing import Any

class V1Endpoint:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, addresses: list[str] | None = None, conditions: V1EndpointConditions | None = None, deprecated_topology: dict[str, str] | None = None, hints: V1EndpointHints | None = None, hostname: str | None = None, node_name: str | None = None, target_ref: V1ObjectReference | None = None, zone: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def addresses(self) -> list[str]: ...
    @addresses.setter
    def addresses(self, addresses: list[str]) -> None: ...
    @property
    def conditions(self) -> V1EndpointConditions: ...
    @conditions.setter
    def conditions(self, conditions: V1EndpointConditions) -> None: ...
    @property
    def deprecated_topology(self) -> dict[str, str]: ...
    @deprecated_topology.setter
    def deprecated_topology(self, deprecated_topology: dict[str, str]) -> None: ...
    @property
    def hints(self) -> V1EndpointHints: ...
    @hints.setter
    def hints(self, hints: V1EndpointHints) -> None: ...
    @property
    def hostname(self) -> str: ...
    @hostname.setter
    def hostname(self, hostname: str) -> None: ...
    @property
    def node_name(self) -> str: ...
    @node_name.setter
    def node_name(self, node_name: str) -> None: ...
    @property
    def target_ref(self) -> V1ObjectReference: ...
    @target_ref.setter
    def target_ref(self, target_ref: V1ObjectReference) -> None: ...
    @property
    def zone(self) -> str: ...
    @zone.setter
    def zone(self, zone: str) -> None: ...
