from typing import Any

class V1beta1NetworkDeviceData:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, hardware_address: str | None = None, interface_name: str | None = None, ips: list[str] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def hardware_address(self) -> str: ...
    @hardware_address.setter
    def hardware_address(self, hardware_address: str) -> None: ...
    @property
    def interface_name(self) -> str: ...
    @interface_name.setter
    def interface_name(self, interface_name: str) -> None: ...
    @property
    def ips(self) -> list[str]: ...
    @ips.setter
    def ips(self, ips: list[str]) -> None: ...
