from kubernetes_asyncio.client.models import V1LabelSelector
from typing import Any

class V1PodDisruptionBudgetSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, max_unavailable: Any | None = None, min_available: Any | None = None, selector: V1LabelSelector | None = None, unhealthy_pod_eviction_policy: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def max_unavailable(self) -> Any: ...
    @max_unavailable.setter
    def max_unavailable(self, max_unavailable: Any) -> None: ...
    @property
    def min_available(self) -> Any: ...
    @min_available.setter
    def min_available(self, min_available: Any) -> None: ...
    @property
    def selector(self) -> V1LabelSelector: ...
    @selector.setter
    def selector(self, selector: V1LabelSelector) -> None: ...
    @property
    def unhealthy_pod_eviction_policy(self) -> str: ...
    @unhealthy_pod_eviction_policy.setter
    def unhealthy_pod_eviction_policy(self, unhealthy_pod_eviction_policy: str) -> None: ...
