from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1LocalSubjectAccessReview
from kubernetes_asyncio.client.models import V1SelfSubjectAccessReview
from kubernetes_asyncio.client.models import V1SelfSubjectRulesReview
from kubernetes_asyncio.client.models import V1SubjectAccessReview
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class AuthorizationV1Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def create_namespaced_local_subject_access_review(self, namespace: str, body: V1LocalSubjectAccessReview, **kwargs: Any) -> Awaitable[V1LocalSubjectAccessReview]: ...
    def create_namespaced_local_subject_access_review_with_http_info(self, namespace: str, body: V1LocalSubjectAccessReview, **kwargs: Any) -> Awaitable[tuple[V1LocalSubjectAccessReview, int, CIMultiDictProxy]]: ...
    def create_self_subject_access_review(self, body: V1SelfSubjectAccessReview, **kwargs: Any) -> Awaitable[V1SelfSubjectAccessReview]: ...
    def create_self_subject_access_review_with_http_info(self, body: V1SelfSubjectAccessReview, **kwargs: Any) -> Awaitable[tuple[V1SelfSubjectAccessReview, int, CIMultiDictProxy]]: ...
    def create_self_subject_rules_review(self, body: V1SelfSubjectRulesReview, **kwargs: Any) -> Awaitable[V1SelfSubjectRulesReview]: ...
    def create_self_subject_rules_review_with_http_info(self, body: V1SelfSubjectRulesReview, **kwargs: Any) -> Awaitable[tuple[V1SelfSubjectRulesReview, int, CIMultiDictProxy]]: ...
    def create_subject_access_review(self, body: V1SubjectAccessReview, **kwargs: Any) -> Awaitable[V1SubjectAccessReview]: ...
    def create_subject_access_review_with_http_info(self, body: V1SubjectAccessReview, **kwargs: Any) -> Awaitable[tuple[V1SubjectAccessReview, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
