from datetime import datetime
from kubernetes_asyncio.client.models import V1Condition
from typing import Any

class V1alpha1PodCertificateRequestStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, begin_refresh_at: datetime | None = None, certificate_chain: str | None = None, conditions: list[V1Condition] | None = None, not_after: datetime | None = None, not_before: datetime | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def begin_refresh_at(self) -> datetime: ...
    @begin_refresh_at.setter
    def begin_refresh_at(self, begin_refresh_at: datetime) -> None: ...
    @property
    def certificate_chain(self) -> str: ...
    @certificate_chain.setter
    def certificate_chain(self, certificate_chain: str) -> None: ...
    @property
    def conditions(self) -> list[V1Condition]: ...
    @conditions.setter
    def conditions(self, conditions: list[V1Condition]) -> None: ...
    @property
    def not_after(self) -> datetime: ...
    @not_after.setter
    def not_after(self, not_after: datetime) -> None: ...
    @property
    def not_before(self) -> datetime: ...
    @not_before.setter
    def not_before(self, not_before: datetime) -> None: ...
