from kubernetes_asyncio.client.models import V1DeviceClaimConfiguration
from kubernetes_asyncio.client.models import V1DeviceConstraint
from kubernetes_asyncio.client.models import V1DeviceRequest
from typing import Any

class V1DeviceClaim:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, config: list[V1DeviceClaimConfiguration] | None = None, constraints: list[V1DeviceConstraint] | None = None, requests: list[V1DeviceRequest] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def config(self) -> list[V1DeviceClaimConfiguration]: ...
    @config.setter
    def config(self, config: list[V1DeviceClaimConfiguration]) -> None: ...
    @property
    def constraints(self) -> list[V1DeviceConstraint]: ...
    @constraints.setter
    def constraints(self, constraints: list[V1DeviceConstraint]) -> None: ...
    @property
    def requests(self) -> list[V1DeviceRequest]: ...
    @requests.setter
    def requests(self, requests: list[V1DeviceRequest]) -> None: ...
