from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1MutatingWebhookConfiguration
from kubernetes_asyncio.client.models import V1MutatingWebhookConfigurationList
from kubernetes_asyncio.client.models import V1Status
from kubernetes_asyncio.client.models import V1ValidatingAdmissionPolicy
from kubernetes_asyncio.client.models import V1ValidatingAdmissionPolicyBinding
from kubernetes_asyncio.client.models import V1ValidatingAdmissionPolicyBindingList
from kubernetes_asyncio.client.models import V1ValidatingAdmissionPolicyList
from kubernetes_asyncio.client.models import V1ValidatingWebhookConfiguration
from kubernetes_asyncio.client.models import V1ValidatingWebhookConfigurationList
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class AdmissionregistrationV1Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def create_mutating_webhook_configuration(self, body: V1MutatingWebhookConfiguration, **kwargs: Any) -> Awaitable[V1MutatingWebhookConfiguration]: ...
    def create_mutating_webhook_configuration_with_http_info(self, body: V1MutatingWebhookConfiguration, **kwargs: Any) -> Awaitable[tuple[V1MutatingWebhookConfiguration, int, CIMultiDictProxy]]: ...
    def create_validating_admission_policy(self, body: V1ValidatingAdmissionPolicy, **kwargs: Any) -> Awaitable[V1ValidatingAdmissionPolicy]: ...
    def create_validating_admission_policy_binding(self, body: V1ValidatingAdmissionPolicyBinding, **kwargs: Any) -> Awaitable[V1ValidatingAdmissionPolicyBinding]: ...
    def create_validating_admission_policy_binding_with_http_info(self, body: V1ValidatingAdmissionPolicyBinding, **kwargs: Any) -> Awaitable[tuple[V1ValidatingAdmissionPolicyBinding, int, CIMultiDictProxy]]: ...
    def create_validating_admission_policy_with_http_info(self, body: V1ValidatingAdmissionPolicy, **kwargs: Any) -> Awaitable[tuple[V1ValidatingAdmissionPolicy, int, CIMultiDictProxy]]: ...
    def create_validating_webhook_configuration(self, body: V1ValidatingWebhookConfiguration, **kwargs: Any) -> Awaitable[V1ValidatingWebhookConfiguration]: ...
    def create_validating_webhook_configuration_with_http_info(self, body: V1ValidatingWebhookConfiguration, **kwargs: Any) -> Awaitable[tuple[V1ValidatingWebhookConfiguration, int, CIMultiDictProxy]]: ...
    def delete_collection_mutating_webhook_configuration(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_mutating_webhook_configuration_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_validating_admission_policy(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_validating_admission_policy_binding(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_validating_admission_policy_binding_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_validating_admission_policy_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_validating_webhook_configuration(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_validating_webhook_configuration_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_mutating_webhook_configuration(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_mutating_webhook_configuration_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_validating_admission_policy(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_validating_admission_policy_binding(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_validating_admission_policy_binding_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_validating_admission_policy_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_validating_webhook_configuration(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_validating_webhook_configuration_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
    def list_mutating_webhook_configuration(self, **kwargs: Any) -> Awaitable[V1MutatingWebhookConfigurationList]: ...
    def list_mutating_webhook_configuration_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1MutatingWebhookConfigurationList, int, CIMultiDictProxy]]: ...
    def list_validating_admission_policy(self, **kwargs: Any) -> Awaitable[V1ValidatingAdmissionPolicyList]: ...
    def list_validating_admission_policy_binding(self, **kwargs: Any) -> Awaitable[V1ValidatingAdmissionPolicyBindingList]: ...
    def list_validating_admission_policy_binding_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ValidatingAdmissionPolicyBindingList, int, CIMultiDictProxy]]: ...
    def list_validating_admission_policy_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ValidatingAdmissionPolicyList, int, CIMultiDictProxy]]: ...
    def list_validating_webhook_configuration(self, **kwargs: Any) -> Awaitable[V1ValidatingWebhookConfigurationList]: ...
    def list_validating_webhook_configuration_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ValidatingWebhookConfigurationList, int, CIMultiDictProxy]]: ...
    def patch_mutating_webhook_configuration(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1MutatingWebhookConfiguration]: ...
    def patch_mutating_webhook_configuration_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1MutatingWebhookConfiguration, int, CIMultiDictProxy]]: ...
    def patch_validating_admission_policy(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1ValidatingAdmissionPolicy]: ...
    def patch_validating_admission_policy_binding(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1ValidatingAdmissionPolicyBinding]: ...
    def patch_validating_admission_policy_binding_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ValidatingAdmissionPolicyBinding, int, CIMultiDictProxy]]: ...
    def patch_validating_admission_policy_status(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1ValidatingAdmissionPolicy]: ...
    def patch_validating_admission_policy_status_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ValidatingAdmissionPolicy, int, CIMultiDictProxy]]: ...
    def patch_validating_admission_policy_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ValidatingAdmissionPolicy, int, CIMultiDictProxy]]: ...
    def patch_validating_webhook_configuration(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1ValidatingWebhookConfiguration]: ...
    def patch_validating_webhook_configuration_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ValidatingWebhookConfiguration, int, CIMultiDictProxy]]: ...
    def read_mutating_webhook_configuration(self, name: str, **kwargs: Any) -> Awaitable[V1MutatingWebhookConfiguration]: ...
    def read_mutating_webhook_configuration_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1MutatingWebhookConfiguration, int, CIMultiDictProxy]]: ...
    def read_validating_admission_policy(self, name: str, **kwargs: Any) -> Awaitable[V1ValidatingAdmissionPolicy]: ...
    def read_validating_admission_policy_binding(self, name: str, **kwargs: Any) -> Awaitable[V1ValidatingAdmissionPolicyBinding]: ...
    def read_validating_admission_policy_binding_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1ValidatingAdmissionPolicyBinding, int, CIMultiDictProxy]]: ...
    def read_validating_admission_policy_status(self, name: str, **kwargs: Any) -> Awaitable[V1ValidatingAdmissionPolicy]: ...
    def read_validating_admission_policy_status_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1ValidatingAdmissionPolicy, int, CIMultiDictProxy]]: ...
    def read_validating_admission_policy_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1ValidatingAdmissionPolicy, int, CIMultiDictProxy]]: ...
    def read_validating_webhook_configuration(self, name: str, **kwargs: Any) -> Awaitable[V1ValidatingWebhookConfiguration]: ...
    def read_validating_webhook_configuration_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1ValidatingWebhookConfiguration, int, CIMultiDictProxy]]: ...
    def replace_mutating_webhook_configuration(self, name: str, body: V1MutatingWebhookConfiguration, **kwargs: Any) -> Awaitable[V1MutatingWebhookConfiguration]: ...
    def replace_mutating_webhook_configuration_with_http_info(self, name: str, body: V1MutatingWebhookConfiguration, **kwargs: Any) -> Awaitable[tuple[V1MutatingWebhookConfiguration, int, CIMultiDictProxy]]: ...
    def replace_validating_admission_policy(self, name: str, body: V1ValidatingAdmissionPolicy, **kwargs: Any) -> Awaitable[V1ValidatingAdmissionPolicy]: ...
    def replace_validating_admission_policy_binding(self, name: str, body: V1ValidatingAdmissionPolicyBinding, **kwargs: Any) -> Awaitable[V1ValidatingAdmissionPolicyBinding]: ...
    def replace_validating_admission_policy_binding_with_http_info(self, name: str, body: V1ValidatingAdmissionPolicyBinding, **kwargs: Any) -> Awaitable[tuple[V1ValidatingAdmissionPolicyBinding, int, CIMultiDictProxy]]: ...
    def replace_validating_admission_policy_status(self, name: str, body: V1ValidatingAdmissionPolicy, **kwargs: Any) -> Awaitable[V1ValidatingAdmissionPolicy]: ...
    def replace_validating_admission_policy_status_with_http_info(self, name: str, body: V1ValidatingAdmissionPolicy, **kwargs: Any) -> Awaitable[tuple[V1ValidatingAdmissionPolicy, int, CIMultiDictProxy]]: ...
    def replace_validating_admission_policy_with_http_info(self, name: str, body: V1ValidatingAdmissionPolicy, **kwargs: Any) -> Awaitable[tuple[V1ValidatingAdmissionPolicy, int, CIMultiDictProxy]]: ...
    def replace_validating_webhook_configuration(self, name: str, body: V1ValidatingWebhookConfiguration, **kwargs: Any) -> Awaitable[V1ValidatingWebhookConfiguration]: ...
    def replace_validating_webhook_configuration_with_http_info(self, name: str, body: V1ValidatingWebhookConfiguration, **kwargs: Any) -> Awaitable[tuple[V1ValidatingWebhookConfiguration, int, CIMultiDictProxy]]: ...
