from kubernetes_asyncio.client.models import V1ConfigMapKeySelector
from kubernetes_asyncio.client.models import V1FileKeySelector
from kubernetes_asyncio.client.models import V1ObjectFieldSelector
from kubernetes_asyncio.client.models import V1ResourceFieldSelector
from kubernetes_asyncio.client.models import V1SecretKeySelector
from typing import Any

class V1EnvVarSource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, config_map_key_ref: V1ConfigMapKeySelector | None = None, field_ref: V1ObjectFieldSelector | None = None, file_key_ref: V1FileKeySelector | None = None, resource_field_ref: V1ResourceFieldSelector | None = None, secret_key_ref: V1SecretKeySelector | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def config_map_key_ref(self) -> V1ConfigMapKeySelector: ...
    @config_map_key_ref.setter
    def config_map_key_ref(self, config_map_key_ref: V1ConfigMapKeySelector) -> None: ...
    @property
    def field_ref(self) -> V1ObjectFieldSelector: ...
    @field_ref.setter
    def field_ref(self, field_ref: V1ObjectFieldSelector) -> None: ...
    @property
    def file_key_ref(self) -> V1FileKeySelector: ...
    @file_key_ref.setter
    def file_key_ref(self, file_key_ref: V1FileKeySelector) -> None: ...
    @property
    def resource_field_ref(self) -> V1ResourceFieldSelector: ...
    @resource_field_ref.setter
    def resource_field_ref(self, resource_field_ref: V1ResourceFieldSelector) -> None: ...
    @property
    def secret_key_ref(self) -> V1SecretKeySelector: ...
    @secret_key_ref.setter
    def secret_key_ref(self, secret_key_ref: V1SecretKeySelector) -> None: ...
