from kubernetes_asyncio.client.models import V1Toleration
from typing import Any

class V1Scheduling:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, node_selector: dict[str, str] | None = None, tolerations: list[V1Toleration] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def node_selector(self) -> dict[str, str]: ...
    @node_selector.setter
    def node_selector(self, node_selector: dict[str, str]) -> None: ...
    @property
    def tolerations(self) -> list[V1Toleration]: ...
    @tolerations.setter
    def tolerations(self, tolerations: list[V1Toleration]) -> None: ...
