from typing import Any

class V1EndpointConditions:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, ready: bool | None = None, serving: bool | None = None, terminating: bool | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def ready(self) -> bool: ...
    @ready.setter
    def ready(self, ready: bool) -> None: ...
    @property
    def serving(self) -> bool: ...
    @serving.setter
    def serving(self, serving: bool) -> None: ...
    @property
    def terminating(self) -> bool: ...
    @terminating.setter
    def terminating(self, terminating: bool) -> None: ...
