from typing import Any

class V1alpha1PodCertificateRequestSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, max_expiration_seconds: int | None = None, node_name: str | None = None, node_uid: str | None = None, pkix_public_key: str | None = None, pod_name: str | None = None, pod_uid: str | None = None, proof_of_possession: str | None = None, service_account_name: str | None = None, service_account_uid: str | None = None, signer_name: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def max_expiration_seconds(self) -> int: ...
    @max_expiration_seconds.setter
    def max_expiration_seconds(self, max_expiration_seconds: int) -> None: ...
    @property
    def node_name(self) -> str: ...
    @node_name.setter
    def node_name(self, node_name: str) -> None: ...
    @property
    def node_uid(self) -> str: ...
    @node_uid.setter
    def node_uid(self, node_uid: str) -> None: ...
    @property
    def pkix_public_key(self) -> str: ...
    @pkix_public_key.setter
    def pkix_public_key(self, pkix_public_key: str) -> None: ...
    @property
    def pod_name(self) -> str: ...
    @pod_name.setter
    def pod_name(self, pod_name: str) -> None: ...
    @property
    def pod_uid(self) -> str: ...
    @pod_uid.setter
    def pod_uid(self, pod_uid: str) -> None: ...
    @property
    def proof_of_possession(self) -> str: ...
    @proof_of_possession.setter
    def proof_of_possession(self, proof_of_possession: str) -> None: ...
    @property
    def service_account_name(self) -> str: ...
    @service_account_name.setter
    def service_account_name(self, service_account_name: str) -> None: ...
    @property
    def service_account_uid(self) -> str: ...
    @service_account_uid.setter
    def service_account_uid(self, service_account_uid: str) -> None: ...
    @property
    def signer_name(self) -> str: ...
    @signer_name.setter
    def signer_name(self, signer_name: str) -> None: ...
