from kubernetes_asyncio.client.models import V1ModifyVolumeStatus
from kubernetes_asyncio.client.models import V1PersistentVolumeClaimCondition
from typing import Any

class V1PersistentVolumeClaimStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, access_modes: list[str] | None = None, allocated_resource_statuses: dict[str, str] | None = None, allocated_resources: dict[str, str] | None = None, capacity: dict[str, str] | None = None, conditions: list[V1PersistentVolumeClaimCondition] | None = None, current_volume_attributes_class_name: str | None = None, modify_volume_status: V1ModifyVolumeStatus | None = None, phase: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def access_modes(self) -> list[str]: ...
    @access_modes.setter
    def access_modes(self, access_modes: list[str]) -> None: ...
    @property
    def allocated_resource_statuses(self) -> dict[str, str]: ...
    @allocated_resource_statuses.setter
    def allocated_resource_statuses(self, allocated_resource_statuses: dict[str, str]) -> None: ...
    @property
    def allocated_resources(self) -> dict[str, str]: ...
    @allocated_resources.setter
    def allocated_resources(self, allocated_resources: dict[str, str]) -> None: ...
    @property
    def capacity(self) -> dict[str, str]: ...
    @capacity.setter
    def capacity(self, capacity: dict[str, str]) -> None: ...
    @property
    def conditions(self) -> list[V1PersistentVolumeClaimCondition]: ...
    @conditions.setter
    def conditions(self, conditions: list[V1PersistentVolumeClaimCondition]) -> None: ...
    @property
    def current_volume_attributes_class_name(self) -> str: ...
    @current_volume_attributes_class_name.setter
    def current_volume_attributes_class_name(self, current_volume_attributes_class_name: str) -> None: ...
    @property
    def modify_volume_status(self) -> V1ModifyVolumeStatus: ...
    @modify_volume_status.setter
    def modify_volume_status(self, modify_volume_status: V1ModifyVolumeStatus) -> None: ...
    @property
    def phase(self) -> str: ...
    @phase.setter
    def phase(self, phase: str) -> None: ...
