from typing import Any

class V1CustomResourceDefinitionNames:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, categories: list[str] | None = None, kind: str | None = None, list_kind: str | None = None, plural: str | None = None, short_names: list[str] | None = None, singular: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def categories(self) -> list[str]: ...
    @categories.setter
    def categories(self, categories: list[str]) -> None: ...
    @property
    def kind(self) -> str: ...
    @kind.setter
    def kind(self, kind: str) -> None: ...
    @property
    def list_kind(self) -> str: ...
    @list_kind.setter
    def list_kind(self, list_kind: str) -> None: ...
    @property
    def plural(self) -> str: ...
    @plural.setter
    def plural(self, plural: str) -> None: ...
    @property
    def short_names(self) -> list[str]: ...
    @short_names.setter
    def short_names(self, short_names: list[str]) -> None: ...
    @property
    def singular(self) -> str: ...
    @singular.setter
    def singular(self, singular: str) -> None: ...
