from typing import Any

class V1ContainerPort:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, container_port: int | None = None, host_ip: str | None = None, host_port: int | None = None, name: str | None = None, protocol: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def container_port(self) -> int: ...
    @container_port.setter
    def container_port(self, container_port: int) -> None: ...
    @property
    def host_ip(self) -> str: ...
    @host_ip.setter
    def host_ip(self, host_ip: str) -> None: ...
    @property
    def host_port(self) -> int: ...
    @host_port.setter
    def host_port(self, host_port: int) -> None: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
    @property
    def protocol(self) -> str: ...
    @protocol.setter
    def protocol(self, protocol: str) -> None: ...
