from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1Status
from kubernetes_asyncio.client.models import V1beta1IPAddress
from kubernetes_asyncio.client.models import V1beta1IPAddressList
from kubernetes_asyncio.client.models import V1beta1ServiceCIDR
from kubernetes_asyncio.client.models import V1beta1ServiceCIDRList
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class NetworkingV1beta1Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def create_ip_address(self, body: V1beta1IPAddress, **kwargs: Any) -> Awaitable[V1beta1IPAddress]: ...
    def create_ip_address_with_http_info(self, body: V1beta1IPAddress, **kwargs: Any) -> Awaitable[tuple[V1beta1IPAddress, int, CIMultiDictProxy]]: ...
    def create_service_cidr(self, body: V1beta1ServiceCIDR, **kwargs: Any) -> Awaitable[V1beta1ServiceCIDR]: ...
    def create_service_cidr_with_http_info(self, body: V1beta1ServiceCIDR, **kwargs: Any) -> Awaitable[tuple[V1beta1ServiceCIDR, int, CIMultiDictProxy]]: ...
    def delete_collection_ip_address(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_ip_address_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_service_cidr(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_service_cidr_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_ip_address(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_ip_address_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_service_cidr(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_service_cidr_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
    def list_ip_address(self, **kwargs: Any) -> Awaitable[V1beta1IPAddressList]: ...
    def list_ip_address_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1beta1IPAddressList, int, CIMultiDictProxy]]: ...
    def list_service_cidr(self, **kwargs: Any) -> Awaitable[V1beta1ServiceCIDRList]: ...
    def list_service_cidr_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1beta1ServiceCIDRList, int, CIMultiDictProxy]]: ...
    def patch_ip_address(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1beta1IPAddress]: ...
    def patch_ip_address_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1beta1IPAddress, int, CIMultiDictProxy]]: ...
    def patch_service_cidr(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1beta1ServiceCIDR]: ...
    def patch_service_cidr_status(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1beta1ServiceCIDR]: ...
    def patch_service_cidr_status_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1beta1ServiceCIDR, int, CIMultiDictProxy]]: ...
    def patch_service_cidr_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1beta1ServiceCIDR, int, CIMultiDictProxy]]: ...
    def read_ip_address(self, name: str, **kwargs: Any) -> Awaitable[V1beta1IPAddress]: ...
    def read_ip_address_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1beta1IPAddress, int, CIMultiDictProxy]]: ...
    def read_service_cidr(self, name: str, **kwargs: Any) -> Awaitable[V1beta1ServiceCIDR]: ...
    def read_service_cidr_status(self, name: str, **kwargs: Any) -> Awaitable[V1beta1ServiceCIDR]: ...
    def read_service_cidr_status_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1beta1ServiceCIDR, int, CIMultiDictProxy]]: ...
    def read_service_cidr_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1beta1ServiceCIDR, int, CIMultiDictProxy]]: ...
    def replace_ip_address(self, name: str, body: V1beta1IPAddress, **kwargs: Any) -> Awaitable[V1beta1IPAddress]: ...
    def replace_ip_address_with_http_info(self, name: str, body: V1beta1IPAddress, **kwargs: Any) -> Awaitable[tuple[V1beta1IPAddress, int, CIMultiDictProxy]]: ...
    def replace_service_cidr(self, name: str, body: V1beta1ServiceCIDR, **kwargs: Any) -> Awaitable[V1beta1ServiceCIDR]: ...
    def replace_service_cidr_status(self, name: str, body: V1beta1ServiceCIDR, **kwargs: Any) -> Awaitable[V1beta1ServiceCIDR]: ...
    def replace_service_cidr_status_with_http_info(self, name: str, body: V1beta1ServiceCIDR, **kwargs: Any) -> Awaitable[tuple[V1beta1ServiceCIDR, int, CIMultiDictProxy]]: ...
    def replace_service_cidr_with_http_info(self, name: str, body: V1beta1ServiceCIDR, **kwargs: Any) -> Awaitable[tuple[V1beta1ServiceCIDR, int, CIMultiDictProxy]]: ...
