from kubernetes_asyncio.client.models import V1GroupSubject
from kubernetes_asyncio.client.models import V1ServiceAccountSubject
from kubernetes_asyncio.client.models import V1UserSubject
from typing import Any

class FlowcontrolV1Subject:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, group: V1GroupSubject | None = None, kind: str | None = None, service_account: V1ServiceAccountSubject | None = None, user: V1UserSubject | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def group(self) -> V1GroupSubject: ...
    @group.setter
    def group(self, group: V1GroupSubject) -> None: ...
    @property
    def kind(self) -> str: ...
    @kind.setter
    def kind(self, kind: str) -> None: ...
    @property
    def service_account(self) -> V1ServiceAccountSubject: ...
    @service_account.setter
    def service_account(self, service_account: V1ServiceAccountSubject) -> None: ...
    @property
    def user(self) -> V1UserSubject: ...
    @user.setter
    def user(self, user: V1UserSubject) -> None: ...
