from kubernetes_asyncio.client.models import V2MetricValueStatus
from typing import Any

class V2ContainerResourceMetricStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, container: str | None = None, current: V2MetricValueStatus | None = None, name: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def container(self) -> str: ...
    @container.setter
    def container(self, container: str) -> None: ...
    @property
    def current(self) -> V2MetricValueStatus: ...
    @current.setter
    def current(self, current: V2MetricValueStatus) -> None: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
