from kubernetes_asyncio.client.models import V1LoadBalancerIngress
from typing import Any

class V1LoadBalancerStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, ingress: list[V1LoadBalancerIngress] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def ingress(self) -> list[V1LoadBalancerIngress]: ...
    @ingress.setter
    def ingress(self, ingress: list[V1LoadBalancerIngress]) -> None: ...
