from kubernetes_asyncio.client.models import V1CustomResourceDefinitionCondition
from kubernetes_asyncio.client.models import V1CustomResourceDefinitionNames
from typing import Any

class V1CustomResourceDefinitionStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, accepted_names: V1CustomResourceDefinitionNames | None = None, conditions: list[V1CustomResourceDefinitionCondition] | None = None, stored_versions: list[str] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def accepted_names(self) -> V1CustomResourceDefinitionNames: ...
    @accepted_names.setter
    def accepted_names(self, accepted_names: V1CustomResourceDefinitionNames) -> None: ...
    @property
    def conditions(self) -> list[V1CustomResourceDefinitionCondition]: ...
    @conditions.setter
    def conditions(self, conditions: list[V1CustomResourceDefinitionCondition]) -> None: ...
    @property
    def stored_versions(self) -> list[str]: ...
    @stored_versions.setter
    def stored_versions(self, stored_versions: list[str]) -> None: ...
