from kubernetes_asyncio.client.models import V1Condition
from kubernetes_asyncio.client.models import V1TypeChecking
from typing import Any

class V1ValidatingAdmissionPolicyStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, conditions: list[V1Condition] | None = None, observed_generation: int | None = None, type_checking: V1TypeChecking | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def conditions(self) -> list[V1Condition]: ...
    @conditions.setter
    def conditions(self, conditions: list[V1Condition]) -> None: ...
    @property
    def observed_generation(self) -> int: ...
    @observed_generation.setter
    def observed_generation(self, observed_generation: int) -> None: ...
    @property
    def type_checking(self) -> V1TypeChecking: ...
    @type_checking.setter
    def type_checking(self, type_checking: V1TypeChecking) -> None: ...
