from kubernetes_asyncio.client.models import V1GroupVersionForDiscovery
from kubernetes_asyncio.client.models import V1ServerAddressByClientCIDR
from typing import Any

class V1APIGroup:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, api_version: str | None = None, kind: str | None = None, name: str | None = None, preferred_version: V1GroupVersionForDiscovery | None = None, server_address_by_client_cidrs: list[V1ServerAddressByClientCIDR] | None = None, versions: list[V1GroupVersionForDiscovery] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def api_version(self) -> str: ...
    @api_version.setter
    def api_version(self, api_version: str) -> None: ...
    @property
    def kind(self) -> str: ...
    @kind.setter
    def kind(self, kind: str) -> None: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
    @property
    def preferred_version(self) -> V1GroupVersionForDiscovery: ...
    @preferred_version.setter
    def preferred_version(self, preferred_version: V1GroupVersionForDiscovery) -> None: ...
    @property
    def server_address_by_client_cidrs(self) -> list[V1ServerAddressByClientCIDR]: ...
    @server_address_by_client_cidrs.setter
    def server_address_by_client_cidrs(self, server_address_by_client_cidrs: list[V1ServerAddressByClientCIDR]) -> None: ...
    @property
    def versions(self) -> list[V1GroupVersionForDiscovery]: ...
    @versions.setter
    def versions(self, versions: list[V1GroupVersionForDiscovery]) -> None: ...
