from kubernetes_asyncio.client.models import V1beta1BasicDevice
from typing import Any

class V1beta1Device:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, basic: V1beta1BasicDevice | None = None, name: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def basic(self) -> V1beta1BasicDevice: ...
    @basic.setter
    def basic(self, basic: V1beta1BasicDevice) -> None: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
