from kubernetes_asyncio.client.models import V1NodeConfigSource
from kubernetes_asyncio.client.models import V1Taint
from typing import Any

class V1NodeSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, config_source: V1NodeConfigSource | None = None, external_id: str | None = None, pod_cidr: str | None = None, pod_cidrs: list[str] | None = None, provider_id: str | None = None, taints: list[V1Taint] | None = None, unschedulable: bool | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def config_source(self) -> V1NodeConfigSource: ...
    @config_source.setter
    def config_source(self, config_source: V1NodeConfigSource) -> None: ...
    @property
    def external_id(self) -> str: ...
    @external_id.setter
    def external_id(self, external_id: str) -> None: ...
    @property
    def pod_cidr(self) -> str: ...
    @pod_cidr.setter
    def pod_cidr(self, pod_cidr: str) -> None: ...
    @property
    def pod_cidrs(self) -> list[str]: ...
    @pod_cidrs.setter
    def pod_cidrs(self, pod_cidrs: list[str]) -> None: ...
    @property
    def provider_id(self) -> str: ...
    @provider_id.setter
    def provider_id(self, provider_id: str) -> None: ...
    @property
    def taints(self) -> list[V1Taint]: ...
    @taints.setter
    def taints(self, taints: list[V1Taint]) -> None: ...
    @property
    def unschedulable(self) -> bool: ...
    @unschedulable.setter
    def unschedulable(self, unschedulable: bool) -> None: ...
