from typing import Any

class V1NodeRuntimeHandlerFeatures:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, recursive_read_only_mounts: bool | None = None, user_namespaces: bool | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def recursive_read_only_mounts(self) -> bool: ...
    @recursive_read_only_mounts.setter
    def recursive_read_only_mounts(self, recursive_read_only_mounts: bool) -> None: ...
    @property
    def user_namespaces(self) -> bool: ...
    @user_namespaces.setter
    def user_namespaces(self, user_namespaces: bool) -> None: ...
