from kubernetes_asyncio.client.models import V1NodeAffinity
from kubernetes_asyncio.client.models import V1PodAffinity
from kubernetes_asyncio.client.models import V1PodAntiAffinity
from typing import Any

class V1Affinity:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, node_affinity: V1NodeAffinity | None = None, pod_affinity: V1PodAffinity | None = None, pod_anti_affinity: V1PodAntiAffinity | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def node_affinity(self) -> V1NodeAffinity: ...
    @node_affinity.setter
    def node_affinity(self, node_affinity: V1NodeAffinity) -> None: ...
    @property
    def pod_affinity(self) -> V1PodAffinity: ...
    @pod_affinity.setter
    def pod_affinity(self, pod_affinity: V1PodAffinity) -> None: ...
    @property
    def pod_anti_affinity(self) -> V1PodAntiAffinity: ...
    @pod_anti_affinity.setter
    def pod_anti_affinity(self, pod_anti_affinity: V1PodAntiAffinity) -> None: ...
