from typing import Any

class V1ListMeta:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, _continue: str | None = None, remaining_item_count: int | None = None, resource_version: str | None = None, self_link: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def _continue(self) -> str: ...
    @_continue.setter
    def _continue(self, _continue: str) -> None: ...
    @property
    def remaining_item_count(self) -> int: ...
    @remaining_item_count.setter
    def remaining_item_count(self, remaining_item_count: int) -> None: ...
    @property
    def resource_version(self) -> str: ...
    @resource_version.setter
    def resource_version(self, resource_version: str) -> None: ...
    @property
    def self_link(self) -> str: ...
    @self_link.setter
    def self_link(self, self_link: str) -> None: ...
