from kubernetes_asyncio.client.models import V1alpha1ServerStorageVersion
from kubernetes_asyncio.client.models import V1alpha1StorageVersionCondition
from typing import Any

class V1alpha1StorageVersionStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, common_encoding_version: str | None = None, conditions: list[V1alpha1StorageVersionCondition] | None = None, storage_versions: list[V1alpha1ServerStorageVersion] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def common_encoding_version(self) -> str: ...
    @common_encoding_version.setter
    def common_encoding_version(self, common_encoding_version: str) -> None: ...
    @property
    def conditions(self) -> list[V1alpha1StorageVersionCondition]: ...
    @conditions.setter
    def conditions(self, conditions: list[V1alpha1StorageVersionCondition]) -> None: ...
    @property
    def storage_versions(self) -> list[V1alpha1ServerStorageVersion]: ...
    @storage_versions.setter
    def storage_versions(self, storage_versions: list[V1alpha1ServerStorageVersion]) -> None: ...
