from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1Status
from kubernetes_asyncio.client.models import V1beta2DeviceClass
from kubernetes_asyncio.client.models import V1beta2DeviceClassList
from kubernetes_asyncio.client.models import V1beta2ResourceClaim
from kubernetes_asyncio.client.models import V1beta2ResourceClaimList
from kubernetes_asyncio.client.models import V1beta2ResourceClaimTemplate
from kubernetes_asyncio.client.models import V1beta2ResourceClaimTemplateList
from kubernetes_asyncio.client.models import V1beta2ResourceSlice
from kubernetes_asyncio.client.models import V1beta2ResourceSliceList
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class ResourceV1beta2Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def create_device_class(self, body: V1beta2DeviceClass, **kwargs: Any) -> Awaitable[V1beta2DeviceClass]: ...
    def create_device_class_with_http_info(self, body: V1beta2DeviceClass, **kwargs: Any) -> Awaitable[tuple[V1beta2DeviceClass, int, CIMultiDictProxy]]: ...
    def create_namespaced_resource_claim(self, namespace: str, body: V1beta2ResourceClaim, **kwargs: Any) -> Awaitable[V1beta2ResourceClaim]: ...
    def create_namespaced_resource_claim_template(self, namespace: str, body: V1beta2ResourceClaimTemplate, **kwargs: Any) -> Awaitable[V1beta2ResourceClaimTemplate]: ...
    def create_namespaced_resource_claim_template_with_http_info(self, namespace: str, body: V1beta2ResourceClaimTemplate, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaimTemplate, int, CIMultiDictProxy]]: ...
    def create_namespaced_resource_claim_with_http_info(self, namespace: str, body: V1beta2ResourceClaim, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaim, int, CIMultiDictProxy]]: ...
    def create_resource_slice(self, body: V1beta2ResourceSlice, **kwargs: Any) -> Awaitable[V1beta2ResourceSlice]: ...
    def create_resource_slice_with_http_info(self, body: V1beta2ResourceSlice, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceSlice, int, CIMultiDictProxy]]: ...
    def delete_collection_device_class(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_device_class_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_resource_claim(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_resource_claim_template(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_resource_claim_template_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_resource_claim_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_resource_slice(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_resource_slice_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_device_class(self, name: str, **kwargs: Any) -> Awaitable[V1beta2DeviceClass]: ...
    def delete_device_class_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1beta2DeviceClass, int, CIMultiDictProxy]]: ...
    def delete_namespaced_resource_claim(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1beta2ResourceClaim]: ...
    def delete_namespaced_resource_claim_template(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1beta2ResourceClaimTemplate]: ...
    def delete_namespaced_resource_claim_template_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaimTemplate, int, CIMultiDictProxy]]: ...
    def delete_namespaced_resource_claim_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaim, int, CIMultiDictProxy]]: ...
    def delete_resource_slice(self, name: str, **kwargs: Any) -> Awaitable[V1beta2ResourceSlice]: ...
    def delete_resource_slice_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceSlice, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
    def list_device_class(self, **kwargs: Any) -> Awaitable[V1beta2DeviceClassList]: ...
    def list_device_class_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1beta2DeviceClassList, int, CIMultiDictProxy]]: ...
    def list_namespaced_resource_claim(self, namespace: str, **kwargs: Any) -> Awaitable[V1beta2ResourceClaimList]: ...
    def list_namespaced_resource_claim_template(self, namespace: str, **kwargs: Any) -> Awaitable[V1beta2ResourceClaimTemplateList]: ...
    def list_namespaced_resource_claim_template_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaimTemplateList, int, CIMultiDictProxy]]: ...
    def list_namespaced_resource_claim_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaimList, int, CIMultiDictProxy]]: ...
    def list_resource_claim_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1beta2ResourceClaimList]: ...
    def list_resource_claim_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaimList, int, CIMultiDictProxy]]: ...
    def list_resource_claim_template_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1beta2ResourceClaimTemplateList]: ...
    def list_resource_claim_template_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaimTemplateList, int, CIMultiDictProxy]]: ...
    def list_resource_slice(self, **kwargs: Any) -> Awaitable[V1beta2ResourceSliceList]: ...
    def list_resource_slice_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceSliceList, int, CIMultiDictProxy]]: ...
    def patch_device_class(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1beta2DeviceClass]: ...
    def patch_device_class_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1beta2DeviceClass, int, CIMultiDictProxy]]: ...
    def patch_namespaced_resource_claim(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1beta2ResourceClaim]: ...
    def patch_namespaced_resource_claim_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1beta2ResourceClaim]: ...
    def patch_namespaced_resource_claim_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaim, int, CIMultiDictProxy]]: ...
    def patch_namespaced_resource_claim_template(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1beta2ResourceClaimTemplate]: ...
    def patch_namespaced_resource_claim_template_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaimTemplate, int, CIMultiDictProxy]]: ...
    def patch_namespaced_resource_claim_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaim, int, CIMultiDictProxy]]: ...
    def patch_resource_slice(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1beta2ResourceSlice]: ...
    def patch_resource_slice_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceSlice, int, CIMultiDictProxy]]: ...
    def read_device_class(self, name: str, **kwargs: Any) -> Awaitable[V1beta2DeviceClass]: ...
    def read_device_class_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1beta2DeviceClass, int, CIMultiDictProxy]]: ...
    def read_namespaced_resource_claim(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1beta2ResourceClaim]: ...
    def read_namespaced_resource_claim_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1beta2ResourceClaim]: ...
    def read_namespaced_resource_claim_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaim, int, CIMultiDictProxy]]: ...
    def read_namespaced_resource_claim_template(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1beta2ResourceClaimTemplate]: ...
    def read_namespaced_resource_claim_template_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaimTemplate, int, CIMultiDictProxy]]: ...
    def read_namespaced_resource_claim_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaim, int, CIMultiDictProxy]]: ...
    def read_resource_slice(self, name: str, **kwargs: Any) -> Awaitable[V1beta2ResourceSlice]: ...
    def read_resource_slice_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceSlice, int, CIMultiDictProxy]]: ...
    def replace_device_class(self, name: str, body: V1beta2DeviceClass, **kwargs: Any) -> Awaitable[V1beta2DeviceClass]: ...
    def replace_device_class_with_http_info(self, name: str, body: V1beta2DeviceClass, **kwargs: Any) -> Awaitable[tuple[V1beta2DeviceClass, int, CIMultiDictProxy]]: ...
    def replace_namespaced_resource_claim(self, name: str, namespace: str, body: V1beta2ResourceClaim, **kwargs: Any) -> Awaitable[V1beta2ResourceClaim]: ...
    def replace_namespaced_resource_claim_status(self, name: str, namespace: str, body: V1beta2ResourceClaim, **kwargs: Any) -> Awaitable[V1beta2ResourceClaim]: ...
    def replace_namespaced_resource_claim_status_with_http_info(self, name: str, namespace: str, body: V1beta2ResourceClaim, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaim, int, CIMultiDictProxy]]: ...
    def replace_namespaced_resource_claim_template(self, name: str, namespace: str, body: V1beta2ResourceClaimTemplate, **kwargs: Any) -> Awaitable[V1beta2ResourceClaimTemplate]: ...
    def replace_namespaced_resource_claim_template_with_http_info(self, name: str, namespace: str, body: V1beta2ResourceClaimTemplate, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaimTemplate, int, CIMultiDictProxy]]: ...
    def replace_namespaced_resource_claim_with_http_info(self, name: str, namespace: str, body: V1beta2ResourceClaim, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceClaim, int, CIMultiDictProxy]]: ...
    def replace_resource_slice(self, name: str, body: V1beta2ResourceSlice, **kwargs: Any) -> Awaitable[V1beta2ResourceSlice]: ...
    def replace_resource_slice_with_http_info(self, name: str, body: V1beta2ResourceSlice, **kwargs: Any) -> Awaitable[tuple[V1beta2ResourceSlice, int, CIMultiDictProxy]]: ...
