from typing import Any

class V1CustomResourceColumnDefinition:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, description: str | None = None, format: str | None = None, json_path: str | None = None, name: str | None = None, priority: int | None = None, type: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def description(self) -> str: ...
    @description.setter
    def description(self, description: str) -> None: ...
    @property
    def format(self) -> str: ...
    @format.setter
    def format(self, format: str) -> None: ...
    @property
    def json_path(self) -> str: ...
    @json_path.setter
    def json_path(self, json_path: str) -> None: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
    @property
    def priority(self) -> int: ...
    @priority.setter
    def priority(self, priority: int) -> None: ...
    @property
    def type(self) -> str: ...
    @type.setter
    def type(self, type: str) -> None: ...
