from kubernetes_asyncio.client.models import V1ExemptPriorityLevelConfiguration
from kubernetes_asyncio.client.models import V1LimitedPriorityLevelConfiguration
from typing import Any

class V1PriorityLevelConfigurationSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, exempt: V1ExemptPriorityLevelConfiguration | None = None, limited: V1LimitedPriorityLevelConfiguration | None = None, type: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def exempt(self) -> V1ExemptPriorityLevelConfiguration: ...
    @exempt.setter
    def exempt(self, exempt: V1ExemptPriorityLevelConfiguration) -> None: ...
    @property
    def limited(self) -> V1LimitedPriorityLevelConfiguration: ...
    @limited.setter
    def limited(self, limited: V1LimitedPriorityLevelConfiguration) -> None: ...
    @property
    def type(self) -> str: ...
    @type.setter
    def type(self, type: str) -> None: ...
