from kubernetes_asyncio.client.models import V1ContainerPort
from kubernetes_asyncio.client.models import V1ContainerResizePolicy
from kubernetes_asyncio.client.models import V1ContainerRestartRule
from kubernetes_asyncio.client.models import V1EnvFromSource
from kubernetes_asyncio.client.models import V1EnvVar
from kubernetes_asyncio.client.models import V1Lifecycle
from kubernetes_asyncio.client.models import V1Probe
from kubernetes_asyncio.client.models import V1ResourceRequirements
from kubernetes_asyncio.client.models import V1SecurityContext
from kubernetes_asyncio.client.models import V1VolumeDevice
from kubernetes_asyncio.client.models import V1VolumeMount
from typing import Any

class V1Container:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, args: list[str] | None = None, command: list[str] | None = None, env: list[V1EnvVar] | None = None, env_from: list[V1EnvFromSource] | None = None, image: str | None = None, image_pull_policy: str | None = None, lifecycle: V1Lifecycle | None = None, liveness_probe: V1Probe | None = None, name: str | None = None, ports: list[V1ContainerPort] | None = None, readiness_probe: V1Probe | None = None, resize_policy: list[V1ContainerResizePolicy] | None = None, resources: V1ResourceRequirements | None = None, restart_policy: str | None = None, restart_policy_rules: list[V1ContainerRestartRule] | None = None, security_context: V1SecurityContext | None = None, startup_probe: V1Probe | None = None, stdin: bool | None = None, stdin_once: bool | None = None, termination_message_path: str | None = None, termination_message_policy: str | None = None, tty: bool | None = None, volume_devices: list[V1VolumeDevice] | None = None, volume_mounts: list[V1VolumeMount] | None = None, working_dir: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def args(self) -> list[str]: ...
    @args.setter
    def args(self, args: list[str]) -> None: ...
    @property
    def command(self) -> list[str]: ...
    @command.setter
    def command(self, command: list[str]) -> None: ...
    @property
    def env(self) -> list[V1EnvVar]: ...
    @env.setter
    def env(self, env: list[V1EnvVar]) -> None: ...
    @property
    def env_from(self) -> list[V1EnvFromSource]: ...
    @env_from.setter
    def env_from(self, env_from: list[V1EnvFromSource]) -> None: ...
    @property
    def image(self) -> str: ...
    @image.setter
    def image(self, image: str) -> None: ...
    @property
    def image_pull_policy(self) -> str: ...
    @image_pull_policy.setter
    def image_pull_policy(self, image_pull_policy: str) -> None: ...
    @property
    def lifecycle(self) -> V1Lifecycle: ...
    @lifecycle.setter
    def lifecycle(self, lifecycle: V1Lifecycle) -> None: ...
    @property
    def liveness_probe(self) -> V1Probe: ...
    @liveness_probe.setter
    def liveness_probe(self, liveness_probe: V1Probe) -> None: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
    @property
    def ports(self) -> list[V1ContainerPort]: ...
    @ports.setter
    def ports(self, ports: list[V1ContainerPort]) -> None: ...
    @property
    def readiness_probe(self) -> V1Probe: ...
    @readiness_probe.setter
    def readiness_probe(self, readiness_probe: V1Probe) -> None: ...
    @property
    def resize_policy(self) -> list[V1ContainerResizePolicy]: ...
    @resize_policy.setter
    def resize_policy(self, resize_policy: list[V1ContainerResizePolicy]) -> None: ...
    @property
    def resources(self) -> V1ResourceRequirements: ...
    @resources.setter
    def resources(self, resources: V1ResourceRequirements) -> None: ...
    @property
    def restart_policy(self) -> str: ...
    @restart_policy.setter
    def restart_policy(self, restart_policy: str) -> None: ...
    @property
    def restart_policy_rules(self) -> list[V1ContainerRestartRule]: ...
    @restart_policy_rules.setter
    def restart_policy_rules(self, restart_policy_rules: list[V1ContainerRestartRule]) -> None: ...
    @property
    def security_context(self) -> V1SecurityContext: ...
    @security_context.setter
    def security_context(self, security_context: V1SecurityContext) -> None: ...
    @property
    def startup_probe(self) -> V1Probe: ...
    @startup_probe.setter
    def startup_probe(self, startup_probe: V1Probe) -> None: ...
    @property
    def stdin(self) -> bool: ...
    @stdin.setter
    def stdin(self, stdin: bool) -> None: ...
    @property
    def stdin_once(self) -> bool: ...
    @stdin_once.setter
    def stdin_once(self, stdin_once: bool) -> None: ...
    @property
    def termination_message_path(self) -> str: ...
    @termination_message_path.setter
    def termination_message_path(self, termination_message_path: str) -> None: ...
    @property
    def termination_message_policy(self) -> str: ...
    @termination_message_policy.setter
    def termination_message_policy(self, termination_message_policy: str) -> None: ...
    @property
    def tty(self) -> bool: ...
    @tty.setter
    def tty(self, tty: bool) -> None: ...
    @property
    def volume_devices(self) -> list[V1VolumeDevice]: ...
    @volume_devices.setter
    def volume_devices(self, volume_devices: list[V1VolumeDevice]) -> None: ...
    @property
    def volume_mounts(self) -> list[V1VolumeMount]: ...
    @volume_mounts.setter
    def volume_mounts(self, volume_mounts: list[V1VolumeMount]) -> None: ...
    @property
    def working_dir(self) -> str: ...
    @working_dir.setter
    def working_dir(self, working_dir: str) -> None: ...
