from kubernetes_asyncio.client.models import V1VolumeAttachmentSource
from typing import Any

class V1VolumeAttachmentSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, attacher: str | None = None, node_name: str | None = None, source: V1VolumeAttachmentSource | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def attacher(self) -> str: ...
    @attacher.setter
    def attacher(self, attacher: str) -> None: ...
    @property
    def node_name(self) -> str: ...
    @node_name.setter
    def node_name(self, node_name: str) -> None: ...
    @property
    def source(self) -> V1VolumeAttachmentSource: ...
    @source.setter
    def source(self, source: V1VolumeAttachmentSource) -> None: ...
