from typing import Any

class V1SELinuxOptions:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, level: str | None = None, role: str | None = None, type: str | None = None, user: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def level(self) -> str: ...
    @level.setter
    def level(self, level: str) -> None: ...
    @property
    def role(self) -> str: ...
    @role.setter
    def role(self, role: str) -> None: ...
    @property
    def type(self) -> str: ...
    @type.setter
    def type(self, type: str) -> None: ...
    @property
    def user(self) -> str: ...
    @user.setter
    def user(self, user: str) -> None: ...
