from typing import Any

class V1ExemptPriorityLevelConfiguration:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, lendable_percent: int | None = None, nominal_concurrency_shares: int | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def lendable_percent(self) -> int: ...
    @lendable_percent.setter
    def lendable_percent(self, lendable_percent: int) -> None: ...
    @property
    def nominal_concurrency_shares(self) -> int: ...
    @nominal_concurrency_shares.setter
    def nominal_concurrency_shares(self, nominal_concurrency_shares: int) -> None: ...
