from datetime import datetime
from kubernetes_asyncio.client.models import EventsV1EventSeries
from kubernetes_asyncio.client.models import V1EventSource
from kubernetes_asyncio.client.models import V1ObjectMeta
from kubernetes_asyncio.client.models import V1ObjectReference
from typing import Any

class EventsV1Event:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, action: str | None = None, api_version: str | None = None, deprecated_count: int | None = None, deprecated_first_timestamp: datetime | None = None, deprecated_last_timestamp: datetime | None = None, deprecated_source: V1EventSource | None = None, event_time: datetime | None = None, kind: str | None = None, metadata: V1ObjectMeta | None = None, note: str | None = None, reason: str | None = None, regarding: V1ObjectReference | None = None, related: V1ObjectReference | None = None, reporting_controller: str | None = None, reporting_instance: str | None = None, series: EventsV1EventSeries | None = None, type: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def action(self) -> str: ...
    @action.setter
    def action(self, action: str) -> None: ...
    @property
    def api_version(self) -> str: ...
    @api_version.setter
    def api_version(self, api_version: str) -> None: ...
    @property
    def deprecated_count(self) -> int: ...
    @deprecated_count.setter
    def deprecated_count(self, deprecated_count: int) -> None: ...
    @property
    def deprecated_first_timestamp(self) -> datetime: ...
    @deprecated_first_timestamp.setter
    def deprecated_first_timestamp(self, deprecated_first_timestamp: datetime) -> None: ...
    @property
    def deprecated_last_timestamp(self) -> datetime: ...
    @deprecated_last_timestamp.setter
    def deprecated_last_timestamp(self, deprecated_last_timestamp: datetime) -> None: ...
    @property
    def deprecated_source(self) -> V1EventSource: ...
    @deprecated_source.setter
    def deprecated_source(self, deprecated_source: V1EventSource) -> None: ...
    @property
    def event_time(self) -> datetime: ...
    @event_time.setter
    def event_time(self, event_time: datetime) -> None: ...
    @property
    def kind(self) -> str: ...
    @kind.setter
    def kind(self, kind: str) -> None: ...
    @property
    def metadata(self) -> V1ObjectMeta: ...
    @metadata.setter
    def metadata(self, metadata: V1ObjectMeta) -> None: ...
    @property
    def note(self) -> str: ...
    @note.setter
    def note(self, note: str) -> None: ...
    @property
    def reason(self) -> str: ...
    @reason.setter
    def reason(self, reason: str) -> None: ...
    @property
    def regarding(self) -> V1ObjectReference: ...
    @regarding.setter
    def regarding(self, regarding: V1ObjectReference) -> None: ...
    @property
    def related(self) -> V1ObjectReference: ...
    @related.setter
    def related(self, related: V1ObjectReference) -> None: ...
    @property
    def reporting_controller(self) -> str: ...
    @reporting_controller.setter
    def reporting_controller(self, reporting_controller: str) -> None: ...
    @property
    def reporting_instance(self) -> str: ...
    @reporting_instance.setter
    def reporting_instance(self, reporting_instance: str) -> None: ...
    @property
    def series(self) -> EventsV1EventSeries: ...
    @series.setter
    def series(self, series: EventsV1EventSeries) -> None: ...
    @property
    def type(self) -> str: ...
    @type.setter
    def type(self, type: str) -> None: ...
