from kubernetes_asyncio.client.models import V1beta1DeviceAllocationConfiguration
from kubernetes_asyncio.client.models import V1beta1DeviceRequestAllocationResult
from typing import Any

class V1beta1DeviceAllocationResult:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, config: list[V1beta1DeviceAllocationConfiguration] | None = None, results: list[V1beta1DeviceRequestAllocationResult] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def config(self) -> list[V1beta1DeviceAllocationConfiguration]: ...
    @config.setter
    def config(self, config: list[V1beta1DeviceAllocationConfiguration]) -> None: ...
    @property
    def results(self) -> list[V1beta1DeviceRequestAllocationResult]: ...
    @results.setter
    def results(self, results: list[V1beta1DeviceRequestAllocationResult]) -> None: ...
