from kubernetes_asyncio.client.models import V1ExpressionWarning
from typing import Any

class V1TypeChecking:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, expression_warnings: list[V1ExpressionWarning] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def expression_warnings(self) -> list[V1ExpressionWarning]: ...
    @expression_warnings.setter
    def expression_warnings(self, expression_warnings: list[V1ExpressionWarning]) -> None: ...
