from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1ControllerRevision
from kubernetes_asyncio.client.models import V1ControllerRevisionList
from kubernetes_asyncio.client.models import V1DaemonSet
from kubernetes_asyncio.client.models import V1DaemonSetList
from kubernetes_asyncio.client.models import V1Deployment
from kubernetes_asyncio.client.models import V1DeploymentList
from kubernetes_asyncio.client.models import V1ReplicaSet
from kubernetes_asyncio.client.models import V1ReplicaSetList
from kubernetes_asyncio.client.models import V1Scale
from kubernetes_asyncio.client.models import V1StatefulSet
from kubernetes_asyncio.client.models import V1StatefulSetList
from kubernetes_asyncio.client.models import V1Status
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class AppsV1Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def create_namespaced_controller_revision(self, namespace: str, body: V1ControllerRevision, **kwargs: Any) -> Awaitable[V1ControllerRevision]: ...
    def create_namespaced_controller_revision_with_http_info(self, namespace: str, body: V1ControllerRevision, **kwargs: Any) -> Awaitable[tuple[V1ControllerRevision, int, CIMultiDictProxy]]: ...
    def create_namespaced_daemon_set(self, namespace: str, body: V1DaemonSet, **kwargs: Any) -> Awaitable[V1DaemonSet]: ...
    def create_namespaced_daemon_set_with_http_info(self, namespace: str, body: V1DaemonSet, **kwargs: Any) -> Awaitable[tuple[V1DaemonSet, int, CIMultiDictProxy]]: ...
    def create_namespaced_deployment(self, namespace: str, body: V1Deployment, **kwargs: Any) -> Awaitable[V1Deployment]: ...
    def create_namespaced_deployment_with_http_info(self, namespace: str, body: V1Deployment, **kwargs: Any) -> Awaitable[tuple[V1Deployment, int, CIMultiDictProxy]]: ...
    def create_namespaced_replica_set(self, namespace: str, body: V1ReplicaSet, **kwargs: Any) -> Awaitable[V1ReplicaSet]: ...
    def create_namespaced_replica_set_with_http_info(self, namespace: str, body: V1ReplicaSet, **kwargs: Any) -> Awaitable[tuple[V1ReplicaSet, int, CIMultiDictProxy]]: ...
    def create_namespaced_stateful_set(self, namespace: str, body: V1StatefulSet, **kwargs: Any) -> Awaitable[V1StatefulSet]: ...
    def create_namespaced_stateful_set_with_http_info(self, namespace: str, body: V1StatefulSet, **kwargs: Any) -> Awaitable[tuple[V1StatefulSet, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_controller_revision(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_controller_revision_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_daemon_set(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_daemon_set_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_deployment(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_deployment_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_replica_set(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_replica_set_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_stateful_set(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_stateful_set_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_controller_revision(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_controller_revision_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_daemon_set(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_daemon_set_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_deployment(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_deployment_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_replica_set(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_replica_set_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_stateful_set(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_stateful_set_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
    def list_controller_revision_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1ControllerRevisionList]: ...
    def list_controller_revision_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ControllerRevisionList, int, CIMultiDictProxy]]: ...
    def list_daemon_set_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1DaemonSetList]: ...
    def list_daemon_set_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1DaemonSetList, int, CIMultiDictProxy]]: ...
    def list_deployment_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1DeploymentList]: ...
    def list_deployment_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1DeploymentList, int, CIMultiDictProxy]]: ...
    def list_namespaced_controller_revision(self, namespace: str, **kwargs: Any) -> Awaitable[V1ControllerRevisionList]: ...
    def list_namespaced_controller_revision_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ControllerRevisionList, int, CIMultiDictProxy]]: ...
    def list_namespaced_daemon_set(self, namespace: str, **kwargs: Any) -> Awaitable[V1DaemonSetList]: ...
    def list_namespaced_daemon_set_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1DaemonSetList, int, CIMultiDictProxy]]: ...
    def list_namespaced_deployment(self, namespace: str, **kwargs: Any) -> Awaitable[V1DeploymentList]: ...
    def list_namespaced_deployment_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1DeploymentList, int, CIMultiDictProxy]]: ...
    def list_namespaced_replica_set(self, namespace: str, **kwargs: Any) -> Awaitable[V1ReplicaSetList]: ...
    def list_namespaced_replica_set_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ReplicaSetList, int, CIMultiDictProxy]]: ...
    def list_namespaced_stateful_set(self, namespace: str, **kwargs: Any) -> Awaitable[V1StatefulSetList]: ...
    def list_namespaced_stateful_set_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1StatefulSetList, int, CIMultiDictProxy]]: ...
    def list_replica_set_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1ReplicaSetList]: ...
    def list_replica_set_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ReplicaSetList, int, CIMultiDictProxy]]: ...
    def list_stateful_set_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1StatefulSetList]: ...
    def list_stateful_set_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1StatefulSetList, int, CIMultiDictProxy]]: ...
    def patch_namespaced_controller_revision(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1ControllerRevision]: ...
    def patch_namespaced_controller_revision_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ControllerRevision, int, CIMultiDictProxy]]: ...
    def patch_namespaced_daemon_set(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1DaemonSet]: ...
    def patch_namespaced_daemon_set_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1DaemonSet]: ...
    def patch_namespaced_daemon_set_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1DaemonSet, int, CIMultiDictProxy]]: ...
    def patch_namespaced_daemon_set_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1DaemonSet, int, CIMultiDictProxy]]: ...
    def patch_namespaced_deployment(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Deployment]: ...
    def patch_namespaced_deployment_scale(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Scale]: ...
    def patch_namespaced_deployment_scale_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Scale, int, CIMultiDictProxy]]: ...
    def patch_namespaced_deployment_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Deployment]: ...
    def patch_namespaced_deployment_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Deployment, int, CIMultiDictProxy]]: ...
    def patch_namespaced_deployment_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Deployment, int, CIMultiDictProxy]]: ...
    def patch_namespaced_replica_set(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1ReplicaSet]: ...
    def patch_namespaced_replica_set_scale(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Scale]: ...
    def patch_namespaced_replica_set_scale_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Scale, int, CIMultiDictProxy]]: ...
    def patch_namespaced_replica_set_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1ReplicaSet]: ...
    def patch_namespaced_replica_set_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ReplicaSet, int, CIMultiDictProxy]]: ...
    def patch_namespaced_replica_set_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ReplicaSet, int, CIMultiDictProxy]]: ...
    def patch_namespaced_stateful_set(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1StatefulSet]: ...
    def patch_namespaced_stateful_set_scale(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Scale]: ...
    def patch_namespaced_stateful_set_scale_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Scale, int, CIMultiDictProxy]]: ...
    def patch_namespaced_stateful_set_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1StatefulSet]: ...
    def patch_namespaced_stateful_set_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1StatefulSet, int, CIMultiDictProxy]]: ...
    def patch_namespaced_stateful_set_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1StatefulSet, int, CIMultiDictProxy]]: ...
    def read_namespaced_controller_revision(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ControllerRevision]: ...
    def read_namespaced_controller_revision_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ControllerRevision, int, CIMultiDictProxy]]: ...
    def read_namespaced_daemon_set(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1DaemonSet]: ...
    def read_namespaced_daemon_set_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1DaemonSet]: ...
    def read_namespaced_daemon_set_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1DaemonSet, int, CIMultiDictProxy]]: ...
    def read_namespaced_daemon_set_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1DaemonSet, int, CIMultiDictProxy]]: ...
    def read_namespaced_deployment(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Deployment]: ...
    def read_namespaced_deployment_scale(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Scale]: ...
    def read_namespaced_deployment_scale_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Scale, int, CIMultiDictProxy]]: ...
    def read_namespaced_deployment_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Deployment]: ...
    def read_namespaced_deployment_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Deployment, int, CIMultiDictProxy]]: ...
    def read_namespaced_deployment_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Deployment, int, CIMultiDictProxy]]: ...
    def read_namespaced_replica_set(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ReplicaSet]: ...
    def read_namespaced_replica_set_scale(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Scale]: ...
    def read_namespaced_replica_set_scale_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Scale, int, CIMultiDictProxy]]: ...
    def read_namespaced_replica_set_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ReplicaSet]: ...
    def read_namespaced_replica_set_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ReplicaSet, int, CIMultiDictProxy]]: ...
    def read_namespaced_replica_set_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ReplicaSet, int, CIMultiDictProxy]]: ...
    def read_namespaced_stateful_set(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1StatefulSet]: ...
    def read_namespaced_stateful_set_scale(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Scale]: ...
    def read_namespaced_stateful_set_scale_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Scale, int, CIMultiDictProxy]]: ...
    def read_namespaced_stateful_set_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1StatefulSet]: ...
    def read_namespaced_stateful_set_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1StatefulSet, int, CIMultiDictProxy]]: ...
    def read_namespaced_stateful_set_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1StatefulSet, int, CIMultiDictProxy]]: ...
    def replace_namespaced_controller_revision(self, name: str, namespace: str, body: V1ControllerRevision, **kwargs: Any) -> Awaitable[V1ControllerRevision]: ...
    def replace_namespaced_controller_revision_with_http_info(self, name: str, namespace: str, body: V1ControllerRevision, **kwargs: Any) -> Awaitable[tuple[V1ControllerRevision, int, CIMultiDictProxy]]: ...
    def replace_namespaced_daemon_set(self, name: str, namespace: str, body: V1DaemonSet, **kwargs: Any) -> Awaitable[V1DaemonSet]: ...
    def replace_namespaced_daemon_set_status(self, name: str, namespace: str, body: V1DaemonSet, **kwargs: Any) -> Awaitable[V1DaemonSet]: ...
    def replace_namespaced_daemon_set_status_with_http_info(self, name: str, namespace: str, body: V1DaemonSet, **kwargs: Any) -> Awaitable[tuple[V1DaemonSet, int, CIMultiDictProxy]]: ...
    def replace_namespaced_daemon_set_with_http_info(self, name: str, namespace: str, body: V1DaemonSet, **kwargs: Any) -> Awaitable[tuple[V1DaemonSet, int, CIMultiDictProxy]]: ...
    def replace_namespaced_deployment(self, name: str, namespace: str, body: V1Deployment, **kwargs: Any) -> Awaitable[V1Deployment]: ...
    def replace_namespaced_deployment_scale(self, name: str, namespace: str, body: V1Scale, **kwargs: Any) -> Awaitable[V1Scale]: ...
    def replace_namespaced_deployment_scale_with_http_info(self, name: str, namespace: str, body: V1Scale, **kwargs: Any) -> Awaitable[tuple[V1Scale, int, CIMultiDictProxy]]: ...
    def replace_namespaced_deployment_status(self, name: str, namespace: str, body: V1Deployment, **kwargs: Any) -> Awaitable[V1Deployment]: ...
    def replace_namespaced_deployment_status_with_http_info(self, name: str, namespace: str, body: V1Deployment, **kwargs: Any) -> Awaitable[tuple[V1Deployment, int, CIMultiDictProxy]]: ...
    def replace_namespaced_deployment_with_http_info(self, name: str, namespace: str, body: V1Deployment, **kwargs: Any) -> Awaitable[tuple[V1Deployment, int, CIMultiDictProxy]]: ...
    def replace_namespaced_replica_set(self, name: str, namespace: str, body: V1ReplicaSet, **kwargs: Any) -> Awaitable[V1ReplicaSet]: ...
    def replace_namespaced_replica_set_scale(self, name: str, namespace: str, body: V1Scale, **kwargs: Any) -> Awaitable[V1Scale]: ...
    def replace_namespaced_replica_set_scale_with_http_info(self, name: str, namespace: str, body: V1Scale, **kwargs: Any) -> Awaitable[tuple[V1Scale, int, CIMultiDictProxy]]: ...
    def replace_namespaced_replica_set_status(self, name: str, namespace: str, body: V1ReplicaSet, **kwargs: Any) -> Awaitable[V1ReplicaSet]: ...
    def replace_namespaced_replica_set_status_with_http_info(self, name: str, namespace: str, body: V1ReplicaSet, **kwargs: Any) -> Awaitable[tuple[V1ReplicaSet, int, CIMultiDictProxy]]: ...
    def replace_namespaced_replica_set_with_http_info(self, name: str, namespace: str, body: V1ReplicaSet, **kwargs: Any) -> Awaitable[tuple[V1ReplicaSet, int, CIMultiDictProxy]]: ...
    def replace_namespaced_stateful_set(self, name: str, namespace: str, body: V1StatefulSet, **kwargs: Any) -> Awaitable[V1StatefulSet]: ...
    def replace_namespaced_stateful_set_scale(self, name: str, namespace: str, body: V1Scale, **kwargs: Any) -> Awaitable[V1Scale]: ...
    def replace_namespaced_stateful_set_scale_with_http_info(self, name: str, namespace: str, body: V1Scale, **kwargs: Any) -> Awaitable[tuple[V1Scale, int, CIMultiDictProxy]]: ...
    def replace_namespaced_stateful_set_status(self, name: str, namespace: str, body: V1StatefulSet, **kwargs: Any) -> Awaitable[V1StatefulSet]: ...
    def replace_namespaced_stateful_set_status_with_http_info(self, name: str, namespace: str, body: V1StatefulSet, **kwargs: Any) -> Awaitable[tuple[V1StatefulSet, int, CIMultiDictProxy]]: ...
    def replace_namespaced_stateful_set_with_http_info(self, name: str, namespace: str, body: V1StatefulSet, **kwargs: Any) -> Awaitable[tuple[V1StatefulSet, int, CIMultiDictProxy]]: ...
