from kubernetes_asyncio.client.models import V1JSONSchemaProps
from typing import Any

class V1CustomResourceValidation:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, open_apiv3_schema: V1JSONSchemaProps | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def open_apiv3_schema(self) -> V1JSONSchemaProps: ...
    @open_apiv3_schema.setter
    def open_apiv3_schema(self, open_apiv3_schema: V1JSONSchemaProps) -> None: ...
