from kubernetes_asyncio.client.models import ApiregistrationV1ServiceReference
from typing import Any

class V1APIServiceSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, ca_bundle: str | None = None, group: str | None = None, group_priority_minimum: int | None = None, insecure_skip_tls_verify: bool | None = None, service: ApiregistrationV1ServiceReference | None = None, version: str | None = None, version_priority: int | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def ca_bundle(self) -> str: ...
    @ca_bundle.setter
    def ca_bundle(self, ca_bundle: str) -> None: ...
    @property
    def group(self) -> str: ...
    @group.setter
    def group(self, group: str) -> None: ...
    @property
    def group_priority_minimum(self) -> int: ...
    @group_priority_minimum.setter
    def group_priority_minimum(self, group_priority_minimum: int) -> None: ...
    @property
    def insecure_skip_tls_verify(self) -> bool: ...
    @insecure_skip_tls_verify.setter
    def insecure_skip_tls_verify(self, insecure_skip_tls_verify: bool) -> None: ...
    @property
    def service(self) -> ApiregistrationV1ServiceReference: ...
    @service.setter
    def service(self, service: ApiregistrationV1ServiceReference) -> None: ...
    @property
    def version(self) -> str: ...
    @version.setter
    def version(self, version: str) -> None: ...
    @property
    def version_priority(self) -> int: ...
    @version_priority.setter
    def version_priority(self, version_priority: int) -> None: ...
