from typing import Any

class V1alpha1ServerStorageVersion:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, api_server_id: str | None = None, decodable_versions: list[str] | None = None, encoding_version: str | None = None, served_versions: list[str] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def api_server_id(self) -> str: ...
    @api_server_id.setter
    def api_server_id(self, api_server_id: str) -> None: ...
    @property
    def decodable_versions(self) -> list[str]: ...
    @decodable_versions.setter
    def decodable_versions(self, decodable_versions: list[str]) -> None: ...
    @property
    def encoding_version(self) -> str: ...
    @encoding_version.setter
    def encoding_version(self, encoding_version: str) -> None: ...
    @property
    def served_versions(self) -> list[str]: ...
    @served_versions.setter
    def served_versions(self, served_versions: list[str]) -> None: ...
