from kubernetes_asyncio.client.models import V1DeviceClaim
from typing import Any

class V1ResourceClaimSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, devices: V1DeviceClaim | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def devices(self) -> V1DeviceClaim: ...
    @devices.setter
    def devices(self, devices: V1DeviceClaim) -> None: ...
