from typing import Any

class V1GlusterfsPersistentVolumeSource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, endpoints: str | None = None, endpoints_namespace: str | None = None, path: str | None = None, read_only: bool | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def endpoints(self) -> str: ...
    @endpoints.setter
    def endpoints(self, endpoints: str) -> None: ...
    @property
    def endpoints_namespace(self) -> str: ...
    @endpoints_namespace.setter
    def endpoints_namespace(self, endpoints_namespace: str) -> None: ...
    @property
    def path(self) -> str: ...
    @path.setter
    def path(self, path: str) -> None: ...
    @property
    def read_only(self) -> bool: ...
    @read_only.setter
    def read_only(self, read_only: bool) -> None: ...
