from datetime import datetime
from kubernetes_asyncio.client.models import V1NodeSelector
from kubernetes_asyncio.client.models import V1beta2DeviceAllocationResult
from typing import Any

class V1beta2AllocationResult:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, allocation_timestamp: datetime | None = None, devices: V1beta2DeviceAllocationResult | None = None, node_selector: V1NodeSelector | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def allocation_timestamp(self) -> datetime: ...
    @allocation_timestamp.setter
    def allocation_timestamp(self, allocation_timestamp: datetime) -> None: ...
    @property
    def devices(self) -> V1beta2DeviceAllocationResult: ...
    @devices.setter
    def devices(self, devices: V1beta2DeviceAllocationResult) -> None: ...
    @property
    def node_selector(self) -> V1NodeSelector: ...
    @node_selector.setter
    def node_selector(self, node_selector: V1NodeSelector) -> None: ...
