from kubernetes_asyncio.client.models import V1ClientIPConfig
from typing import Any

class V1SessionAffinityConfig:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, client_ip: V1ClientIPConfig | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def client_ip(self) -> V1ClientIPConfig: ...
    @client_ip.setter
    def client_ip(self, client_ip: V1ClientIPConfig) -> None: ...
