from kubernetes_asyncio.client.models import V2HPAScalingPolicy
from typing import Any

class V2HPAScalingRules:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, policies: list[V2HPAScalingPolicy] | None = None, select_policy: str | None = None, stabilization_window_seconds: int | None = None, tolerance: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def policies(self) -> list[V2HPAScalingPolicy]: ...
    @policies.setter
    def policies(self, policies: list[V2HPAScalingPolicy]) -> None: ...
    @property
    def select_policy(self) -> str: ...
    @select_policy.setter
    def select_policy(self, select_policy: str) -> None: ...
    @property
    def stabilization_window_seconds(self) -> int: ...
    @stabilization_window_seconds.setter
    def stabilization_window_seconds(self, stabilization_window_seconds: int) -> None: ...
    @property
    def tolerance(self) -> str: ...
    @tolerance.setter
    def tolerance(self, tolerance: str) -> None: ...
