from kubernetes_asyncio.client.api_client import ApiClient
from typing import Any
from typing import Awaitable

class LogsApi:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def log_file_handler(self, logpath: str, **kwargs: Any) -> Awaitable[None]: ...
    def log_file_handler_with_http_info(self, logpath: str, **kwargs: Any) -> Awaitable[None]: ...
    def log_file_list_handler(self, **kwargs: Any) -> Awaitable[None]: ...
    def log_file_list_handler_with_http_info(self, **kwargs: Any) -> Awaitable[None]: ...
