from kubernetes_asyncio.client.models import V1IPBlock
from kubernetes_asyncio.client.models import V1LabelSelector
from typing import Any

class V1NetworkPolicyPeer:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, ip_block: V1IPBlock | None = None, namespace_selector: V1LabelSelector | None = None, pod_selector: V1LabelSelector | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def ip_block(self) -> V1IPBlock: ...
    @ip_block.setter
    def ip_block(self, ip_block: V1IPBlock) -> None: ...
    @property
    def namespace_selector(self) -> V1LabelSelector: ...
    @namespace_selector.setter
    def namespace_selector(self, namespace_selector: V1LabelSelector) -> None: ...
    @property
    def pod_selector(self) -> V1LabelSelector: ...
    @pod_selector.setter
    def pod_selector(self, pod_selector: V1LabelSelector) -> None: ...
