from typing import Any

class V1PodCertificateProjection:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, certificate_chain_path: str | None = None, credential_bundle_path: str | None = None, key_path: str | None = None, key_type: str | None = None, max_expiration_seconds: int | None = None, signer_name: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def certificate_chain_path(self) -> str: ...
    @certificate_chain_path.setter
    def certificate_chain_path(self, certificate_chain_path: str) -> None: ...
    @property
    def credential_bundle_path(self) -> str: ...
    @credential_bundle_path.setter
    def credential_bundle_path(self, credential_bundle_path: str) -> None: ...
    @property
    def key_path(self) -> str: ...
    @key_path.setter
    def key_path(self, key_path: str) -> None: ...
    @property
    def key_type(self) -> str: ...
    @key_type.setter
    def key_type(self, key_type: str) -> None: ...
    @property
    def max_expiration_seconds(self) -> int: ...
    @max_expiration_seconds.setter
    def max_expiration_seconds(self, max_expiration_seconds: int) -> None: ...
    @property
    def signer_name(self) -> str: ...
    @signer_name.setter
    def signer_name(self, signer_name: str) -> None: ...
