from kubernetes_asyncio.client.models import V1PodFailurePolicyOnExitCodesRequirement
from kubernetes_asyncio.client.models import V1PodFailurePolicyOnPodConditionsPattern
from typing import Any

class V1PodFailurePolicyRule:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, action: str | None = None, on_exit_codes: V1PodFailurePolicyOnExitCodesRequirement | None = None, on_pod_conditions: list[V1PodFailurePolicyOnPodConditionsPattern] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def action(self) -> str: ...
    @action.setter
    def action(self, action: str) -> None: ...
    @property
    def on_exit_codes(self) -> V1PodFailurePolicyOnExitCodesRequirement: ...
    @on_exit_codes.setter
    def on_exit_codes(self, on_exit_codes: V1PodFailurePolicyOnExitCodesRequirement) -> None: ...
    @property
    def on_pod_conditions(self) -> list[V1PodFailurePolicyOnPodConditionsPattern]: ...
    @on_pod_conditions.setter
    def on_pod_conditions(self, on_pod_conditions: list[V1PodFailurePolicyOnPodConditionsPattern]) -> None: ...
