from kubernetes_asyncio.client.models import V1ObjectMeta
from kubernetes_asyncio.client.models import V1PodSpec
from typing import Any

class V1PodTemplateSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, metadata: V1ObjectMeta | None = None, spec: V1PodSpec | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def metadata(self) -> V1ObjectMeta: ...
    @metadata.setter
    def metadata(self, metadata: V1ObjectMeta) -> None: ...
    @property
    def spec(self) -> V1PodSpec: ...
    @spec.setter
    def spec(self, spec: V1PodSpec) -> None: ...
