from kubernetes_asyncio.client.models import V1IngressServiceBackend
from kubernetes_asyncio.client.models import V1TypedLocalObjectReference
from typing import Any

class V1IngressBackend:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, resource: V1TypedLocalObjectReference | None = None, service: V1IngressServiceBackend | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def resource(self) -> V1TypedLocalObjectReference: ...
    @resource.setter
    def resource(self, resource: V1TypedLocalObjectReference) -> None: ...
    @property
    def service(self) -> V1IngressServiceBackend: ...
    @service.setter
    def service(self, service: V1IngressServiceBackend) -> None: ...
