from kubernetes_asyncio.client.models import V1VolumeProjection
from typing import Any

class V1ProjectedVolumeSource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, default_mode: int | None = None, sources: list[V1VolumeProjection] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def default_mode(self) -> int: ...
    @default_mode.setter
    def default_mode(self, default_mode: int) -> None: ...
    @property
    def sources(self) -> list[V1VolumeProjection]: ...
    @sources.setter
    def sources(self, sources: list[V1VolumeProjection]) -> None: ...
