from kubernetes_asyncio.client.models import V1NodeSelectorRequirement
from typing import Any

class V1NodeSelectorTerm:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, match_expressions: list[V1NodeSelectorRequirement] | None = None, match_fields: list[V1NodeSelectorRequirement] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def match_expressions(self) -> list[V1NodeSelectorRequirement]: ...
    @match_expressions.setter
    def match_expressions(self, match_expressions: list[V1NodeSelectorRequirement]) -> None: ...
    @property
    def match_fields(self) -> list[V1NodeSelectorRequirement]: ...
    @match_fields.setter
    def match_fields(self, match_fields: list[V1NodeSelectorRequirement]) -> None: ...
