from kubernetes_asyncio.client.models import V1PersistentVolumeSpec
from typing import Any

class V1VolumeAttachmentSource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, inline_volume_spec: V1PersistentVolumeSpec | None = None, persistent_volume_name: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def inline_volume_spec(self) -> V1PersistentVolumeSpec: ...
    @inline_volume_spec.setter
    def inline_volume_spec(self, inline_volume_spec: V1PersistentVolumeSpec) -> None: ...
    @property
    def persistent_volume_name(self) -> str: ...
    @persistent_volume_name.setter
    def persistent_volume_name(self, persistent_volume_name: str) -> None: ...
