from kubernetes_asyncio.client.models import V1IngressBackend
from kubernetes_asyncio.client.models import V1IngressRule
from kubernetes_asyncio.client.models import V1IngressTLS
from typing import Any

class V1IngressSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, default_backend: V1IngressBackend | None = None, ingress_class_name: str | None = None, rules: list[V1IngressRule] | None = None, tls: list[V1IngressTLS] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def default_backend(self) -> V1IngressBackend: ...
    @default_backend.setter
    def default_backend(self, default_backend: V1IngressBackend) -> None: ...
    @property
    def ingress_class_name(self) -> str: ...
    @ingress_class_name.setter
    def ingress_class_name(self, ingress_class_name: str) -> None: ...
    @property
    def rules(self) -> list[V1IngressRule]: ...
    @rules.setter
    def rules(self, rules: list[V1IngressRule]) -> None: ...
    @property
    def tls(self) -> list[V1IngressTLS]: ...
    @tls.setter
    def tls(self, tls: list[V1IngressTLS]) -> None: ...
