from kubernetes_asyncio.client.models import V1ScopeSelector
from typing import Any

class V1ResourceQuotaSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, hard: dict[str, str] | None = None, scope_selector: V1ScopeSelector | None = None, scopes: list[str] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def hard(self) -> dict[str, str]: ...
    @hard.setter
    def hard(self, hard: dict[str, str]) -> None: ...
    @property
    def scope_selector(self) -> V1ScopeSelector: ...
    @scope_selector.setter
    def scope_selector(self, scope_selector: V1ScopeSelector) -> None: ...
    @property
    def scopes(self) -> list[str]: ...
    @scopes.setter
    def scopes(self, scopes: list[str]) -> None: ...
