from typing import Any

class V1QuobyteVolumeSource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, group: str | None = None, read_only: bool | None = None, registry: str | None = None, tenant: str | None = None, user: str | None = None, volume: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def group(self) -> str: ...
    @group.setter
    def group(self, group: str) -> None: ...
    @property
    def read_only(self) -> bool: ...
    @read_only.setter
    def read_only(self, read_only: bool) -> None: ...
    @property
    def registry(self) -> str: ...
    @registry.setter
    def registry(self, registry: str) -> None: ...
    @property
    def tenant(self) -> str: ...
    @tenant.setter
    def tenant(self, tenant: str) -> None: ...
    @property
    def user(self) -> str: ...
    @user.setter
    def user(self, user: str) -> None: ...
    @property
    def volume(self) -> str: ...
    @volume.setter
    def volume(self, volume: str) -> None: ...
