from datetime import datetime
from kubernetes_asyncio.client.models import V1ManagedFieldsEntry
from kubernetes_asyncio.client.models import V1OwnerReference
from typing import Any

class V1ObjectMeta:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, annotations: dict[str, str] | None = None, creation_timestamp: datetime | None = None, deletion_grace_period_seconds: int | None = None, deletion_timestamp: datetime | None = None, finalizers: list[str] | None = None, generate_name: str | None = None, generation: int | None = None, labels: dict[str, str] | None = None, managed_fields: list[V1ManagedFieldsEntry] | None = None, name: str | None = None, namespace: str | None = None, owner_references: list[V1OwnerReference] | None = None, resource_version: str | None = None, self_link: str | None = None, uid: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def annotations(self) -> dict[str, str]: ...
    @annotations.setter
    def annotations(self, annotations: dict[str, str]) -> None: ...
    @property
    def creation_timestamp(self) -> datetime: ...
    @creation_timestamp.setter
    def creation_timestamp(self, creation_timestamp: datetime) -> None: ...
    @property
    def deletion_grace_period_seconds(self) -> int: ...
    @deletion_grace_period_seconds.setter
    def deletion_grace_period_seconds(self, deletion_grace_period_seconds: int) -> None: ...
    @property
    def deletion_timestamp(self) -> datetime: ...
    @deletion_timestamp.setter
    def deletion_timestamp(self, deletion_timestamp: datetime) -> None: ...
    @property
    def finalizers(self) -> list[str]: ...
    @finalizers.setter
    def finalizers(self, finalizers: list[str]) -> None: ...
    @property
    def generate_name(self) -> str: ...
    @generate_name.setter
    def generate_name(self, generate_name: str) -> None: ...
    @property
    def generation(self) -> int: ...
    @generation.setter
    def generation(self, generation: int) -> None: ...
    @property
    def labels(self) -> dict[str, str]: ...
    @labels.setter
    def labels(self, labels: dict[str, str]) -> None: ...
    @property
    def managed_fields(self) -> list[V1ManagedFieldsEntry]: ...
    @managed_fields.setter
    def managed_fields(self, managed_fields: list[V1ManagedFieldsEntry]) -> None: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
    @property
    def namespace(self) -> str: ...
    @namespace.setter
    def namespace(self, namespace: str) -> None: ...
    @property
    def owner_references(self) -> list[V1OwnerReference]: ...
    @owner_references.setter
    def owner_references(self, owner_references: list[V1OwnerReference]) -> None: ...
    @property
    def resource_version(self) -> str: ...
    @resource_version.setter
    def resource_version(self, resource_version: str) -> None: ...
    @property
    def self_link(self) -> str: ...
    @self_link.setter
    def self_link(self, self_link: str) -> None: ...
    @property
    def uid(self) -> str: ...
    @uid.setter
    def uid(self, uid: str) -> None: ...
