from kubernetes_asyncio.client.models import V1HTTPHeader
from typing import Any

class V1HTTPGetAction:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, host: str | None = None, http_headers: list[V1HTTPHeader] | None = None, path: str | None = None, port: Any | None = None, scheme: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def host(self) -> str: ...
    @host.setter
    def host(self, host: str) -> None: ...
    @property
    def http_headers(self) -> list[V1HTTPHeader]: ...
    @http_headers.setter
    def http_headers(self, http_headers: list[V1HTTPHeader]) -> None: ...
    @property
    def path(self) -> str: ...
    @path.setter
    def path(self, path: str) -> None: ...
    @property
    def port(self) -> Any: ...
    @port.setter
    def port(self, port: Any) -> None: ...
    @property
    def scheme(self) -> str: ...
    @scheme.setter
    def scheme(self, scheme: str) -> None: ...
