from typing import Any

class V1FileKeySelector:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, key: str | None = None, optional: bool | None = None, path: str | None = None, volume_name: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, key: str) -> None: ...
    @property
    def optional(self) -> bool: ...
    @optional.setter
    def optional(self, optional: bool) -> None: ...
    @property
    def path(self) -> str: ...
    @path.setter
    def path(self, path: str) -> None: ...
    @property
    def volume_name(self) -> str: ...
    @volume_name.setter
    def volume_name(self, volume_name: str) -> None: ...
