from datetime import datetime
from typing import Any

class V1LeaseSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, acquire_time: datetime | None = None, holder_identity: str | None = None, lease_duration_seconds: int | None = None, lease_transitions: int | None = None, preferred_holder: str | None = None, renew_time: datetime | None = None, strategy: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def acquire_time(self) -> datetime: ...
    @acquire_time.setter
    def acquire_time(self, acquire_time: datetime) -> None: ...
    @property
    def holder_identity(self) -> str: ...
    @holder_identity.setter
    def holder_identity(self, holder_identity: str) -> None: ...
    @property
    def lease_duration_seconds(self) -> int: ...
    @lease_duration_seconds.setter
    def lease_duration_seconds(self, lease_duration_seconds: int) -> None: ...
    @property
    def lease_transitions(self) -> int: ...
    @lease_transitions.setter
    def lease_transitions(self, lease_transitions: int) -> None: ...
    @property
    def preferred_holder(self) -> str: ...
    @preferred_holder.setter
    def preferred_holder(self, preferred_holder: str) -> None: ...
    @property
    def renew_time(self) -> datetime: ...
    @renew_time.setter
    def renew_time(self, renew_time: datetime) -> None: ...
    @property
    def strategy(self) -> str: ...
    @strategy.setter
    def strategy(self, strategy: str) -> None: ...
