from kubernetes_asyncio.client.models import V1ListMeta
from kubernetes_asyncio.client.models import V1alpha1PodCertificateRequest
from typing import Any

class V1alpha1PodCertificateRequestList:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, api_version: str | None = None, items: list[V1alpha1PodCertificateRequest] | None = None, kind: str | None = None, metadata: V1ListMeta | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def api_version(self) -> str: ...
    @api_version.setter
    def api_version(self, api_version: str) -> None: ...
    @property
    def items(self) -> list[V1alpha1PodCertificateRequest]: ...
    @items.setter
    def items(self, items: list[V1alpha1PodCertificateRequest]) -> None: ...
    @property
    def kind(self) -> str: ...
    @kind.setter
    def kind(self, kind: str) -> None: ...
    @property
    def metadata(self) -> V1ListMeta: ...
    @metadata.setter
    def metadata(self, metadata: V1ListMeta) -> None: ...
