from kubernetes_asyncio.client.models import V1ParentReference
from typing import Any

class V1IPAddressSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, parent_ref: V1ParentReference | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def parent_ref(self) -> V1ParentReference: ...
    @parent_ref.setter
    def parent_ref(self, parent_ref: V1ParentReference) -> None: ...
