from typing import Any

class V1TokenReviewSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, audiences: list[str] | None = None, token: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def audiences(self) -> list[str]: ...
    @audiences.setter
    def audiences(self, audiences: list[str]) -> None: ...
    @property
    def token(self) -> str: ...
    @token.setter
    def token(self, token: str) -> None: ...
