from kubernetes_asyncio.client.models import V1ReplicaSetCondition
from typing import Any

class V1ReplicaSetStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, available_replicas: int | None = None, conditions: list[V1ReplicaSetCondition] | None = None, fully_labeled_replicas: int | None = None, observed_generation: int | None = None, ready_replicas: int | None = None, replicas: int | None = None, terminating_replicas: int | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def available_replicas(self) -> int: ...
    @available_replicas.setter
    def available_replicas(self, available_replicas: int) -> None: ...
    @property
    def conditions(self) -> list[V1ReplicaSetCondition]: ...
    @conditions.setter
    def conditions(self, conditions: list[V1ReplicaSetCondition]) -> None: ...
    @property
    def fully_labeled_replicas(self) -> int: ...
    @fully_labeled_replicas.setter
    def fully_labeled_replicas(self, fully_labeled_replicas: int) -> None: ...
    @property
    def observed_generation(self) -> int: ...
    @observed_generation.setter
    def observed_generation(self, observed_generation: int) -> None: ...
    @property
    def ready_replicas(self) -> int: ...
    @ready_replicas.setter
    def ready_replicas(self, ready_replicas: int) -> None: ...
    @property
    def replicas(self) -> int: ...
    @replicas.setter
    def replicas(self, replicas: int) -> None: ...
    @property
    def terminating_replicas(self) -> int: ...
    @terminating_replicas.setter
    def terminating_replicas(self, terminating_replicas: int) -> None: ...
