from kubernetes_asyncio.client.models import V1ContainerStateRunning
from kubernetes_asyncio.client.models import V1ContainerStateTerminated
from kubernetes_asyncio.client.models import V1ContainerStateWaiting
from typing import Any

class V1ContainerState:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, running: V1ContainerStateRunning | None = None, terminated: V1ContainerStateTerminated | None = None, waiting: V1ContainerStateWaiting | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def running(self) -> V1ContainerStateRunning: ...
    @running.setter
    def running(self, running: V1ContainerStateRunning) -> None: ...
    @property
    def terminated(self) -> V1ContainerStateTerminated: ...
    @terminated.setter
    def terminated(self, terminated: V1ContainerStateTerminated) -> None: ...
    @property
    def waiting(self) -> V1ContainerStateWaiting: ...
    @waiting.setter
    def waiting(self, waiting: V1ContainerStateWaiting) -> None: ...
