from kubernetes_asyncio.client.models import V1beta1DeviceClassConfiguration
from kubernetes_asyncio.client.models import V1beta1DeviceSelector
from typing import Any

class V1beta1DeviceClassSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, config: list[V1beta1DeviceClassConfiguration] | None = None, extended_resource_name: str | None = None, selectors: list[V1beta1DeviceSelector] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def config(self) -> list[V1beta1DeviceClassConfiguration]: ...
    @config.setter
    def config(self, config: list[V1beta1DeviceClassConfiguration]) -> None: ...
    @property
    def extended_resource_name(self) -> str: ...
    @extended_resource_name.setter
    def extended_resource_name(self, extended_resource_name: str) -> None: ...
    @property
    def selectors(self) -> list[V1beta1DeviceSelector]: ...
    @selectors.setter
    def selectors(self, selectors: list[V1beta1DeviceSelector]) -> None: ...
