from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1CronJob
from kubernetes_asyncio.client.models import V1CronJobList
from kubernetes_asyncio.client.models import V1Job
from kubernetes_asyncio.client.models import V1JobList
from kubernetes_asyncio.client.models import V1Status
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class BatchV1Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def create_namespaced_cron_job(self, namespace: str, body: V1CronJob, **kwargs: Any) -> Awaitable[V1CronJob]: ...
    def create_namespaced_cron_job_with_http_info(self, namespace: str, body: V1CronJob, **kwargs: Any) -> Awaitable[tuple[V1CronJob, int, CIMultiDictProxy]]: ...
    def create_namespaced_job(self, namespace: str, body: V1Job, **kwargs: Any) -> Awaitable[V1Job]: ...
    def create_namespaced_job_with_http_info(self, namespace: str, body: V1Job, **kwargs: Any) -> Awaitable[tuple[V1Job, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_cron_job(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_cron_job_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_job(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_job_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_cron_job(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_cron_job_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_job(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_job_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
    def list_cron_job_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1CronJobList]: ...
    def list_cron_job_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1CronJobList, int, CIMultiDictProxy]]: ...
    def list_job_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1JobList]: ...
    def list_job_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1JobList, int, CIMultiDictProxy]]: ...
    def list_namespaced_cron_job(self, namespace: str, **kwargs: Any) -> Awaitable[V1CronJobList]: ...
    def list_namespaced_cron_job_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1CronJobList, int, CIMultiDictProxy]]: ...
    def list_namespaced_job(self, namespace: str, **kwargs: Any) -> Awaitable[V1JobList]: ...
    def list_namespaced_job_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1JobList, int, CIMultiDictProxy]]: ...
    def patch_namespaced_cron_job(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1CronJob]: ...
    def patch_namespaced_cron_job_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1CronJob]: ...
    def patch_namespaced_cron_job_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1CronJob, int, CIMultiDictProxy]]: ...
    def patch_namespaced_cron_job_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1CronJob, int, CIMultiDictProxy]]: ...
    def patch_namespaced_job(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Job]: ...
    def patch_namespaced_job_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Job]: ...
    def patch_namespaced_job_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Job, int, CIMultiDictProxy]]: ...
    def patch_namespaced_job_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Job, int, CIMultiDictProxy]]: ...
    def read_namespaced_cron_job(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1CronJob]: ...
    def read_namespaced_cron_job_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1CronJob]: ...
    def read_namespaced_cron_job_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1CronJob, int, CIMultiDictProxy]]: ...
    def read_namespaced_cron_job_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1CronJob, int, CIMultiDictProxy]]: ...
    def read_namespaced_job(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Job]: ...
    def read_namespaced_job_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Job]: ...
    def read_namespaced_job_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Job, int, CIMultiDictProxy]]: ...
    def read_namespaced_job_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Job, int, CIMultiDictProxy]]: ...
    def replace_namespaced_cron_job(self, name: str, namespace: str, body: V1CronJob, **kwargs: Any) -> Awaitable[V1CronJob]: ...
    def replace_namespaced_cron_job_status(self, name: str, namespace: str, body: V1CronJob, **kwargs: Any) -> Awaitable[V1CronJob]: ...
    def replace_namespaced_cron_job_status_with_http_info(self, name: str, namespace: str, body: V1CronJob, **kwargs: Any) -> Awaitable[tuple[V1CronJob, int, CIMultiDictProxy]]: ...
    def replace_namespaced_cron_job_with_http_info(self, name: str, namespace: str, body: V1CronJob, **kwargs: Any) -> Awaitable[tuple[V1CronJob, int, CIMultiDictProxy]]: ...
    def replace_namespaced_job(self, name: str, namespace: str, body: V1Job, **kwargs: Any) -> Awaitable[V1Job]: ...
    def replace_namespaced_job_status(self, name: str, namespace: str, body: V1Job, **kwargs: Any) -> Awaitable[V1Job]: ...
    def replace_namespaced_job_status_with_http_info(self, name: str, namespace: str, body: V1Job, **kwargs: Any) -> Awaitable[tuple[V1Job, int, CIMultiDictProxy]]: ...
    def replace_namespaced_job_with_http_info(self, name: str, namespace: str, body: V1Job, **kwargs: Any) -> Awaitable[tuple[V1Job, int, CIMultiDictProxy]]: ...
