from datetime import datetime
from typing import Any

class V1ManagedFieldsEntry:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, api_version: str | None = None, fields_type: str | None = None, fields_v1: Any | None = None, manager: str | None = None, operation: str | None = None, subresource: str | None = None, time: datetime | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def api_version(self) -> str: ...
    @api_version.setter
    def api_version(self, api_version: str) -> None: ...
    @property
    def fields_type(self) -> str: ...
    @fields_type.setter
    def fields_type(self, fields_type: str) -> None: ...
    @property
    def fields_v1(self) -> Any: ...
    @fields_v1.setter
    def fields_v1(self, fields_v1: Any) -> None: ...
    @property
    def manager(self) -> str: ...
    @manager.setter
    def manager(self, manager: str) -> None: ...
    @property
    def operation(self) -> str: ...
    @operation.setter
    def operation(self, operation: str) -> None: ...
    @property
    def subresource(self) -> str: ...
    @subresource.setter
    def subresource(self, subresource: str) -> None: ...
    @property
    def time(self) -> datetime: ...
    @time.setter
    def time(self, time: datetime) -> None: ...
