from datetime import datetime
from kubernetes_asyncio.client.models import V1ContainerStatus
from kubernetes_asyncio.client.models import V1HostIP
from kubernetes_asyncio.client.models import V1PodCondition
from kubernetes_asyncio.client.models import V1PodExtendedResourceClaimStatus
from kubernetes_asyncio.client.models import V1PodIP
from kubernetes_asyncio.client.models import V1PodResourceClaimStatus
from typing import Any

class V1PodStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, conditions: list[V1PodCondition] | None = None, container_statuses: list[V1ContainerStatus] | None = None, ephemeral_container_statuses: list[V1ContainerStatus] | None = None, extended_resource_claim_status: V1PodExtendedResourceClaimStatus | None = None, host_ip: str | None = None, host_ips: list[V1HostIP] | None = None, init_container_statuses: list[V1ContainerStatus] | None = None, message: str | None = None, nominated_node_name: str | None = None, observed_generation: int | None = None, phase: str | None = None, pod_ip: str | None = None, pod_ips: list[V1PodIP] | None = None, qos_class: str | None = None, reason: str | None = None, resize: str | None = None, resource_claim_statuses: list[V1PodResourceClaimStatus] | None = None, start_time: datetime | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def conditions(self) -> list[V1PodCondition]: ...
    @conditions.setter
    def conditions(self, conditions: list[V1PodCondition]) -> None: ...
    @property
    def container_statuses(self) -> list[V1ContainerStatus]: ...
    @container_statuses.setter
    def container_statuses(self, container_statuses: list[V1ContainerStatus]) -> None: ...
    @property
    def ephemeral_container_statuses(self) -> list[V1ContainerStatus]: ...
    @ephemeral_container_statuses.setter
    def ephemeral_container_statuses(self, ephemeral_container_statuses: list[V1ContainerStatus]) -> None: ...
    @property
    def extended_resource_claim_status(self) -> V1PodExtendedResourceClaimStatus: ...
    @extended_resource_claim_status.setter
    def extended_resource_claim_status(self, extended_resource_claim_status: V1PodExtendedResourceClaimStatus) -> None: ...
    @property
    def host_ip(self) -> str: ...
    @host_ip.setter
    def host_ip(self, host_ip: str) -> None: ...
    @property
    def host_ips(self) -> list[V1HostIP]: ...
    @host_ips.setter
    def host_ips(self, host_ips: list[V1HostIP]) -> None: ...
    @property
    def init_container_statuses(self) -> list[V1ContainerStatus]: ...
    @init_container_statuses.setter
    def init_container_statuses(self, init_container_statuses: list[V1ContainerStatus]) -> None: ...
    @property
    def message(self) -> str: ...
    @message.setter
    def message(self, message: str) -> None: ...
    @property
    def nominated_node_name(self) -> str: ...
    @nominated_node_name.setter
    def nominated_node_name(self, nominated_node_name: str) -> None: ...
    @property
    def observed_generation(self) -> int: ...
    @observed_generation.setter
    def observed_generation(self, observed_generation: int) -> None: ...
    @property
    def phase(self) -> str: ...
    @phase.setter
    def phase(self, phase: str) -> None: ...
    @property
    def pod_ip(self) -> str: ...
    @pod_ip.setter
    def pod_ip(self, pod_ip: str) -> None: ...
    @property
    def pod_ips(self) -> list[V1PodIP]: ...
    @pod_ips.setter
    def pod_ips(self, pod_ips: list[V1PodIP]) -> None: ...
    @property
    def qos_class(self) -> str: ...
    @qos_class.setter
    def qos_class(self, qos_class: str) -> None: ...
    @property
    def reason(self) -> str: ...
    @reason.setter
    def reason(self, reason: str) -> None: ...
    @property
    def resize(self) -> str: ...
    @resize.setter
    def resize(self, resize: str) -> None: ...
    @property
    def resource_claim_statuses(self) -> list[V1PodResourceClaimStatus]: ...
    @resource_claim_statuses.setter
    def resource_claim_statuses(self, resource_claim_statuses: list[V1PodResourceClaimStatus]) -> None: ...
    @property
    def start_time(self) -> datetime: ...
    @start_time.setter
    def start_time(self, start_time: datetime) -> None: ...
