from kubernetes_asyncio.client.models import V1NonResourceAttributes
from kubernetes_asyncio.client.models import V1ResourceAttributes
from typing import Any

class V1SubjectAccessReviewSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, extra: dict[str, list[str]] | None = None, groups: list[str] | None = None, non_resource_attributes: V1NonResourceAttributes | None = None, resource_attributes: V1ResourceAttributes | None = None, uid: str | None = None, user: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def extra(self) -> dict[str, list[str]]: ...
    @extra.setter
    def extra(self, extra: dict[str, list[str]]) -> None: ...
    @property
    def groups(self) -> list[str]: ...
    @groups.setter
    def groups(self, groups: list[str]) -> None: ...
    @property
    def non_resource_attributes(self) -> V1NonResourceAttributes: ...
    @non_resource_attributes.setter
    def non_resource_attributes(self, non_resource_attributes: V1NonResourceAttributes) -> None: ...
    @property
    def resource_attributes(self) -> V1ResourceAttributes: ...
    @resource_attributes.setter
    def resource_attributes(self, resource_attributes: V1ResourceAttributes) -> None: ...
    @property
    def uid(self) -> str: ...
    @uid.setter
    def uid(self, uid: str) -> None: ...
    @property
    def user(self) -> str: ...
    @user.setter
    def user(self, user: str) -> None: ...
