from typing import Any

class V1beta2CapacityRequestPolicyRange:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, max: str | None = None, min: str | None = None, step: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def max(self) -> str: ...
    @max.setter
    def max(self, max: str) -> None: ...
    @property
    def min(self) -> str: ...
    @min.setter
    def min(self, min: str) -> None: ...
    @property
    def step(self) -> str: ...
    @step.setter
    def step(self, step: str) -> None: ...
