from kubernetes_asyncio.client.models import V1LifecycleHandler
from typing import Any

class V1Lifecycle:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, post_start: V1LifecycleHandler | None = None, pre_stop: V1LifecycleHandler | None = None, stop_signal: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def post_start(self) -> V1LifecycleHandler: ...
    @post_start.setter
    def post_start(self, post_start: V1LifecycleHandler) -> None: ...
    @property
    def pre_stop(self) -> V1LifecycleHandler: ...
    @pre_stop.setter
    def pre_stop(self, pre_stop: V1LifecycleHandler) -> None: ...
    @property
    def stop_signal(self) -> str: ...
    @stop_signal.setter
    def stop_signal(self, stop_signal: str) -> None: ...
