from typing import Any

class V1FieldSelectorRequirement:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, key: str | None = None, operator: str | None = None, values: list[str] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, key: str) -> None: ...
    @property
    def operator(self) -> str: ...
    @operator.setter
    def operator(self, operator: str) -> None: ...
    @property
    def values(self) -> list[str]: ...
    @values.setter
    def values(self, values: list[str]) -> None: ...
