from kubernetes_asyncio.client.models import V1ObjectReference
from typing import Any

class V1StorageOSPersistentVolumeSource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, fs_type: str | None = None, read_only: bool | None = None, secret_ref: V1ObjectReference | None = None, volume_name: str | None = None, volume_namespace: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def fs_type(self) -> str: ...
    @fs_type.setter
    def fs_type(self, fs_type: str) -> None: ...
    @property
    def read_only(self) -> bool: ...
    @read_only.setter
    def read_only(self, read_only: bool) -> None: ...
    @property
    def secret_ref(self) -> V1ObjectReference: ...
    @secret_ref.setter
    def secret_ref(self, secret_ref: V1ObjectReference) -> None: ...
    @property
    def volume_name(self) -> str: ...
    @volume_name.setter
    def volume_name(self, volume_name: str) -> None: ...
    @property
    def volume_namespace(self) -> str: ...
    @volume_namespace.setter
    def volume_namespace(self, volume_namespace: str) -> None: ...
