from kubernetes_asyncio.client.models import ApiextensionsV1ServiceReference
from typing import Any

class ApiextensionsV1WebhookClientConfig:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, ca_bundle: str | None = None, service: ApiextensionsV1ServiceReference | None = None, url: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def ca_bundle(self) -> str: ...
    @ca_bundle.setter
    def ca_bundle(self, ca_bundle: str) -> None: ...
    @property
    def service(self) -> ApiextensionsV1ServiceReference: ...
    @service.setter
    def service(self, service: ApiextensionsV1ServiceReference) -> None: ...
    @property
    def url(self) -> str: ...
    @url.setter
    def url(self, url: str) -> None: ...
