from kubernetes_asyncio.client.models import V1Preconditions
from typing import Any

class V1DeleteOptions:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, api_version: str | None = None, dry_run: list[str] | None = None, grace_period_seconds: int | None = None, ignore_store_read_error_with_cluster_breaking_potential: bool | None = None, kind: str | None = None, orphan_dependents: bool | None = None, preconditions: V1Preconditions | None = None, propagation_policy: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def api_version(self) -> str: ...
    @api_version.setter
    def api_version(self, api_version: str) -> None: ...
    @property
    def dry_run(self) -> list[str]: ...
    @dry_run.setter
    def dry_run(self, dry_run: list[str]) -> None: ...
    @property
    def grace_period_seconds(self) -> int: ...
    @grace_period_seconds.setter
    def grace_period_seconds(self, grace_period_seconds: int) -> None: ...
    @property
    def ignore_store_read_error_with_cluster_breaking_potential(self) -> bool: ...
    @ignore_store_read_error_with_cluster_breaking_potential.setter
    def ignore_store_read_error_with_cluster_breaking_potential(self, ignore_store_read_error_with_cluster_breaking_potential: bool) -> None: ...
    @property
    def kind(self) -> str: ...
    @kind.setter
    def kind(self, kind: str) -> None: ...
    @property
    def orphan_dependents(self) -> bool: ...
    @orphan_dependents.setter
    def orphan_dependents(self, orphan_dependents: bool) -> None: ...
    @property
    def preconditions(self) -> V1Preconditions: ...
    @preconditions.setter
    def preconditions(self, preconditions: V1Preconditions) -> None: ...
    @property
    def propagation_policy(self) -> str: ...
    @propagation_policy.setter
    def propagation_policy(self, propagation_policy: str) -> None: ...
