from kubernetes_asyncio.client.models import V1FieldSelectorAttributes
from kubernetes_asyncio.client.models import V1LabelSelectorAttributes
from typing import Any

class V1ResourceAttributes:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, field_selector: V1FieldSelectorAttributes | None = None, group: str | None = None, label_selector: V1LabelSelectorAttributes | None = None, name: str | None = None, namespace: str | None = None, resource: str | None = None, subresource: str | None = None, verb: str | None = None, version: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def field_selector(self) -> V1FieldSelectorAttributes: ...
    @field_selector.setter
    def field_selector(self, field_selector: V1FieldSelectorAttributes) -> None: ...
    @property
    def group(self) -> str: ...
    @group.setter
    def group(self, group: str) -> None: ...
    @property
    def label_selector(self) -> V1LabelSelectorAttributes: ...
    @label_selector.setter
    def label_selector(self, label_selector: V1LabelSelectorAttributes) -> None: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
    @property
    def namespace(self) -> str: ...
    @namespace.setter
    def namespace(self, namespace: str) -> None: ...
    @property
    def resource(self) -> str: ...
    @resource.setter
    def resource(self, resource: str) -> None: ...
    @property
    def subresource(self) -> str: ...
    @subresource.setter
    def subresource(self, subresource: str) -> None: ...
    @property
    def verb(self) -> str: ...
    @verb.setter
    def verb(self, verb: str) -> None: ...
    @property
    def version(self) -> str: ...
    @version.setter
    def version(self, version: str) -> None: ...
