from kubernetes_asyncio.client.models import V1JobTemplateSpec
from typing import Any

class V1CronJobSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, concurrency_policy: str | None = None, failed_jobs_history_limit: int | None = None, job_template: V1JobTemplateSpec | None = None, schedule: str | None = None, starting_deadline_seconds: int | None = None, successful_jobs_history_limit: int | None = None, suspend: bool | None = None, time_zone: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def concurrency_policy(self) -> str: ...
    @concurrency_policy.setter
    def concurrency_policy(self, concurrency_policy: str) -> None: ...
    @property
    def failed_jobs_history_limit(self) -> int: ...
    @failed_jobs_history_limit.setter
    def failed_jobs_history_limit(self, failed_jobs_history_limit: int) -> None: ...
    @property
    def job_template(self) -> V1JobTemplateSpec: ...
    @job_template.setter
    def job_template(self, job_template: V1JobTemplateSpec) -> None: ...
    @property
    def schedule(self) -> str: ...
    @schedule.setter
    def schedule(self, schedule: str) -> None: ...
    @property
    def starting_deadline_seconds(self) -> int: ...
    @starting_deadline_seconds.setter
    def starting_deadline_seconds(self, starting_deadline_seconds: int) -> None: ...
    @property
    def successful_jobs_history_limit(self) -> int: ...
    @successful_jobs_history_limit.setter
    def successful_jobs_history_limit(self, successful_jobs_history_limit: int) -> None: ...
    @property
    def suspend(self) -> bool: ...
    @suspend.setter
    def suspend(self, suspend: bool) -> None: ...
    @property
    def time_zone(self) -> str: ...
    @time_zone.setter
    def time_zone(self, time_zone: str) -> None: ...
