from kubernetes_asyncio.client.models import V1beta2DeviceToleration
from typing import Any

class V1beta2DeviceRequestAllocationResult:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, admin_access: bool | None = None, binding_conditions: list[str] | None = None, binding_failure_conditions: list[str] | None = None, consumed_capacity: dict[str, str] | None = None, device: str | None = None, driver: str | None = None, pool: str | None = None, request: str | None = None, share_id: str | None = None, tolerations: list[V1beta2DeviceToleration] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def admin_access(self) -> bool: ...
    @admin_access.setter
    def admin_access(self, admin_access: bool) -> None: ...
    @property
    def binding_conditions(self) -> list[str]: ...
    @binding_conditions.setter
    def binding_conditions(self, binding_conditions: list[str]) -> None: ...
    @property
    def binding_failure_conditions(self) -> list[str]: ...
    @binding_failure_conditions.setter
    def binding_failure_conditions(self, binding_failure_conditions: list[str]) -> None: ...
    @property
    def consumed_capacity(self) -> dict[str, str]: ...
    @consumed_capacity.setter
    def consumed_capacity(self, consumed_capacity: dict[str, str]) -> None: ...
    @property
    def device(self) -> str: ...
    @device.setter
    def device(self, device: str) -> None: ...
    @property
    def driver(self) -> str: ...
    @driver.setter
    def driver(self, driver: str) -> None: ...
    @property
    def pool(self) -> str: ...
    @pool.setter
    def pool(self, pool: str) -> None: ...
    @property
    def request(self) -> str: ...
    @request.setter
    def request(self, request: str) -> None: ...
    @property
    def share_id(self) -> str: ...
    @share_id.setter
    def share_id(self, share_id: str) -> None: ...
    @property
    def tolerations(self) -> list[V1beta2DeviceToleration]: ...
    @tolerations.setter
    def tolerations(self, tolerations: list[V1beta2DeviceToleration]) -> None: ...
