from datetime import datetime
from typing import Any

class V1alpha2LeaseCandidateSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, binary_version: str | None = None, emulation_version: str | None = None, lease_name: str | None = None, ping_time: datetime | None = None, renew_time: datetime | None = None, strategy: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def binary_version(self) -> str: ...
    @binary_version.setter
    def binary_version(self, binary_version: str) -> None: ...
    @property
    def emulation_version(self) -> str: ...
    @emulation_version.setter
    def emulation_version(self, emulation_version: str) -> None: ...
    @property
    def lease_name(self) -> str: ...
    @lease_name.setter
    def lease_name(self, lease_name: str) -> None: ...
    @property
    def ping_time(self) -> datetime: ...
    @ping_time.setter
    def ping_time(self, ping_time: datetime) -> None: ...
    @property
    def renew_time(self) -> datetime: ...
    @renew_time.setter
    def renew_time(self, renew_time: datetime) -> None: ...
    @property
    def strategy(self) -> str: ...
    @strategy.setter
    def strategy(self, strategy: str) -> None: ...
