from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1APIService
from kubernetes_asyncio.client.models import V1APIServiceList
from kubernetes_asyncio.client.models import V1Status
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class ApiregistrationV1Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def create_api_service(self, body: V1APIService, **kwargs: Any) -> Awaitable[V1APIService]: ...
    def create_api_service_with_http_info(self, body: V1APIService, **kwargs: Any) -> Awaitable[tuple[V1APIService, int, CIMultiDictProxy]]: ...
    def delete_api_service(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_api_service_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_api_service(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_api_service_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
    def list_api_service(self, **kwargs: Any) -> Awaitable[V1APIServiceList]: ...
    def list_api_service_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIServiceList, int, CIMultiDictProxy]]: ...
    def patch_api_service(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1APIService]: ...
    def patch_api_service_status(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1APIService]: ...
    def patch_api_service_status_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1APIService, int, CIMultiDictProxy]]: ...
    def patch_api_service_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1APIService, int, CIMultiDictProxy]]: ...
    def read_api_service(self, name: str, **kwargs: Any) -> Awaitable[V1APIService]: ...
    def read_api_service_status(self, name: str, **kwargs: Any) -> Awaitable[V1APIService]: ...
    def read_api_service_status_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1APIService, int, CIMultiDictProxy]]: ...
    def read_api_service_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1APIService, int, CIMultiDictProxy]]: ...
    def replace_api_service(self, name: str, body: V1APIService, **kwargs: Any) -> Awaitable[V1APIService]: ...
    def replace_api_service_status(self, name: str, body: V1APIService, **kwargs: Any) -> Awaitable[V1APIService]: ...
    def replace_api_service_status_with_http_info(self, name: str, body: V1APIService, **kwargs: Any) -> Awaitable[tuple[V1APIService, int, CIMultiDictProxy]]: ...
    def replace_api_service_with_http_info(self, name: str, body: V1APIService, **kwargs: Any) -> Awaitable[tuple[V1APIService, int, CIMultiDictProxy]]: ...
