from typing import Any

class V1NonResourceAttributes:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, path: str | None = None, verb: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def path(self) -> str: ...
    @path.setter
    def path(self, path: str) -> None: ...
    @property
    def verb(self) -> str: ...
    @verb.setter
    def verb(self, verb: str) -> None: ...
