from kubernetes_asyncio.client.models import V1LocalObjectReference
from typing import Any

class V1ISCSIVolumeSource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, chap_auth_discovery: bool | None = None, chap_auth_session: bool | None = None, fs_type: str | None = None, initiator_name: str | None = None, iqn: str | None = None, iscsi_interface: str | None = None, lun: int | None = None, portals: list[str] | None = None, read_only: bool | None = None, secret_ref: V1LocalObjectReference | None = None, target_portal: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def chap_auth_discovery(self) -> bool: ...
    @chap_auth_discovery.setter
    def chap_auth_discovery(self, chap_auth_discovery: bool) -> None: ...
    @property
    def chap_auth_session(self) -> bool: ...
    @chap_auth_session.setter
    def chap_auth_session(self, chap_auth_session: bool) -> None: ...
    @property
    def fs_type(self) -> str: ...
    @fs_type.setter
    def fs_type(self, fs_type: str) -> None: ...
    @property
    def initiator_name(self) -> str: ...
    @initiator_name.setter
    def initiator_name(self, initiator_name: str) -> None: ...
    @property
    def iqn(self) -> str: ...
    @iqn.setter
    def iqn(self, iqn: str) -> None: ...
    @property
    def iscsi_interface(self) -> str: ...
    @iscsi_interface.setter
    def iscsi_interface(self, iscsi_interface: str) -> None: ...
    @property
    def lun(self) -> int: ...
    @lun.setter
    def lun(self, lun: int) -> None: ...
    @property
    def portals(self) -> list[str]: ...
    @portals.setter
    def portals(self, portals: list[str]) -> None: ...
    @property
    def read_only(self) -> bool: ...
    @read_only.setter
    def read_only(self, read_only: bool) -> None: ...
    @property
    def secret_ref(self) -> V1LocalObjectReference: ...
    @secret_ref.setter
    def secret_ref(self, secret_ref: V1LocalObjectReference) -> None: ...
    @property
    def target_portal(self) -> str: ...
    @target_portal.setter
    def target_portal(self, target_portal: str) -> None: ...
