from typing import Any

class V1APIResource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, categories: list[str] | None = None, group: str | None = None, kind: str | None = None, name: str | None = None, namespaced: bool | None = None, short_names: list[str] | None = None, singular_name: str | None = None, storage_version_hash: str | None = None, verbs: list[str] | None = None, version: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def categories(self) -> list[str]: ...
    @categories.setter
    def categories(self, categories: list[str]) -> None: ...
    @property
    def group(self) -> str: ...
    @group.setter
    def group(self, group: str) -> None: ...
    @property
    def kind(self) -> str: ...
    @kind.setter
    def kind(self, kind: str) -> None: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
    @property
    def namespaced(self) -> bool: ...
    @namespaced.setter
    def namespaced(self, namespaced: bool) -> None: ...
    @property
    def short_names(self) -> list[str]: ...
    @short_names.setter
    def short_names(self, short_names: list[str]) -> None: ...
    @property
    def singular_name(self) -> str: ...
    @singular_name.setter
    def singular_name(self, singular_name: str) -> None: ...
    @property
    def storage_version_hash(self) -> str: ...
    @storage_version_hash.setter
    def storage_version_hash(self, storage_version_hash: str) -> None: ...
    @property
    def verbs(self) -> list[str]: ...
    @verbs.setter
    def verbs(self, verbs: list[str]) -> None: ...
    @property
    def version(self) -> str: ...
    @version.setter
    def version(self, version: str) -> None: ...
