from kubernetes_asyncio.client.models import V1SecretReference
from typing import Any

class V1CephFSPersistentVolumeSource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, monitors: list[str] | None = None, path: str | None = None, read_only: bool | None = None, secret_file: str | None = None, secret_ref: V1SecretReference | None = None, user: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def monitors(self) -> list[str]: ...
    @monitors.setter
    def monitors(self, monitors: list[str]) -> None: ...
    @property
    def path(self) -> str: ...
    @path.setter
    def path(self, path: str) -> None: ...
    @property
    def read_only(self) -> bool: ...
    @read_only.setter
    def read_only(self, read_only: bool) -> None: ...
    @property
    def secret_file(self) -> str: ...
    @secret_file.setter
    def secret_file(self, secret_file: str) -> None: ...
    @property
    def secret_ref(self) -> V1SecretReference: ...
    @secret_ref.setter
    def secret_ref(self, secret_ref: V1SecretReference) -> None: ...
    @property
    def user(self) -> str: ...
    @user.setter
    def user(self, user: str) -> None: ...
