from kubernetes_asyncio.client.models import V1beta2Counter
from typing import Any

class V1beta2DeviceCounterConsumption:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, counter_set: str | None = None, counters: dict[str, V1beta2Counter] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def counter_set(self) -> str: ...
    @counter_set.setter
    def counter_set(self, counter_set: str) -> None: ...
    @property
    def counters(self) -> dict[str, V1beta2Counter]: ...
    @counters.setter
    def counters(self, counters: dict[str, V1beta2Counter]) -> None: ...
