from kubernetes_asyncio.client.models import V1CustomResourceColumnDefinition
from kubernetes_asyncio.client.models import V1CustomResourceSubresources
from kubernetes_asyncio.client.models import V1CustomResourceValidation
from kubernetes_asyncio.client.models import V1SelectableField
from typing import Any

class V1CustomResourceDefinitionVersion:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, additional_printer_columns: list[V1CustomResourceColumnDefinition] | None = None, deprecated: bool | None = None, deprecation_warning: str | None = None, name: str | None = None, schema: V1CustomResourceValidation | None = None, selectable_fields: list[V1SelectableField] | None = None, served: bool | None = None, storage: bool | None = None, subresources: V1CustomResourceSubresources | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def additional_printer_columns(self) -> list[V1CustomResourceColumnDefinition]: ...
    @additional_printer_columns.setter
    def additional_printer_columns(self, additional_printer_columns: list[V1CustomResourceColumnDefinition]) -> None: ...
    @property
    def deprecated(self) -> bool: ...
    @deprecated.setter
    def deprecated(self, deprecated: bool) -> None: ...
    @property
    def deprecation_warning(self) -> str: ...
    @deprecation_warning.setter
    def deprecation_warning(self, deprecation_warning: str) -> None: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
    @property
    def schema(self) -> V1CustomResourceValidation: ...
    @schema.setter
    def schema(self, schema: V1CustomResourceValidation) -> None: ...
    @property
    def selectable_fields(self) -> list[V1SelectableField]: ...
    @selectable_fields.setter
    def selectable_fields(self, selectable_fields: list[V1SelectableField]) -> None: ...
    @property
    def served(self) -> bool: ...
    @served.setter
    def served(self, served: bool) -> None: ...
    @property
    def storage(self) -> bool: ...
    @storage.setter
    def storage(self, storage: bool) -> None: ...
    @property
    def subresources(self) -> V1CustomResourceSubresources: ...
    @subresources.setter
    def subresources(self, subresources: V1CustomResourceSubresources) -> None: ...
