from datetime import datetime
from kubernetes_asyncio.client.models import V1JobCondition
from kubernetes_asyncio.client.models import V1UncountedTerminatedPods
from typing import Any

class V1JobStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, active: int | None = None, completed_indexes: str | None = None, completion_time: datetime | None = None, conditions: list[V1JobCondition] | None = None, failed: int | None = None, failed_indexes: str | None = None, ready: int | None = None, start_time: datetime | None = None, succeeded: int | None = None, terminating: int | None = None, uncounted_terminated_pods: V1UncountedTerminatedPods | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def active(self) -> int: ...
    @active.setter
    def active(self, active: int) -> None: ...
    @property
    def completed_indexes(self) -> str: ...
    @completed_indexes.setter
    def completed_indexes(self, completed_indexes: str) -> None: ...
    @property
    def completion_time(self) -> datetime: ...
    @completion_time.setter
    def completion_time(self, completion_time: datetime) -> None: ...
    @property
    def conditions(self) -> list[V1JobCondition]: ...
    @conditions.setter
    def conditions(self, conditions: list[V1JobCondition]) -> None: ...
    @property
    def failed(self) -> int: ...
    @failed.setter
    def failed(self, failed: int) -> None: ...
    @property
    def failed_indexes(self) -> str: ...
    @failed_indexes.setter
    def failed_indexes(self, failed_indexes: str) -> None: ...
    @property
    def ready(self) -> int: ...
    @ready.setter
    def ready(self, ready: int) -> None: ...
    @property
    def start_time(self) -> datetime: ...
    @start_time.setter
    def start_time(self, start_time: datetime) -> None: ...
    @property
    def succeeded(self) -> int: ...
    @succeeded.setter
    def succeeded(self, succeeded: int) -> None: ...
    @property
    def terminating(self) -> int: ...
    @terminating.setter
    def terminating(self, terminating: int) -> None: ...
    @property
    def uncounted_terminated_pods(self) -> V1UncountedTerminatedPods: ...
    @uncounted_terminated_pods.setter
    def uncounted_terminated_pods(self, uncounted_terminated_pods: V1UncountedTerminatedPods) -> None: ...
