from typing import Any

class V1PodFailurePolicyOnExitCodesRequirement:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, container_name: str | None = None, operator: str | None = None, values: list[int] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def container_name(self) -> str: ...
    @container_name.setter
    def container_name(self, container_name: str) -> None: ...
    @property
    def operator(self) -> str: ...
    @operator.setter
    def operator(self, operator: str) -> None: ...
    @property
    def values(self) -> list[int]: ...
    @values.setter
    def values(self, values: list[int]) -> None: ...
