from kubernetes_asyncio.client.models import V1NodeConfigSource
from typing import Any

class V1NodeConfigStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, active: V1NodeConfigSource | None = None, assigned: V1NodeConfigSource | None = None, error: str | None = None, last_known_good: V1NodeConfigSource | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def active(self) -> V1NodeConfigSource: ...
    @active.setter
    def active(self, active: V1NodeConfigSource) -> None: ...
    @property
    def assigned(self) -> V1NodeConfigSource: ...
    @assigned.setter
    def assigned(self, assigned: V1NodeConfigSource) -> None: ...
    @property
    def error(self) -> str: ...
    @error.setter
    def error(self, error: str) -> None: ...
    @property
    def last_known_good(self) -> V1NodeConfigSource: ...
    @last_known_good.setter
    def last_known_good(self, last_known_good: V1NodeConfigSource) -> None: ...
