from kubernetes_asyncio.client.models import V1NetworkPolicyPeer
from kubernetes_asyncio.client.models import V1NetworkPolicyPort
from typing import Any

class V1NetworkPolicyIngressRule:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, _from: list[V1NetworkPolicyPeer] | None = None, ports: list[V1NetworkPolicyPort] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def _from(self) -> list[V1NetworkPolicyPeer]: ...
    @_from.setter
    def _from(self, _from: list[V1NetworkPolicyPeer]) -> None: ...
    @property
    def ports(self) -> list[V1NetworkPolicyPort]: ...
    @ports.setter
    def ports(self, ports: list[V1NetworkPolicyPort]) -> None: ...
