from kubernetes_asyncio.client.models import V2MetricIdentifier
from kubernetes_asyncio.client.models import V2MetricValueStatus
from typing import Any

class V2PodsMetricStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, current: V2MetricValueStatus | None = None, metric: V2MetricIdentifier | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def current(self) -> V2MetricValueStatus: ...
    @current.setter
    def current(self, current: V2MetricValueStatus) -> None: ...
    @property
    def metric(self) -> V2MetricIdentifier: ...
    @metric.setter
    def metric(self, metric: V2MetricIdentifier) -> None: ...
