from typing import Any

class V1LimitRangeItem:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, default: dict[str, str] | None = None, default_request: dict[str, str] | None = None, max: dict[str, str] | None = None, max_limit_request_ratio: dict[str, str] | None = None, min: dict[str, str] | None = None, type: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def default(self) -> dict[str, str]: ...
    @default.setter
    def default(self, default: dict[str, str]) -> None: ...
    @property
    def default_request(self) -> dict[str, str]: ...
    @default_request.setter
    def default_request(self, default_request: dict[str, str]) -> None: ...
    @property
    def max(self) -> dict[str, str]: ...
    @max.setter
    def max(self, max: dict[str, str]) -> None: ...
    @property
    def max_limit_request_ratio(self) -> dict[str, str]: ...
    @max_limit_request_ratio.setter
    def max_limit_request_ratio(self, max_limit_request_ratio: dict[str, str]) -> None: ...
    @property
    def min(self) -> dict[str, str]: ...
    @min.setter
    def min(self, min: dict[str, str]) -> None: ...
    @property
    def type(self) -> str: ...
    @type.setter
    def type(self, type: str) -> None: ...
