from kubernetes_asyncio.client.models import V1NodeSelectorTerm
from typing import Any

class V1PreferredSchedulingTerm:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, preference: V1NodeSelectorTerm | None = None, weight: int | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def preference(self) -> V1NodeSelectorTerm: ...
    @preference.setter
    def preference(self, preference: V1NodeSelectorTerm) -> None: ...
    @property
    def weight(self) -> int: ...
    @weight.setter
    def weight(self, weight: int) -> None: ...
