from kubernetes_asyncio.client.models import V1alpha1GroupVersionResource
from typing import Any

class V1alpha1StorageVersionMigrationSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, continue_token: str | None = None, resource: V1alpha1GroupVersionResource | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def continue_token(self) -> str: ...
    @continue_token.setter
    def continue_token(self, continue_token: str) -> None: ...
    @property
    def resource(self) -> V1alpha1GroupVersionResource: ...
    @resource.setter
    def resource(self, resource: V1alpha1GroupVersionResource) -> None: ...
