from kubernetes_asyncio.client.models import ApiextensionsV1WebhookClientConfig
from typing import Any

class V1WebhookConversion:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, client_config: ApiextensionsV1WebhookClientConfig | None = None, conversion_review_versions: list[str] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def client_config(self) -> ApiextensionsV1WebhookClientConfig: ...
    @client_config.setter
    def client_config(self, client_config: ApiextensionsV1WebhookClientConfig) -> None: ...
    @property
    def conversion_review_versions(self) -> list[str]: ...
    @conversion_review_versions.setter
    def conversion_review_versions(self, conversion_review_versions: list[str]) -> None: ...
