from kubernetes_asyncio.client.models import V1ClusterTrustBundleProjection
from kubernetes_asyncio.client.models import V1ConfigMapProjection
from kubernetes_asyncio.client.models import V1DownwardAPIProjection
from kubernetes_asyncio.client.models import V1PodCertificateProjection
from kubernetes_asyncio.client.models import V1SecretProjection
from kubernetes_asyncio.client.models import V1ServiceAccountTokenProjection
from typing import Any

class V1VolumeProjection:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, cluster_trust_bundle: V1ClusterTrustBundleProjection | None = None, config_map: V1ConfigMapProjection | None = None, downward_api: V1DownwardAPIProjection | None = None, pod_certificate: V1PodCertificateProjection | None = None, secret: V1SecretProjection | None = None, service_account_token: V1ServiceAccountTokenProjection | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def cluster_trust_bundle(self) -> V1ClusterTrustBundleProjection: ...
    @cluster_trust_bundle.setter
    def cluster_trust_bundle(self, cluster_trust_bundle: V1ClusterTrustBundleProjection) -> None: ...
    @property
    def config_map(self) -> V1ConfigMapProjection: ...
    @config_map.setter
    def config_map(self, config_map: V1ConfigMapProjection) -> None: ...
    @property
    def downward_api(self) -> V1DownwardAPIProjection: ...
    @downward_api.setter
    def downward_api(self, downward_api: V1DownwardAPIProjection) -> None: ...
    @property
    def pod_certificate(self) -> V1PodCertificateProjection: ...
    @pod_certificate.setter
    def pod_certificate(self, pod_certificate: V1PodCertificateProjection) -> None: ...
    @property
    def secret(self) -> V1SecretProjection: ...
    @secret.setter
    def secret(self, secret: V1SecretProjection) -> None: ...
    @property
    def service_account_token(self) -> V1ServiceAccountTokenProjection: ...
    @service_account_token.setter
    def service_account_token(self, service_account_token: V1ServiceAccountTokenProjection) -> None: ...
