from datetime import datetime
from typing import Any

class V1StatefulSetCondition:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, last_transition_time: datetime | None = None, message: str | None = None, reason: str | None = None, status: str | None = None, type: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def last_transition_time(self) -> datetime: ...
    @last_transition_time.setter
    def last_transition_time(self, last_transition_time: datetime) -> None: ...
    @property
    def message(self) -> str: ...
    @message.setter
    def message(self, message: str) -> None: ...
    @property
    def reason(self) -> str: ...
    @reason.setter
    def reason(self, reason: str) -> None: ...
    @property
    def status(self) -> str: ...
    @status.setter
    def status(self, status: str) -> None: ...
    @property
    def type(self) -> str: ...
    @type.setter
    def type(self, type: str) -> None: ...
