from typing import Any

class V1VolumeResourceRequirements:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, limits: dict[str, str] | None = None, requests: dict[str, str] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def limits(self) -> dict[str, str]: ...
    @limits.setter
    def limits(self, limits: dict[str, str]) -> None: ...
    @property
    def requests(self) -> dict[str, str]: ...
    @requests.setter
    def requests(self, requests: dict[str, str]) -> None: ...
