from kubernetes_asyncio.client.models import V1NamespaceCondition
from typing import Any

class V1NamespaceStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, conditions: list[V1NamespaceCondition] | None = None, phase: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def conditions(self) -> list[V1NamespaceCondition]: ...
    @conditions.setter
    def conditions(self, conditions: list[V1NamespaceCondition]) -> None: ...
    @property
    def phase(self) -> str: ...
    @phase.setter
    def phase(self, phase: str) -> None: ...
