from typing import Any

class V1ValidationRule:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, field_path: str | None = None, message: str | None = None, message_expression: str | None = None, optional_old_self: bool | None = None, reason: str | None = None, rule: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def field_path(self) -> str: ...
    @field_path.setter
    def field_path(self, field_path: str) -> None: ...
    @property
    def message(self) -> str: ...
    @message.setter
    def message(self, message: str) -> None: ...
    @property
    def message_expression(self) -> str: ...
    @message_expression.setter
    def message_expression(self, message_expression: str) -> None: ...
    @property
    def optional_old_self(self) -> bool: ...
    @optional_old_self.setter
    def optional_old_self(self, optional_old_self: bool) -> None: ...
    @property
    def reason(self) -> str: ...
    @reason.setter
    def reason(self, reason: str) -> None: ...
    @property
    def rule(self) -> str: ...
    @rule.setter
    def rule(self, rule: str) -> None: ...
