from kubernetes_asyncio.client.models import V1alpha3DeviceTaint
from kubernetes_asyncio.client.models import V1alpha3DeviceTaintSelector
from typing import Any

class V1alpha3DeviceTaintRuleSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, device_selector: V1alpha3DeviceTaintSelector | None = None, taint: V1alpha3DeviceTaint | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def device_selector(self) -> V1alpha3DeviceTaintSelector: ...
    @device_selector.setter
    def device_selector(self, device_selector: V1alpha3DeviceTaintSelector) -> None: ...
    @property
    def taint(self) -> V1alpha3DeviceTaint: ...
    @taint.setter
    def taint(self, taint: V1alpha3DeviceTaint) -> None: ...
