from kubernetes_asyncio.client.models import V1LabelSelector
from typing import Any

class V1alpha1ParamRef:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, name: str | None = None, namespace: str | None = None, parameter_not_found_action: str | None = None, selector: V1LabelSelector | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
    @property
    def namespace(self) -> str: ...
    @namespace.setter
    def namespace(self, namespace: str) -> None: ...
    @property
    def parameter_not_found_action(self) -> str: ...
    @parameter_not_found_action.setter
    def parameter_not_found_action(self, parameter_not_found_action: str) -> None: ...
    @property
    def selector(self) -> V1LabelSelector: ...
    @selector.setter
    def selector(self, selector: V1LabelSelector) -> None: ...
