from kubernetes_asyncio.client.models import V1FlowDistinguisherMethod
from kubernetes_asyncio.client.models import V1PolicyRulesWithSubjects
from kubernetes_asyncio.client.models import V1PriorityLevelConfigurationReference
from typing import Any

class V1FlowSchemaSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, distinguisher_method: V1FlowDistinguisherMethod | None = None, matching_precedence: int | None = None, priority_level_configuration: V1PriorityLevelConfigurationReference | None = None, rules: list[V1PolicyRulesWithSubjects] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def distinguisher_method(self) -> V1FlowDistinguisherMethod: ...
    @distinguisher_method.setter
    def distinguisher_method(self, distinguisher_method: V1FlowDistinguisherMethod) -> None: ...
    @property
    def matching_precedence(self) -> int: ...
    @matching_precedence.setter
    def matching_precedence(self, matching_precedence: int) -> None: ...
    @property
    def priority_level_configuration(self) -> V1PriorityLevelConfigurationReference: ...
    @priority_level_configuration.setter
    def priority_level_configuration(self, priority_level_configuration: V1PriorityLevelConfigurationReference) -> None: ...
    @property
    def rules(self) -> list[V1PolicyRulesWithSubjects]: ...
    @rules.setter
    def rules(self, rules: list[V1PolicyRulesWithSubjects]) -> None: ...
