from kubernetes_asyncio.client.models import V1AttachedVolume
from kubernetes_asyncio.client.models import V1ContainerImage
from kubernetes_asyncio.client.models import V1NodeAddress
from kubernetes_asyncio.client.models import V1NodeCondition
from kubernetes_asyncio.client.models import V1NodeConfigStatus
from kubernetes_asyncio.client.models import V1NodeDaemonEndpoints
from kubernetes_asyncio.client.models import V1NodeFeatures
from kubernetes_asyncio.client.models import V1NodeRuntimeHandler
from kubernetes_asyncio.client.models import V1NodeSystemInfo
from typing import Any

class V1NodeStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, addresses: list[V1NodeAddress] | None = None, allocatable: dict[str, str] | None = None, capacity: dict[str, str] | None = None, conditions: list[V1NodeCondition] | None = None, config: V1NodeConfigStatus | None = None, daemon_endpoints: V1NodeDaemonEndpoints | None = None, features: V1NodeFeatures | None = None, images: list[V1ContainerImage] | None = None, node_info: V1NodeSystemInfo | None = None, phase: str | None = None, runtime_handlers: list[V1NodeRuntimeHandler] | None = None, volumes_attached: list[V1AttachedVolume] | None = None, volumes_in_use: list[str] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def addresses(self) -> list[V1NodeAddress]: ...
    @addresses.setter
    def addresses(self, addresses: list[V1NodeAddress]) -> None: ...
    @property
    def allocatable(self) -> dict[str, str]: ...
    @allocatable.setter
    def allocatable(self, allocatable: dict[str, str]) -> None: ...
    @property
    def capacity(self) -> dict[str, str]: ...
    @capacity.setter
    def capacity(self, capacity: dict[str, str]) -> None: ...
    @property
    def conditions(self) -> list[V1NodeCondition]: ...
    @conditions.setter
    def conditions(self, conditions: list[V1NodeCondition]) -> None: ...
    @property
    def config(self) -> V1NodeConfigStatus: ...
    @config.setter
    def config(self, config: V1NodeConfigStatus) -> None: ...
    @property
    def daemon_endpoints(self) -> V1NodeDaemonEndpoints: ...
    @daemon_endpoints.setter
    def daemon_endpoints(self, daemon_endpoints: V1NodeDaemonEndpoints) -> None: ...
    @property
    def features(self) -> V1NodeFeatures: ...
    @features.setter
    def features(self, features: V1NodeFeatures) -> None: ...
    @property
    def images(self) -> list[V1ContainerImage]: ...
    @images.setter
    def images(self, images: list[V1ContainerImage]) -> None: ...
    @property
    def node_info(self) -> V1NodeSystemInfo: ...
    @node_info.setter
    def node_info(self, node_info: V1NodeSystemInfo) -> None: ...
    @property
    def phase(self) -> str: ...
    @phase.setter
    def phase(self, phase: str) -> None: ...
    @property
    def runtime_handlers(self) -> list[V1NodeRuntimeHandler]: ...
    @runtime_handlers.setter
    def runtime_handlers(self, runtime_handlers: list[V1NodeRuntimeHandler]) -> None: ...
    @property
    def volumes_attached(self) -> list[V1AttachedVolume]: ...
    @volumes_attached.setter
    def volumes_attached(self, volumes_attached: list[V1AttachedVolume]) -> None: ...
    @property
    def volumes_in_use(self) -> list[str]: ...
    @volumes_in_use.setter
    def volumes_in_use(self, volumes_in_use: list[str]) -> None: ...
