from kubernetes_asyncio.client.models import V1LabelSelectorRequirement
from typing import Any

class V1LabelSelector:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, match_expressions: list[V1LabelSelectorRequirement] | None = None, match_labels: dict[str, str] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def match_expressions(self) -> list[V1LabelSelectorRequirement]: ...
    @match_expressions.setter
    def match_expressions(self, match_expressions: list[V1LabelSelectorRequirement]) -> None: ...
    @property
    def match_labels(self) -> dict[str, str]: ...
    @match_labels.setter
    def match_labels(self, match_labels: dict[str, str]) -> None: ...
