from kubernetes_asyncio.client.models import V1IngressClassParametersReference
from typing import Any

class V1IngressClassSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, controller: str | None = None, parameters: V1IngressClassParametersReference | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def controller(self) -> str: ...
    @controller.setter
    def controller(self, controller: str) -> None: ...
    @property
    def parameters(self) -> V1IngressClassParametersReference: ...
    @parameters.setter
    def parameters(self, parameters: V1IngressClassParametersReference) -> None: ...
