from typing import Any

class V1WindowsSecurityContextOptions:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, gmsa_credential_spec: str | None = None, gmsa_credential_spec_name: str | None = None, host_process: bool | None = None, run_as_user_name: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def gmsa_credential_spec(self) -> str: ...
    @gmsa_credential_spec.setter
    def gmsa_credential_spec(self, gmsa_credential_spec: str) -> None: ...
    @property
    def gmsa_credential_spec_name(self) -> str: ...
    @gmsa_credential_spec_name.setter
    def gmsa_credential_spec_name(self, gmsa_credential_spec_name: str) -> None: ...
    @property
    def host_process(self) -> bool: ...
    @host_process.setter
    def host_process(self, host_process: bool) -> None: ...
    @property
    def run_as_user_name(self) -> str: ...
    @run_as_user_name.setter
    def run_as_user_name(self, run_as_user_name: str) -> None: ...
