from typing import Any

class VersionInfo:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, build_date: str | None = None, compiler: str | None = None, emulation_major: str | None = None, emulation_minor: str | None = None, git_commit: str | None = None, git_tree_state: str | None = None, git_version: str | None = None, go_version: str | None = None, major: str | None = None, min_compatibility_major: str | None = None, min_compatibility_minor: str | None = None, minor: str | None = None, platform: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def build_date(self) -> str: ...
    @build_date.setter
    def build_date(self, build_date: str) -> None: ...
    @property
    def compiler(self) -> str: ...
    @compiler.setter
    def compiler(self, compiler: str) -> None: ...
    @property
    def emulation_major(self) -> str: ...
    @emulation_major.setter
    def emulation_major(self, emulation_major: str) -> None: ...
    @property
    def emulation_minor(self) -> str: ...
    @emulation_minor.setter
    def emulation_minor(self, emulation_minor: str) -> None: ...
    @property
    def git_commit(self) -> str: ...
    @git_commit.setter
    def git_commit(self, git_commit: str) -> None: ...
    @property
    def git_tree_state(self) -> str: ...
    @git_tree_state.setter
    def git_tree_state(self, git_tree_state: str) -> None: ...
    @property
    def git_version(self) -> str: ...
    @git_version.setter
    def git_version(self, git_version: str) -> None: ...
    @property
    def go_version(self) -> str: ...
    @go_version.setter
    def go_version(self, go_version: str) -> None: ...
    @property
    def major(self) -> str: ...
    @major.setter
    def major(self, major: str) -> None: ...
    @property
    def min_compatibility_major(self) -> str: ...
    @min_compatibility_major.setter
    def min_compatibility_major(self, min_compatibility_major: str) -> None: ...
    @property
    def min_compatibility_minor(self) -> str: ...
    @min_compatibility_minor.setter
    def min_compatibility_minor(self, min_compatibility_minor: str) -> None: ...
    @property
    def minor(self) -> str: ...
    @minor.setter
    def minor(self, minor: str) -> None: ...
    @property
    def platform(self) -> str: ...
    @platform.setter
    def platform(self, platform: str) -> None: ...
