from datetime import datetime
from kubernetes_asyncio.client.models import CoreV1EventSeries
from kubernetes_asyncio.client.models import V1EventSource
from kubernetes_asyncio.client.models import V1ObjectMeta
from kubernetes_asyncio.client.models import V1ObjectReference
from typing import Any

class CoreV1Event:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, action: str | None = None, api_version: str | None = None, count: int | None = None, event_time: datetime | None = None, first_timestamp: datetime | None = None, involved_object: V1ObjectReference | None = None, kind: str | None = None, last_timestamp: datetime | None = None, message: str | None = None, metadata: V1ObjectMeta | None = None, reason: str | None = None, related: V1ObjectReference | None = None, reporting_component: str | None = None, reporting_instance: str | None = None, series: CoreV1EventSeries | None = None, source: V1EventSource | None = None, type: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def action(self) -> str: ...
    @action.setter
    def action(self, action: str) -> None: ...
    @property
    def api_version(self) -> str: ...
    @api_version.setter
    def api_version(self, api_version: str) -> None: ...
    @property
    def count(self) -> int: ...
    @count.setter
    def count(self, count: int) -> None: ...
    @property
    def event_time(self) -> datetime: ...
    @event_time.setter
    def event_time(self, event_time: datetime) -> None: ...
    @property
    def first_timestamp(self) -> datetime: ...
    @first_timestamp.setter
    def first_timestamp(self, first_timestamp: datetime) -> None: ...
    @property
    def involved_object(self) -> V1ObjectReference: ...
    @involved_object.setter
    def involved_object(self, involved_object: V1ObjectReference) -> None: ...
    @property
    def kind(self) -> str: ...
    @kind.setter
    def kind(self, kind: str) -> None: ...
    @property
    def last_timestamp(self) -> datetime: ...
    @last_timestamp.setter
    def last_timestamp(self, last_timestamp: datetime) -> None: ...
    @property
    def message(self) -> str: ...
    @message.setter
    def message(self, message: str) -> None: ...
    @property
    def metadata(self) -> V1ObjectMeta: ...
    @metadata.setter
    def metadata(self, metadata: V1ObjectMeta) -> None: ...
    @property
    def reason(self) -> str: ...
    @reason.setter
    def reason(self, reason: str) -> None: ...
    @property
    def related(self) -> V1ObjectReference: ...
    @related.setter
    def related(self, related: V1ObjectReference) -> None: ...
    @property
    def reporting_component(self) -> str: ...
    @reporting_component.setter
    def reporting_component(self, reporting_component: str) -> None: ...
    @property
    def reporting_instance(self) -> str: ...
    @reporting_instance.setter
    def reporting_instance(self, reporting_instance: str) -> None: ...
    @property
    def series(self) -> CoreV1EventSeries: ...
    @series.setter
    def series(self, series: CoreV1EventSeries) -> None: ...
    @property
    def source(self) -> V1EventSource: ...
    @source.setter
    def source(self, source: V1EventSource) -> None: ...
    @property
    def type(self) -> str: ...
    @type.setter
    def type(self, type: str) -> None: ...
