from datetime import datetime
from typing import Any

class V1VolumeError:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, error_code: int | None = None, message: str | None = None, time: datetime | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def error_code(self) -> int: ...
    @error_code.setter
    def error_code(self, error_code: int) -> None: ...
    @property
    def message(self) -> str: ...
    @message.setter
    def message(self, message: str) -> None: ...
    @property
    def time(self) -> datetime: ...
    @time.setter
    def time(self, time: datetime) -> None: ...
