from kubernetes_asyncio.client.models import V2HPAScalingRules
from typing import Any

class V2HorizontalPodAutoscalerBehavior:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, scale_down: V2HPAScalingRules | None = None, scale_up: V2HPAScalingRules | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def scale_down(self) -> V2HPAScalingRules: ...
    @scale_down.setter
    def scale_down(self, scale_down: V2HPAScalingRules) -> None: ...
    @property
    def scale_up(self) -> V2HPAScalingRules: ...
    @scale_up.setter
    def scale_up(self, scale_up: V2HPAScalingRules) -> None: ...
