from typing import Any

class V1ResourcePolicyRule:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, api_groups: list[str] | None = None, cluster_scope: bool | None = None, namespaces: list[str] | None = None, resources: list[str] | None = None, verbs: list[str] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def api_groups(self) -> list[str]: ...
    @api_groups.setter
    def api_groups(self, api_groups: list[str]) -> None: ...
    @property
    def cluster_scope(self) -> bool: ...
    @cluster_scope.setter
    def cluster_scope(self, cluster_scope: bool) -> None: ...
    @property
    def namespaces(self) -> list[str]: ...
    @namespaces.setter
    def namespaces(self, namespaces: list[str]) -> None: ...
    @property
    def resources(self) -> list[str]: ...
    @resources.setter
    def resources(self, resources: list[str]) -> None: ...
    @property
    def verbs(self) -> list[str]: ...
    @verbs.setter
    def verbs(self, verbs: list[str]) -> None: ...
