from typing import Any

class V1GitRepoVolumeSource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, directory: str | None = None, repository: str | None = None, revision: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def directory(self) -> str: ...
    @directory.setter
    def directory(self, directory: str) -> None: ...
    @property
    def repository(self) -> str: ...
    @repository.setter
    def repository(self, repository: str) -> None: ...
    @property
    def revision(self) -> str: ...
    @revision.setter
    def revision(self, revision: str) -> None: ...
