from kubernetes_asyncio.client.models import V1PodAffinityTerm
from typing import Any

class V1WeightedPodAffinityTerm:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, pod_affinity_term: V1PodAffinityTerm | None = None, weight: int | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def pod_affinity_term(self) -> V1PodAffinityTerm: ...
    @pod_affinity_term.setter
    def pod_affinity_term(self, pod_affinity_term: V1PodAffinityTerm) -> None: ...
    @property
    def weight(self) -> int: ...
    @weight.setter
    def weight(self, weight: int) -> None: ...
