from kubernetes_asyncio.client.models import V1beta2CapacityRequestPolicyRange
from typing import Any

class V1beta2CapacityRequestPolicy:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, default: str | None = None, valid_range: V1beta2CapacityRequestPolicyRange | None = None, valid_values: list[str] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def default(self) -> str: ...
    @default.setter
    def default(self, default: str) -> None: ...
    @property
    def valid_range(self) -> V1beta2CapacityRequestPolicyRange: ...
    @valid_range.setter
    def valid_range(self, valid_range: V1beta2CapacityRequestPolicyRange) -> None: ...
    @property
    def valid_values(self) -> list[str]: ...
    @valid_values.setter
    def valid_values(self, valid_values: list[str]) -> None: ...
