from kubernetes_asyncio.client.models import V1DaemonEndpoint
from typing import Any

class V1NodeDaemonEndpoints:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, kubelet_endpoint: V1DaemonEndpoint | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def kubelet_endpoint(self) -> V1DaemonEndpoint: ...
    @kubelet_endpoint.setter
    def kubelet_endpoint(self, kubelet_endpoint: V1DaemonEndpoint) -> None: ...
