from typing import Any

class V1alpha1GroupVersionResource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, group: str | None = None, resource: str | None = None, version: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def group(self) -> str: ...
    @group.setter
    def group(self, group: str) -> None: ...
    @property
    def resource(self) -> str: ...
    @resource.setter
    def resource(self, resource: str) -> None: ...
    @property
    def version(self) -> str: ...
    @version.setter
    def version(self, version: str) -> None: ...
