from typing import Any

class V1beta1DeviceToleration:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, effect: str | None = None, key: str | None = None, operator: str | None = None, toleration_seconds: int | None = None, value: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def effect(self) -> str: ...
    @effect.setter
    def effect(self, effect: str) -> None: ...
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, key: str) -> None: ...
    @property
    def operator(self) -> str: ...
    @operator.setter
    def operator(self, operator: str) -> None: ...
    @property
    def toleration_seconds(self) -> int: ...
    @toleration_seconds.setter
    def toleration_seconds(self, toleration_seconds: int) -> None: ...
    @property
    def value(self) -> str: ...
    @value.setter
    def value(self, value: str) -> None: ...
