from kubernetes_asyncio.client.models import V1ExternalDocumentation
from kubernetes_asyncio.client.models import V1ValidationRule
from typing import Any

class V1JSONSchemaProps:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, ref: str | None = None, schema: str | None = None, additional_items: Any | None = None, additional_properties: Any | None = None, all_of: list[V1JSONSchemaProps] | None = None, any_of: list[V1JSONSchemaProps] | None = None, default: Any | None = None, definitions: dict[str, V1JSONSchemaProps] | None = None, dependencies: dict[str, Any] | None = None, description: str | None = None, enum: list[Any] | None = None, example: Any | None = None, exclusive_maximum: bool | None = None, exclusive_minimum: bool | None = None, external_docs: V1ExternalDocumentation | None = None, format: str | None = None, id: str | None = None, items: Any | None = None, max_items: int | None = None, max_length: int | None = None, max_properties: int | None = None, maximum: float | None = None, min_items: int | None = None, min_length: int | None = None, min_properties: int | None = None, minimum: float | None = None, multiple_of: float | None = None, _not: V1JSONSchemaProps | None = None, nullable: bool | None = None, one_of: list[V1JSONSchemaProps] | None = None, pattern: str | None = None, pattern_properties: dict[str, V1JSONSchemaProps] | None = None, properties: dict[str, V1JSONSchemaProps] | None = None, required: list[str] | None = None, title: str | None = None, type: str | None = None, unique_items: bool | None = None, x_kubernetes_embedded_resource: bool | None = None, x_kubernetes_int_or_string: bool | None = None, x_kubernetes_list_map_keys: list[str] | None = None, x_kubernetes_list_type: str | None = None, x_kubernetes_map_type: str | None = None, x_kubernetes_preserve_unknown_fields: bool | None = None, x_kubernetes_validations: list[V1ValidationRule] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def _not(self) -> V1JSONSchemaProps: ...
    @_not.setter
    def _not(self, _not: V1JSONSchemaProps) -> None: ...
    @property
    def additional_items(self) -> Any: ...
    @additional_items.setter
    def additional_items(self, additional_items: Any) -> None: ...
    @property
    def additional_properties(self) -> Any: ...
    @additional_properties.setter
    def additional_properties(self, additional_properties: Any) -> None: ...
    @property
    def all_of(self) -> list[V1JSONSchemaProps]: ...
    @all_of.setter
    def all_of(self, all_of: list[V1JSONSchemaProps]) -> None: ...
    @property
    def any_of(self) -> list[V1JSONSchemaProps]: ...
    @any_of.setter
    def any_of(self, any_of: list[V1JSONSchemaProps]) -> None: ...
    @property
    def default(self) -> Any: ...
    @default.setter
    def default(self, default: Any) -> None: ...
    @property
    def definitions(self) -> dict[str, V1JSONSchemaProps]: ...
    @definitions.setter
    def definitions(self, definitions: dict[str, V1JSONSchemaProps]) -> None: ...
    @property
    def dependencies(self) -> dict[str, Any]: ...
    @dependencies.setter
    def dependencies(self, dependencies: dict[str, Any]) -> None: ...
    @property
    def description(self) -> str: ...
    @description.setter
    def description(self, description: str) -> None: ...
    @property
    def enum(self) -> list[Any]: ...
    @enum.setter
    def enum(self, enum: list[Any]) -> None: ...
    @property
    def example(self) -> Any: ...
    @example.setter
    def example(self, example: Any) -> None: ...
    @property
    def exclusive_maximum(self) -> bool: ...
    @exclusive_maximum.setter
    def exclusive_maximum(self, exclusive_maximum: bool) -> None: ...
    @property
    def exclusive_minimum(self) -> bool: ...
    @exclusive_minimum.setter
    def exclusive_minimum(self, exclusive_minimum: bool) -> None: ...
    @property
    def external_docs(self) -> V1ExternalDocumentation: ...
    @external_docs.setter
    def external_docs(self, external_docs: V1ExternalDocumentation) -> None: ...
    @property
    def format(self) -> str: ...
    @format.setter
    def format(self, format: str) -> None: ...
    @property
    def id(self) -> str: ...
    @id.setter
    def id(self, id: str) -> None: ...
    @property
    def items(self) -> Any: ...
    @items.setter
    def items(self, items: Any) -> None: ...
    @property
    def max_items(self) -> int: ...
    @max_items.setter
    def max_items(self, max_items: int) -> None: ...
    @property
    def max_length(self) -> int: ...
    @max_length.setter
    def max_length(self, max_length: int) -> None: ...
    @property
    def max_properties(self) -> int: ...
    @max_properties.setter
    def max_properties(self, max_properties: int) -> None: ...
    @property
    def maximum(self) -> float: ...
    @maximum.setter
    def maximum(self, maximum: float) -> None: ...
    @property
    def min_items(self) -> int: ...
    @min_items.setter
    def min_items(self, min_items: int) -> None: ...
    @property
    def min_length(self) -> int: ...
    @min_length.setter
    def min_length(self, min_length: int) -> None: ...
    @property
    def min_properties(self) -> int: ...
    @min_properties.setter
    def min_properties(self, min_properties: int) -> None: ...
    @property
    def minimum(self) -> float: ...
    @minimum.setter
    def minimum(self, minimum: float) -> None: ...
    @property
    def multiple_of(self) -> float: ...
    @multiple_of.setter
    def multiple_of(self, multiple_of: float) -> None: ...
    @property
    def nullable(self) -> bool: ...
    @nullable.setter
    def nullable(self, nullable: bool) -> None: ...
    @property
    def one_of(self) -> list[V1JSONSchemaProps]: ...
    @one_of.setter
    def one_of(self, one_of: list[V1JSONSchemaProps]) -> None: ...
    @property
    def pattern(self) -> str: ...
    @pattern.setter
    def pattern(self, pattern: str) -> None: ...
    @property
    def pattern_properties(self) -> dict[str, V1JSONSchemaProps]: ...
    @pattern_properties.setter
    def pattern_properties(self, pattern_properties: dict[str, V1JSONSchemaProps]) -> None: ...
    @property
    def properties(self) -> dict[str, V1JSONSchemaProps]: ...
    @properties.setter
    def properties(self, properties: dict[str, V1JSONSchemaProps]) -> None: ...
    @property
    def ref(self) -> str: ...
    @ref.setter
    def ref(self, ref: str) -> None: ...
    @property
    def required(self) -> list[str]: ...
    @required.setter
    def required(self, required: list[str]) -> None: ...
    @property
    def schema(self) -> str: ...
    @schema.setter
    def schema(self, schema: str) -> None: ...
    @property
    def title(self) -> str: ...
    @title.setter
    def title(self, title: str) -> None: ...
    @property
    def type(self) -> str: ...
    @type.setter
    def type(self, type: str) -> None: ...
    @property
    def unique_items(self) -> bool: ...
    @unique_items.setter
    def unique_items(self, unique_items: bool) -> None: ...
    @property
    def x_kubernetes_embedded_resource(self) -> bool: ...
    @x_kubernetes_embedded_resource.setter
    def x_kubernetes_embedded_resource(self, x_kubernetes_embedded_resource: bool) -> None: ...
    @property
    def x_kubernetes_int_or_string(self) -> bool: ...
    @x_kubernetes_int_or_string.setter
    def x_kubernetes_int_or_string(self, x_kubernetes_int_or_string: bool) -> None: ...
    @property
    def x_kubernetes_list_map_keys(self) -> list[str]: ...
    @x_kubernetes_list_map_keys.setter
    def x_kubernetes_list_map_keys(self, x_kubernetes_list_map_keys: list[str]) -> None: ...
    @property
    def x_kubernetes_list_type(self) -> str: ...
    @x_kubernetes_list_type.setter
    def x_kubernetes_list_type(self, x_kubernetes_list_type: str) -> None: ...
    @property
    def x_kubernetes_map_type(self) -> str: ...
    @x_kubernetes_map_type.setter
    def x_kubernetes_map_type(self, x_kubernetes_map_type: str) -> None: ...
    @property
    def x_kubernetes_preserve_unknown_fields(self) -> bool: ...
    @x_kubernetes_preserve_unknown_fields.setter
    def x_kubernetes_preserve_unknown_fields(self, x_kubernetes_preserve_unknown_fields: bool) -> None: ...
    @property
    def x_kubernetes_validations(self) -> list[V1ValidationRule]: ...
    @x_kubernetes_validations.setter
    def x_kubernetes_validations(self, x_kubernetes_validations: list[V1ValidationRule]) -> None: ...
