from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import AuthenticationV1TokenRequest
from kubernetes_asyncio.client.models import CoreV1Event
from kubernetes_asyncio.client.models import CoreV1EventList
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1Binding
from kubernetes_asyncio.client.models import V1ComponentStatus
from kubernetes_asyncio.client.models import V1ComponentStatusList
from kubernetes_asyncio.client.models import V1ConfigMap
from kubernetes_asyncio.client.models import V1ConfigMapList
from kubernetes_asyncio.client.models import V1Endpoints
from kubernetes_asyncio.client.models import V1EndpointsList
from kubernetes_asyncio.client.models import V1Eviction
from kubernetes_asyncio.client.models import V1LimitRange
from kubernetes_asyncio.client.models import V1LimitRangeList
from kubernetes_asyncio.client.models import V1Namespace
from kubernetes_asyncio.client.models import V1NamespaceList
from kubernetes_asyncio.client.models import V1Node
from kubernetes_asyncio.client.models import V1NodeList
from kubernetes_asyncio.client.models import V1PersistentVolume
from kubernetes_asyncio.client.models import V1PersistentVolumeClaim
from kubernetes_asyncio.client.models import V1PersistentVolumeClaimList
from kubernetes_asyncio.client.models import V1PersistentVolumeList
from kubernetes_asyncio.client.models import V1Pod
from kubernetes_asyncio.client.models import V1PodList
from kubernetes_asyncio.client.models import V1PodTemplate
from kubernetes_asyncio.client.models import V1PodTemplateList
from kubernetes_asyncio.client.models import V1ReplicationController
from kubernetes_asyncio.client.models import V1ReplicationControllerList
from kubernetes_asyncio.client.models import V1ResourceQuota
from kubernetes_asyncio.client.models import V1ResourceQuotaList
from kubernetes_asyncio.client.models import V1Scale
from kubernetes_asyncio.client.models import V1Secret
from kubernetes_asyncio.client.models import V1SecretList
from kubernetes_asyncio.client.models import V1Service
from kubernetes_asyncio.client.models import V1ServiceAccount
from kubernetes_asyncio.client.models import V1ServiceAccountList
from kubernetes_asyncio.client.models import V1ServiceList
from kubernetes_asyncio.client.models import V1Status
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class CoreV1Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def connect_delete_namespaced_pod_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_delete_namespaced_pod_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_delete_namespaced_pod_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_delete_namespaced_pod_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_delete_namespaced_service_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_delete_namespaced_service_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_delete_namespaced_service_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_delete_namespaced_service_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_delete_node_proxy(self, name: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_delete_node_proxy_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_delete_node_proxy_with_path(self, name: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_delete_node_proxy_with_path_with_http_info(self, name: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_namespaced_pod_attach(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_namespaced_pod_attach_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_namespaced_pod_exec(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_namespaced_pod_exec_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_namespaced_pod_portforward(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_namespaced_pod_portforward_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_namespaced_pod_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_namespaced_pod_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_namespaced_pod_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_namespaced_pod_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_namespaced_service_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_namespaced_service_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_namespaced_service_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_namespaced_service_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_node_proxy(self, name: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_node_proxy_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_node_proxy_with_path(self, name: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_node_proxy_with_path_with_http_info(self, name: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_head_namespaced_pod_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_head_namespaced_pod_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_head_namespaced_pod_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_head_namespaced_pod_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_head_namespaced_service_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_head_namespaced_service_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_head_namespaced_service_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_head_namespaced_service_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_head_node_proxy(self, name: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_head_node_proxy_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_head_node_proxy_with_path(self, name: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_head_node_proxy_with_path_with_http_info(self, name: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_options_namespaced_pod_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_options_namespaced_pod_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_options_namespaced_pod_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_options_namespaced_pod_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_options_namespaced_service_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_options_namespaced_service_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_options_namespaced_service_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_options_namespaced_service_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_options_node_proxy(self, name: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_options_node_proxy_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_options_node_proxy_with_path(self, name: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_options_node_proxy_with_path_with_http_info(self, name: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_patch_namespaced_pod_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_patch_namespaced_pod_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_patch_namespaced_pod_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_patch_namespaced_pod_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_patch_namespaced_service_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_patch_namespaced_service_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_patch_namespaced_service_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_patch_namespaced_service_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_patch_node_proxy(self, name: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_patch_node_proxy_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_patch_node_proxy_with_path(self, name: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_patch_node_proxy_with_path_with_http_info(self, name: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_namespaced_pod_attach(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_namespaced_pod_attach_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_namespaced_pod_exec(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_namespaced_pod_exec_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_namespaced_pod_portforward(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_namespaced_pod_portforward_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_namespaced_pod_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_namespaced_pod_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_namespaced_pod_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_namespaced_pod_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_namespaced_service_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_namespaced_service_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_namespaced_service_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_namespaced_service_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_node_proxy(self, name: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_node_proxy_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_node_proxy_with_path(self, name: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_node_proxy_with_path_with_http_info(self, name: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_put_namespaced_pod_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_put_namespaced_pod_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_put_namespaced_pod_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_put_namespaced_pod_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_put_namespaced_service_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_put_namespaced_service_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_put_namespaced_service_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_put_namespaced_service_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_put_node_proxy(self, name: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_put_node_proxy_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_put_node_proxy_with_path(self, name: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_put_node_proxy_with_path_with_http_info(self, name: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def create_namespace(self, body: V1Namespace, **kwargs: Any) -> Awaitable[V1Namespace]: ...
    def create_namespace_with_http_info(self, body: V1Namespace, **kwargs: Any) -> Awaitable[tuple[V1Namespace, int, CIMultiDictProxy]]: ...
    def create_namespaced_binding(self, namespace: str, body: V1Binding, **kwargs: Any) -> Awaitable[V1Binding]: ...
    def create_namespaced_binding_with_http_info(self, namespace: str, body: V1Binding, **kwargs: Any) -> Awaitable[tuple[V1Binding, int, CIMultiDictProxy]]: ...
    def create_namespaced_config_map(self, namespace: str, body: V1ConfigMap, **kwargs: Any) -> Awaitable[V1ConfigMap]: ...
    def create_namespaced_config_map_with_http_info(self, namespace: str, body: V1ConfigMap, **kwargs: Any) -> Awaitable[tuple[V1ConfigMap, int, CIMultiDictProxy]]: ...
    def create_namespaced_endpoints(self, namespace: str, body: V1Endpoints, **kwargs: Any) -> Awaitable[V1Endpoints]: ...
    def create_namespaced_endpoints_with_http_info(self, namespace: str, body: V1Endpoints, **kwargs: Any) -> Awaitable[tuple[V1Endpoints, int, CIMultiDictProxy]]: ...
    def create_namespaced_event(self, namespace: str, body: CoreV1Event, **kwargs: Any) -> Awaitable[CoreV1Event]: ...
    def create_namespaced_event_with_http_info(self, namespace: str, body: CoreV1Event, **kwargs: Any) -> Awaitable[tuple[CoreV1Event, int, CIMultiDictProxy]]: ...
    def create_namespaced_limit_range(self, namespace: str, body: V1LimitRange, **kwargs: Any) -> Awaitable[V1LimitRange]: ...
    def create_namespaced_limit_range_with_http_info(self, namespace: str, body: V1LimitRange, **kwargs: Any) -> Awaitable[tuple[V1LimitRange, int, CIMultiDictProxy]]: ...
    def create_namespaced_persistent_volume_claim(self, namespace: str, body: V1PersistentVolumeClaim, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaim]: ...
    def create_namespaced_persistent_volume_claim_with_http_info(self, namespace: str, body: V1PersistentVolumeClaim, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaim, int, CIMultiDictProxy]]: ...
    def create_namespaced_pod(self, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def create_namespaced_pod_binding(self, name: str, namespace: str, body: V1Binding, **kwargs: Any) -> Awaitable[V1Binding]: ...
    def create_namespaced_pod_binding_with_http_info(self, name: str, namespace: str, body: V1Binding, **kwargs: Any) -> Awaitable[tuple[V1Binding, int, CIMultiDictProxy]]: ...
    def create_namespaced_pod_eviction(self, name: str, namespace: str, body: V1Eviction, **kwargs: Any) -> Awaitable[V1Eviction]: ...
    def create_namespaced_pod_eviction_with_http_info(self, name: str, namespace: str, body: V1Eviction, **kwargs: Any) -> Awaitable[tuple[V1Eviction, int, CIMultiDictProxy]]: ...
    def create_namespaced_pod_template(self, namespace: str, body: V1PodTemplate, **kwargs: Any) -> Awaitable[V1PodTemplate]: ...
    def create_namespaced_pod_template_with_http_info(self, namespace: str, body: V1PodTemplate, **kwargs: Any) -> Awaitable[tuple[V1PodTemplate, int, CIMultiDictProxy]]: ...
    def create_namespaced_pod_with_http_info(self, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def create_namespaced_replication_controller(self, namespace: str, body: V1ReplicationController, **kwargs: Any) -> Awaitable[V1ReplicationController]: ...
    def create_namespaced_replication_controller_with_http_info(self, namespace: str, body: V1ReplicationController, **kwargs: Any) -> Awaitable[tuple[V1ReplicationController, int, CIMultiDictProxy]]: ...
    def create_namespaced_resource_quota(self, namespace: str, body: V1ResourceQuota, **kwargs: Any) -> Awaitable[V1ResourceQuota]: ...
    def create_namespaced_resource_quota_with_http_info(self, namespace: str, body: V1ResourceQuota, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuota, int, CIMultiDictProxy]]: ...
    def create_namespaced_secret(self, namespace: str, body: V1Secret, **kwargs: Any) -> Awaitable[V1Secret]: ...
    def create_namespaced_secret_with_http_info(self, namespace: str, body: V1Secret, **kwargs: Any) -> Awaitable[tuple[V1Secret, int, CIMultiDictProxy]]: ...
    def create_namespaced_service(self, namespace: str, body: V1Service, **kwargs: Any) -> Awaitable[V1Service]: ...
    def create_namespaced_service_account(self, namespace: str, body: V1ServiceAccount, **kwargs: Any) -> Awaitable[V1ServiceAccount]: ...
    def create_namespaced_service_account_token(self, name: str, namespace: str, body: AuthenticationV1TokenRequest, **kwargs: Any) -> Awaitable[AuthenticationV1TokenRequest]: ...
    def create_namespaced_service_account_token_with_http_info(self, name: str, namespace: str, body: AuthenticationV1TokenRequest, **kwargs: Any) -> Awaitable[tuple[AuthenticationV1TokenRequest, int, CIMultiDictProxy]]: ...
    def create_namespaced_service_account_with_http_info(self, namespace: str, body: V1ServiceAccount, **kwargs: Any) -> Awaitable[tuple[V1ServiceAccount, int, CIMultiDictProxy]]: ...
    def create_namespaced_service_with_http_info(self, namespace: str, body: V1Service, **kwargs: Any) -> Awaitable[tuple[V1Service, int, CIMultiDictProxy]]: ...
    def create_node(self, body: V1Node, **kwargs: Any) -> Awaitable[V1Node]: ...
    def create_node_with_http_info(self, body: V1Node, **kwargs: Any) -> Awaitable[tuple[V1Node, int, CIMultiDictProxy]]: ...
    def create_persistent_volume(self, body: V1PersistentVolume, **kwargs: Any) -> Awaitable[V1PersistentVolume]: ...
    def create_persistent_volume_with_http_info(self, body: V1PersistentVolume, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolume, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_config_map(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_config_map_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_endpoints(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_endpoints_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_event(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_event_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_limit_range(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_limit_range_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_persistent_volume_claim(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_persistent_volume_claim_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_pod(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_pod_template(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_pod_template_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_pod_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_replication_controller(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_replication_controller_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_resource_quota(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_resource_quota_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_secret(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_secret_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_service(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_service_account(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_service_account_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_service_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_node(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_node_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_persistent_volume(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_persistent_volume_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespace(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespace_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_config_map(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_config_map_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_endpoints(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_endpoints_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_event(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_event_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_limit_range(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_limit_range_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_persistent_volume_claim(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaim]: ...
    def delete_namespaced_persistent_volume_claim_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaim, int, CIMultiDictProxy]]: ...
    def delete_namespaced_pod(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def delete_namespaced_pod_template(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1PodTemplate]: ...
    def delete_namespaced_pod_template_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1PodTemplate, int, CIMultiDictProxy]]: ...
    def delete_namespaced_pod_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def delete_namespaced_replication_controller(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_replication_controller_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_resource_quota(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ResourceQuota]: ...
    def delete_namespaced_resource_quota_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuota, int, CIMultiDictProxy]]: ...
    def delete_namespaced_secret(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_secret_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_service(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Service]: ...
    def delete_namespaced_service_account(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ServiceAccount]: ...
    def delete_namespaced_service_account_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ServiceAccount, int, CIMultiDictProxy]]: ...
    def delete_namespaced_service_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Service, int, CIMultiDictProxy]]: ...
    def delete_node(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_node_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_persistent_volume(self, name: str, **kwargs: Any) -> Awaitable[V1PersistentVolume]: ...
    def delete_persistent_volume_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolume, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
    def list_component_status(self, **kwargs: Any) -> Awaitable[V1ComponentStatusList]: ...
    def list_component_status_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ComponentStatusList, int, CIMultiDictProxy]]: ...
    def list_config_map_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1ConfigMapList]: ...
    def list_config_map_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ConfigMapList, int, CIMultiDictProxy]]: ...
    def list_endpoints_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1EndpointsList]: ...
    def list_endpoints_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1EndpointsList, int, CIMultiDictProxy]]: ...
    def list_event_for_all_namespaces(self, **kwargs: Any) -> Awaitable[CoreV1EventList]: ...
    def list_event_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[CoreV1EventList, int, CIMultiDictProxy]]: ...
    def list_limit_range_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1LimitRangeList]: ...
    def list_limit_range_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1LimitRangeList, int, CIMultiDictProxy]]: ...
    def list_namespace(self, **kwargs: Any) -> Awaitable[V1NamespaceList]: ...
    def list_namespace_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1NamespaceList, int, CIMultiDictProxy]]: ...
    def list_namespaced_config_map(self, namespace: str, **kwargs: Any) -> Awaitable[V1ConfigMapList]: ...
    def list_namespaced_config_map_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ConfigMapList, int, CIMultiDictProxy]]: ...
    def list_namespaced_endpoints(self, namespace: str, **kwargs: Any) -> Awaitable[V1EndpointsList]: ...
    def list_namespaced_endpoints_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1EndpointsList, int, CIMultiDictProxy]]: ...
    def list_namespaced_event(self, namespace: str, **kwargs: Any) -> Awaitable[CoreV1EventList]: ...
    def list_namespaced_event_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[CoreV1EventList, int, CIMultiDictProxy]]: ...
    def list_namespaced_limit_range(self, namespace: str, **kwargs: Any) -> Awaitable[V1LimitRangeList]: ...
    def list_namespaced_limit_range_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1LimitRangeList, int, CIMultiDictProxy]]: ...
    def list_namespaced_persistent_volume_claim(self, namespace: str, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaimList]: ...
    def list_namespaced_persistent_volume_claim_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaimList, int, CIMultiDictProxy]]: ...
    def list_namespaced_pod(self, namespace: str, **kwargs: Any) -> Awaitable[V1PodList]: ...
    def list_namespaced_pod_template(self, namespace: str, **kwargs: Any) -> Awaitable[V1PodTemplateList]: ...
    def list_namespaced_pod_template_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1PodTemplateList, int, CIMultiDictProxy]]: ...
    def list_namespaced_pod_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1PodList, int, CIMultiDictProxy]]: ...
    def list_namespaced_replication_controller(self, namespace: str, **kwargs: Any) -> Awaitable[V1ReplicationControllerList]: ...
    def list_namespaced_replication_controller_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ReplicationControllerList, int, CIMultiDictProxy]]: ...
    def list_namespaced_resource_quota(self, namespace: str, **kwargs: Any) -> Awaitable[V1ResourceQuotaList]: ...
    def list_namespaced_resource_quota_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuotaList, int, CIMultiDictProxy]]: ...
    def list_namespaced_secret(self, namespace: str, **kwargs: Any) -> Awaitable[V1SecretList]: ...
    def list_namespaced_secret_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1SecretList, int, CIMultiDictProxy]]: ...
    def list_namespaced_service(self, namespace: str, **kwargs: Any) -> Awaitable[V1ServiceList]: ...
    def list_namespaced_service_account(self, namespace: str, **kwargs: Any) -> Awaitable[V1ServiceAccountList]: ...
    def list_namespaced_service_account_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ServiceAccountList, int, CIMultiDictProxy]]: ...
    def list_namespaced_service_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ServiceList, int, CIMultiDictProxy]]: ...
    def list_node(self, **kwargs: Any) -> Awaitable[V1NodeList]: ...
    def list_node_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1NodeList, int, CIMultiDictProxy]]: ...
    def list_persistent_volume(self, **kwargs: Any) -> Awaitable[V1PersistentVolumeList]: ...
    def list_persistent_volume_claim_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaimList]: ...
    def list_persistent_volume_claim_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaimList, int, CIMultiDictProxy]]: ...
    def list_persistent_volume_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeList, int, CIMultiDictProxy]]: ...
    def list_pod_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1PodList]: ...
    def list_pod_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1PodList, int, CIMultiDictProxy]]: ...
    def list_pod_template_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1PodTemplateList]: ...
    def list_pod_template_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1PodTemplateList, int, CIMultiDictProxy]]: ...
    def list_replication_controller_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1ReplicationControllerList]: ...
    def list_replication_controller_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ReplicationControllerList, int, CIMultiDictProxy]]: ...
    def list_resource_quota_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1ResourceQuotaList]: ...
    def list_resource_quota_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuotaList, int, CIMultiDictProxy]]: ...
    def list_secret_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1SecretList]: ...
    def list_secret_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1SecretList, int, CIMultiDictProxy]]: ...
    def list_service_account_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1ServiceAccountList]: ...
    def list_service_account_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ServiceAccountList, int, CIMultiDictProxy]]: ...
    def list_service_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1ServiceList]: ...
    def list_service_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ServiceList, int, CIMultiDictProxy]]: ...
    def patch_namespace(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1Namespace]: ...
    def patch_namespace_status(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1Namespace]: ...
    def patch_namespace_status_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Namespace, int, CIMultiDictProxy]]: ...
    def patch_namespace_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Namespace, int, CIMultiDictProxy]]: ...
    def patch_namespaced_config_map(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1ConfigMap]: ...
    def patch_namespaced_config_map_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ConfigMap, int, CIMultiDictProxy]]: ...
    def patch_namespaced_endpoints(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Endpoints]: ...
    def patch_namespaced_endpoints_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Endpoints, int, CIMultiDictProxy]]: ...
    def patch_namespaced_event(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[CoreV1Event]: ...
    def patch_namespaced_event_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[CoreV1Event, int, CIMultiDictProxy]]: ...
    def patch_namespaced_limit_range(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1LimitRange]: ...
    def patch_namespaced_limit_range_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1LimitRange, int, CIMultiDictProxy]]: ...
    def patch_namespaced_persistent_volume_claim(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaim]: ...
    def patch_namespaced_persistent_volume_claim_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaim]: ...
    def patch_namespaced_persistent_volume_claim_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaim, int, CIMultiDictProxy]]: ...
    def patch_namespaced_persistent_volume_claim_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaim, int, CIMultiDictProxy]]: ...
    def patch_namespaced_pod(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def patch_namespaced_pod_ephemeralcontainers(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def patch_namespaced_pod_ephemeralcontainers_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def patch_namespaced_pod_resize(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def patch_namespaced_pod_resize_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def patch_namespaced_pod_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def patch_namespaced_pod_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def patch_namespaced_pod_template(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1PodTemplate]: ...
    def patch_namespaced_pod_template_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1PodTemplate, int, CIMultiDictProxy]]: ...
    def patch_namespaced_pod_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def patch_namespaced_replication_controller(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1ReplicationController]: ...
    def patch_namespaced_replication_controller_scale(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Scale]: ...
    def patch_namespaced_replication_controller_scale_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Scale, int, CIMultiDictProxy]]: ...
    def patch_namespaced_replication_controller_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1ReplicationController]: ...
    def patch_namespaced_replication_controller_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ReplicationController, int, CIMultiDictProxy]]: ...
    def patch_namespaced_replication_controller_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ReplicationController, int, CIMultiDictProxy]]: ...
    def patch_namespaced_resource_quota(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1ResourceQuota]: ...
    def patch_namespaced_resource_quota_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1ResourceQuota]: ...
    def patch_namespaced_resource_quota_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuota, int, CIMultiDictProxy]]: ...
    def patch_namespaced_resource_quota_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuota, int, CIMultiDictProxy]]: ...
    def patch_namespaced_secret(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Secret]: ...
    def patch_namespaced_secret_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Secret, int, CIMultiDictProxy]]: ...
    def patch_namespaced_service(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Service]: ...
    def patch_namespaced_service_account(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1ServiceAccount]: ...
    def patch_namespaced_service_account_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ServiceAccount, int, CIMultiDictProxy]]: ...
    def patch_namespaced_service_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Service]: ...
    def patch_namespaced_service_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Service, int, CIMultiDictProxy]]: ...
    def patch_namespaced_service_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Service, int, CIMultiDictProxy]]: ...
    def patch_node(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1Node]: ...
    def patch_node_status(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1Node]: ...
    def patch_node_status_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Node, int, CIMultiDictProxy]]: ...
    def patch_node_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Node, int, CIMultiDictProxy]]: ...
    def patch_persistent_volume(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1PersistentVolume]: ...
    def patch_persistent_volume_status(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1PersistentVolume]: ...
    def patch_persistent_volume_status_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolume, int, CIMultiDictProxy]]: ...
    def patch_persistent_volume_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolume, int, CIMultiDictProxy]]: ...
    def read_component_status(self, name: str, **kwargs: Any) -> Awaitable[V1ComponentStatus]: ...
    def read_component_status_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1ComponentStatus, int, CIMultiDictProxy]]: ...
    def read_namespace(self, name: str, **kwargs: Any) -> Awaitable[V1Namespace]: ...
    def read_namespace_status(self, name: str, **kwargs: Any) -> Awaitable[V1Namespace]: ...
    def read_namespace_status_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Namespace, int, CIMultiDictProxy]]: ...
    def read_namespace_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Namespace, int, CIMultiDictProxy]]: ...
    def read_namespaced_config_map(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ConfigMap]: ...
    def read_namespaced_config_map_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ConfigMap, int, CIMultiDictProxy]]: ...
    def read_namespaced_endpoints(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Endpoints]: ...
    def read_namespaced_endpoints_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Endpoints, int, CIMultiDictProxy]]: ...
    def read_namespaced_event(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[CoreV1Event]: ...
    def read_namespaced_event_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[CoreV1Event, int, CIMultiDictProxy]]: ...
    def read_namespaced_limit_range(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1LimitRange]: ...
    def read_namespaced_limit_range_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1LimitRange, int, CIMultiDictProxy]]: ...
    def read_namespaced_persistent_volume_claim(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaim]: ...
    def read_namespaced_persistent_volume_claim_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaim]: ...
    def read_namespaced_persistent_volume_claim_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaim, int, CIMultiDictProxy]]: ...
    def read_namespaced_persistent_volume_claim_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaim, int, CIMultiDictProxy]]: ...
    def read_namespaced_pod(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def read_namespaced_pod_ephemeralcontainers(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def read_namespaced_pod_ephemeralcontainers_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def read_namespaced_pod_log(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def read_namespaced_pod_log_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def read_namespaced_pod_resize(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def read_namespaced_pod_resize_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def read_namespaced_pod_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def read_namespaced_pod_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def read_namespaced_pod_template(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1PodTemplate]: ...
    def read_namespaced_pod_template_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1PodTemplate, int, CIMultiDictProxy]]: ...
    def read_namespaced_pod_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def read_namespaced_replication_controller(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ReplicationController]: ...
    def read_namespaced_replication_controller_scale(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Scale]: ...
    def read_namespaced_replication_controller_scale_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Scale, int, CIMultiDictProxy]]: ...
    def read_namespaced_replication_controller_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ReplicationController]: ...
    def read_namespaced_replication_controller_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ReplicationController, int, CIMultiDictProxy]]: ...
    def read_namespaced_replication_controller_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ReplicationController, int, CIMultiDictProxy]]: ...
    def read_namespaced_resource_quota(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ResourceQuota]: ...
    def read_namespaced_resource_quota_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ResourceQuota]: ...
    def read_namespaced_resource_quota_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuota, int, CIMultiDictProxy]]: ...
    def read_namespaced_resource_quota_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuota, int, CIMultiDictProxy]]: ...
    def read_namespaced_secret(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Secret]: ...
    def read_namespaced_secret_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Secret, int, CIMultiDictProxy]]: ...
    def read_namespaced_service(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Service]: ...
    def read_namespaced_service_account(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ServiceAccount]: ...
    def read_namespaced_service_account_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ServiceAccount, int, CIMultiDictProxy]]: ...
    def read_namespaced_service_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Service]: ...
    def read_namespaced_service_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Service, int, CIMultiDictProxy]]: ...
    def read_namespaced_service_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Service, int, CIMultiDictProxy]]: ...
    def read_node(self, name: str, **kwargs: Any) -> Awaitable[V1Node]: ...
    def read_node_status(self, name: str, **kwargs: Any) -> Awaitable[V1Node]: ...
    def read_node_status_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Node, int, CIMultiDictProxy]]: ...
    def read_node_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Node, int, CIMultiDictProxy]]: ...
    def read_persistent_volume(self, name: str, **kwargs: Any) -> Awaitable[V1PersistentVolume]: ...
    def read_persistent_volume_status(self, name: str, **kwargs: Any) -> Awaitable[V1PersistentVolume]: ...
    def read_persistent_volume_status_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolume, int, CIMultiDictProxy]]: ...
    def read_persistent_volume_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolume, int, CIMultiDictProxy]]: ...
    def replace_namespace(self, name: str, body: V1Namespace, **kwargs: Any) -> Awaitable[V1Namespace]: ...
    def replace_namespace_finalize(self, name: str, body: V1Namespace, **kwargs: Any) -> Awaitable[V1Namespace]: ...
    def replace_namespace_finalize_with_http_info(self, name: str, body: V1Namespace, **kwargs: Any) -> Awaitable[tuple[V1Namespace, int, CIMultiDictProxy]]: ...
    def replace_namespace_status(self, name: str, body: V1Namespace, **kwargs: Any) -> Awaitable[V1Namespace]: ...
    def replace_namespace_status_with_http_info(self, name: str, body: V1Namespace, **kwargs: Any) -> Awaitable[tuple[V1Namespace, int, CIMultiDictProxy]]: ...
    def replace_namespace_with_http_info(self, name: str, body: V1Namespace, **kwargs: Any) -> Awaitable[tuple[V1Namespace, int, CIMultiDictProxy]]: ...
    def replace_namespaced_config_map(self, name: str, namespace: str, body: V1ConfigMap, **kwargs: Any) -> Awaitable[V1ConfigMap]: ...
    def replace_namespaced_config_map_with_http_info(self, name: str, namespace: str, body: V1ConfigMap, **kwargs: Any) -> Awaitable[tuple[V1ConfigMap, int, CIMultiDictProxy]]: ...
    def replace_namespaced_endpoints(self, name: str, namespace: str, body: V1Endpoints, **kwargs: Any) -> Awaitable[V1Endpoints]: ...
    def replace_namespaced_endpoints_with_http_info(self, name: str, namespace: str, body: V1Endpoints, **kwargs: Any) -> Awaitable[tuple[V1Endpoints, int, CIMultiDictProxy]]: ...
    def replace_namespaced_event(self, name: str, namespace: str, body: CoreV1Event, **kwargs: Any) -> Awaitable[CoreV1Event]: ...
    def replace_namespaced_event_with_http_info(self, name: str, namespace: str, body: CoreV1Event, **kwargs: Any) -> Awaitable[tuple[CoreV1Event, int, CIMultiDictProxy]]: ...
    def replace_namespaced_limit_range(self, name: str, namespace: str, body: V1LimitRange, **kwargs: Any) -> Awaitable[V1LimitRange]: ...
    def replace_namespaced_limit_range_with_http_info(self, name: str, namespace: str, body: V1LimitRange, **kwargs: Any) -> Awaitable[tuple[V1LimitRange, int, CIMultiDictProxy]]: ...
    def replace_namespaced_persistent_volume_claim(self, name: str, namespace: str, body: V1PersistentVolumeClaim, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaim]: ...
    def replace_namespaced_persistent_volume_claim_status(self, name: str, namespace: str, body: V1PersistentVolumeClaim, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaim]: ...
    def replace_namespaced_persistent_volume_claim_status_with_http_info(self, name: str, namespace: str, body: V1PersistentVolumeClaim, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaim, int, CIMultiDictProxy]]: ...
    def replace_namespaced_persistent_volume_claim_with_http_info(self, name: str, namespace: str, body: V1PersistentVolumeClaim, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaim, int, CIMultiDictProxy]]: ...
    def replace_namespaced_pod(self, name: str, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def replace_namespaced_pod_ephemeralcontainers(self, name: str, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def replace_namespaced_pod_ephemeralcontainers_with_http_info(self, name: str, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def replace_namespaced_pod_resize(self, name: str, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def replace_namespaced_pod_resize_with_http_info(self, name: str, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def replace_namespaced_pod_status(self, name: str, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def replace_namespaced_pod_status_with_http_info(self, name: str, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def replace_namespaced_pod_template(self, name: str, namespace: str, body: V1PodTemplate, **kwargs: Any) -> Awaitable[V1PodTemplate]: ...
    def replace_namespaced_pod_template_with_http_info(self, name: str, namespace: str, body: V1PodTemplate, **kwargs: Any) -> Awaitable[tuple[V1PodTemplate, int, CIMultiDictProxy]]: ...
    def replace_namespaced_pod_with_http_info(self, name: str, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def replace_namespaced_replication_controller(self, name: str, namespace: str, body: V1ReplicationController, **kwargs: Any) -> Awaitable[V1ReplicationController]: ...
    def replace_namespaced_replication_controller_scale(self, name: str, namespace: str, body: V1Scale, **kwargs: Any) -> Awaitable[V1Scale]: ...
    def replace_namespaced_replication_controller_scale_with_http_info(self, name: str, namespace: str, body: V1Scale, **kwargs: Any) -> Awaitable[tuple[V1Scale, int, CIMultiDictProxy]]: ...
    def replace_namespaced_replication_controller_status(self, name: str, namespace: str, body: V1ReplicationController, **kwargs: Any) -> Awaitable[V1ReplicationController]: ...
    def replace_namespaced_replication_controller_status_with_http_info(self, name: str, namespace: str, body: V1ReplicationController, **kwargs: Any) -> Awaitable[tuple[V1ReplicationController, int, CIMultiDictProxy]]: ...
    def replace_namespaced_replication_controller_with_http_info(self, name: str, namespace: str, body: V1ReplicationController, **kwargs: Any) -> Awaitable[tuple[V1ReplicationController, int, CIMultiDictProxy]]: ...
    def replace_namespaced_resource_quota(self, name: str, namespace: str, body: V1ResourceQuota, **kwargs: Any) -> Awaitable[V1ResourceQuota]: ...
    def replace_namespaced_resource_quota_status(self, name: str, namespace: str, body: V1ResourceQuota, **kwargs: Any) -> Awaitable[V1ResourceQuota]: ...
    def replace_namespaced_resource_quota_status_with_http_info(self, name: str, namespace: str, body: V1ResourceQuota, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuota, int, CIMultiDictProxy]]: ...
    def replace_namespaced_resource_quota_with_http_info(self, name: str, namespace: str, body: V1ResourceQuota, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuota, int, CIMultiDictProxy]]: ...
    def replace_namespaced_secret(self, name: str, namespace: str, body: V1Secret, **kwargs: Any) -> Awaitable[V1Secret]: ...
    def replace_namespaced_secret_with_http_info(self, name: str, namespace: str, body: V1Secret, **kwargs: Any) -> Awaitable[tuple[V1Secret, int, CIMultiDictProxy]]: ...
    def replace_namespaced_service(self, name: str, namespace: str, body: V1Service, **kwargs: Any) -> Awaitable[V1Service]: ...
    def replace_namespaced_service_account(self, name: str, namespace: str, body: V1ServiceAccount, **kwargs: Any) -> Awaitable[V1ServiceAccount]: ...
    def replace_namespaced_service_account_with_http_info(self, name: str, namespace: str, body: V1ServiceAccount, **kwargs: Any) -> Awaitable[tuple[V1ServiceAccount, int, CIMultiDictProxy]]: ...
    def replace_namespaced_service_status(self, name: str, namespace: str, body: V1Service, **kwargs: Any) -> Awaitable[V1Service]: ...
    def replace_namespaced_service_status_with_http_info(self, name: str, namespace: str, body: V1Service, **kwargs: Any) -> Awaitable[tuple[V1Service, int, CIMultiDictProxy]]: ...
    def replace_namespaced_service_with_http_info(self, name: str, namespace: str, body: V1Service, **kwargs: Any) -> Awaitable[tuple[V1Service, int, CIMultiDictProxy]]: ...
    def replace_node(self, name: str, body: V1Node, **kwargs: Any) -> Awaitable[V1Node]: ...
    def replace_node_status(self, name: str, body: V1Node, **kwargs: Any) -> Awaitable[V1Node]: ...
    def replace_node_status_with_http_info(self, name: str, body: V1Node, **kwargs: Any) -> Awaitable[tuple[V1Node, int, CIMultiDictProxy]]: ...
    def replace_node_with_http_info(self, name: str, body: V1Node, **kwargs: Any) -> Awaitable[tuple[V1Node, int, CIMultiDictProxy]]: ...
    def replace_persistent_volume(self, name: str, body: V1PersistentVolume, **kwargs: Any) -> Awaitable[V1PersistentVolume]: ...
    def replace_persistent_volume_status(self, name: str, body: V1PersistentVolume, **kwargs: Any) -> Awaitable[V1PersistentVolume]: ...
    def replace_persistent_volume_status_with_http_info(self, name: str, body: V1PersistentVolume, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolume, int, CIMultiDictProxy]]: ...
    def replace_persistent_volume_with_http_info(self, name: str, body: V1PersistentVolume, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolume, int, CIMultiDictProxy]]: ...
