from kubernetes_asyncio.client.api_client import ApiClient
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class WellKnownApi:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def get_service_account_issuer_open_id_configuration(self, **kwargs: Any) -> Awaitable[str]: ...
    def get_service_account_issuer_open_id_configuration_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
