from kubernetes_asyncio.client.models import V1ListMeta
from kubernetes_asyncio.client.models import V1StatusDetails
from typing import Any

class V1Status:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, api_version: str | None = None, code: int | None = None, details: V1StatusDetails | None = None, kind: str | None = None, message: str | None = None, metadata: V1ListMeta | None = None, reason: str | None = None, status: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def api_version(self) -> str: ...
    @api_version.setter
    def api_version(self, api_version: str) -> None: ...
    @property
    def code(self) -> int: ...
    @code.setter
    def code(self, code: int) -> None: ...
    @property
    def details(self) -> V1StatusDetails: ...
    @details.setter
    def details(self, details: V1StatusDetails) -> None: ...
    @property
    def kind(self) -> str: ...
    @kind.setter
    def kind(self, kind: str) -> None: ...
    @property
    def message(self) -> str: ...
    @message.setter
    def message(self, message: str) -> None: ...
    @property
    def metadata(self) -> V1ListMeta: ...
    @metadata.setter
    def metadata(self, metadata: V1ListMeta) -> None: ...
    @property
    def reason(self) -> str: ...
    @reason.setter
    def reason(self, reason: str) -> None: ...
    @property
    def status(self) -> str: ...
    @status.setter
    def status(self, status: str) -> None: ...
