from kubernetes_asyncio.client.models import V1ContainerState
from kubernetes_asyncio.client.models import V1ContainerUser
from kubernetes_asyncio.client.models import V1ResourceRequirements
from kubernetes_asyncio.client.models import V1ResourceStatus
from kubernetes_asyncio.client.models import V1VolumeMountStatus
from typing import Any

class V1ContainerStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, allocated_resources: dict[str, str] | None = None, allocated_resources_status: list[V1ResourceStatus] | None = None, container_id: str | None = None, image: str | None = None, image_id: str | None = None, last_state: V1ContainerState | None = None, name: str | None = None, ready: bool | None = None, resources: V1ResourceRequirements | None = None, restart_count: int | None = None, started: bool | None = None, state: V1ContainerState | None = None, stop_signal: str | None = None, user: V1ContainerUser | None = None, volume_mounts: list[V1VolumeMountStatus] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def allocated_resources(self) -> dict[str, str]: ...
    @allocated_resources.setter
    def allocated_resources(self, allocated_resources: dict[str, str]) -> None: ...
    @property
    def allocated_resources_status(self) -> list[V1ResourceStatus]: ...
    @allocated_resources_status.setter
    def allocated_resources_status(self, allocated_resources_status: list[V1ResourceStatus]) -> None: ...
    @property
    def container_id(self) -> str: ...
    @container_id.setter
    def container_id(self, container_id: str) -> None: ...
    @property
    def image(self) -> str: ...
    @image.setter
    def image(self, image: str) -> None: ...
    @property
    def image_id(self) -> str: ...
    @image_id.setter
    def image_id(self, image_id: str) -> None: ...
    @property
    def last_state(self) -> V1ContainerState: ...
    @last_state.setter
    def last_state(self, last_state: V1ContainerState) -> None: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
    @property
    def ready(self) -> bool: ...
    @ready.setter
    def ready(self, ready: bool) -> None: ...
    @property
    def resources(self) -> V1ResourceRequirements: ...
    @resources.setter
    def resources(self, resources: V1ResourceRequirements) -> None: ...
    @property
    def restart_count(self) -> int: ...
    @restart_count.setter
    def restart_count(self, restart_count: int) -> None: ...
    @property
    def started(self) -> bool: ...
    @started.setter
    def started(self, started: bool) -> None: ...
    @property
    def state(self) -> V1ContainerState: ...
    @state.setter
    def state(self, state: V1ContainerState) -> None: ...
    @property
    def stop_signal(self) -> str: ...
    @stop_signal.setter
    def stop_signal(self, stop_signal: str) -> None: ...
    @property
    def user(self) -> V1ContainerUser: ...
    @user.setter
    def user(self, user: V1ContainerUser) -> None: ...
    @property
    def volume_mounts(self) -> list[V1VolumeMountStatus]: ...
    @volume_mounts.setter
    def volume_mounts(self, volume_mounts: list[V1VolumeMountStatus]) -> None: ...
