from typing import Any

class V1beta1DeviceAttribute:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, bool: bool | None = None, int: int | None = None, string: str | None = None, version: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def bool(self) -> bool: ...
    @bool.setter
    def bool(self, bool: bool) -> None: ...
    @property
    def int(self) -> int: ...
    @int.setter
    def int(self, int: int) -> None: ...
    @property
    def string(self) -> str: ...
    @string.setter
    def string(self, string: str) -> None: ...
    @property
    def version(self) -> str: ...
    @version.setter
    def version(self, version: str) -> None: ...
