from kubernetes_asyncio.client.models import V1LabelSelector
from kubernetes_asyncio.client.models import V1PodTemplateSpec
from typing import Any

class V1ReplicaSetSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, min_ready_seconds: int | None = None, replicas: int | None = None, selector: V1LabelSelector | None = None, template: V1PodTemplateSpec | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def min_ready_seconds(self) -> int: ...
    @min_ready_seconds.setter
    def min_ready_seconds(self, min_ready_seconds: int) -> None: ...
    @property
    def replicas(self) -> int: ...
    @replicas.setter
    def replicas(self, replicas: int) -> None: ...
    @property
    def selector(self) -> V1LabelSelector: ...
    @selector.setter
    def selector(self, selector: V1LabelSelector) -> None: ...
    @property
    def template(self) -> V1PodTemplateSpec: ...
    @template.setter
    def template(self, template: V1PodTemplateSpec) -> None: ...
