from datetime import datetime
from kubernetes_asyncio.client.models import V1Condition
from typing import Any

class V1PodDisruptionBudgetStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, conditions: list[V1Condition] | None = None, current_healthy: int | None = None, desired_healthy: int | None = None, disrupted_pods: dict[str, datetime] | None = None, disruptions_allowed: int | None = None, expected_pods: int | None = None, observed_generation: int | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def conditions(self) -> list[V1Condition]: ...
    @conditions.setter
    def conditions(self, conditions: list[V1Condition]) -> None: ...
    @property
    def current_healthy(self) -> int: ...
    @current_healthy.setter
    def current_healthy(self, current_healthy: int) -> None: ...
    @property
    def desired_healthy(self) -> int: ...
    @desired_healthy.setter
    def desired_healthy(self, desired_healthy: int) -> None: ...
    @property
    def disrupted_pods(self) -> dict[str, datetime]: ...
    @disrupted_pods.setter
    def disrupted_pods(self, disrupted_pods: dict[str, datetime]) -> None: ...
    @property
    def disruptions_allowed(self) -> int: ...
    @disruptions_allowed.setter
    def disruptions_allowed(self, disruptions_allowed: int) -> None: ...
    @property
    def expected_pods(self) -> int: ...
    @expected_pods.setter
    def expected_pods(self, expected_pods: int) -> None: ...
    @property
    def observed_generation(self) -> int: ...
    @observed_generation.setter
    def observed_generation(self, observed_generation: int) -> None: ...
