from typing import Any

class V1Capabilities:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, add: list[str] | None = None, drop: list[str] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def add(self) -> list[str]: ...
    @add.setter
    def add(self, add: list[str]) -> None: ...
    @property
    def drop(self) -> list[str]: ...
    @drop.setter
    def drop(self, drop: list[str]) -> None: ...
