from kubernetes_asyncio.client.models import V1ConfigMapEnvSource
from kubernetes_asyncio.client.models import V1SecretEnvSource
from typing import Any

class V1EnvFromSource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, config_map_ref: V1ConfigMapEnvSource | None = None, prefix: str | None = None, secret_ref: V1SecretEnvSource | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def config_map_ref(self) -> V1ConfigMapEnvSource: ...
    @config_map_ref.setter
    def config_map_ref(self, config_map_ref: V1ConfigMapEnvSource) -> None: ...
    @property
    def prefix(self) -> str: ...
    @prefix.setter
    def prefix(self, prefix: str) -> None: ...
    @property
    def secret_ref(self) -> V1SecretEnvSource: ...
    @secret_ref.setter
    def secret_ref(self, secret_ref: V1SecretEnvSource) -> None: ...
