from kubernetes_asyncio.client.models import V1Condition
from kubernetes_asyncio.client.models import V1beta1NetworkDeviceData
from typing import Any

class V1beta1AllocatedDeviceStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, conditions: list[V1Condition] | None = None, data: Any | None = None, device: str | None = None, driver: str | None = None, network_data: V1beta1NetworkDeviceData | None = None, pool: str | None = None, share_id: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def conditions(self) -> list[V1Condition]: ...
    @conditions.setter
    def conditions(self, conditions: list[V1Condition]) -> None: ...
    @property
    def data(self) -> Any: ...
    @data.setter
    def data(self, data: Any) -> None: ...
    @property
    def device(self) -> str: ...
    @device.setter
    def device(self, device: str) -> None: ...
    @property
    def driver(self) -> str: ...
    @driver.setter
    def driver(self, driver: str) -> None: ...
    @property
    def network_data(self) -> V1beta1NetworkDeviceData: ...
    @network_data.setter
    def network_data(self, network_data: V1beta1NetworkDeviceData) -> None: ...
    @property
    def pool(self) -> str: ...
    @pool.setter
    def pool(self, pool: str) -> None: ...
    @property
    def share_id(self) -> str: ...
    @share_id.setter
    def share_id(self, share_id: str) -> None: ...
