from kubernetes_asyncio.client.models import FlowcontrolV1Subject
from kubernetes_asyncio.client.models import V1NonResourcePolicyRule
from kubernetes_asyncio.client.models import V1ResourcePolicyRule
from typing import Any

class V1PolicyRulesWithSubjects:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, non_resource_rules: list[V1NonResourcePolicyRule] | None = None, resource_rules: list[V1ResourcePolicyRule] | None = None, subjects: list[FlowcontrolV1Subject] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def non_resource_rules(self) -> list[V1NonResourcePolicyRule]: ...
    @non_resource_rules.setter
    def non_resource_rules(self, non_resource_rules: list[V1NonResourcePolicyRule]) -> None: ...
    @property
    def resource_rules(self) -> list[V1ResourcePolicyRule]: ...
    @resource_rules.setter
    def resource_rules(self, resource_rules: list[V1ResourcePolicyRule]) -> None: ...
    @property
    def subjects(self) -> list[FlowcontrolV1Subject]: ...
    @subjects.setter
    def subjects(self, subjects: list[FlowcontrolV1Subject]) -> None: ...
