from typing import Any

class V1alpha1NamedRuleWithOperations:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, api_groups: list[str] | None = None, api_versions: list[str] | None = None, operations: list[str] | None = None, resource_names: list[str] | None = None, resources: list[str] | None = None, scope: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def api_groups(self) -> list[str]: ...
    @api_groups.setter
    def api_groups(self, api_groups: list[str]) -> None: ...
    @property
    def api_versions(self) -> list[str]: ...
    @api_versions.setter
    def api_versions(self, api_versions: list[str]) -> None: ...
    @property
    def operations(self) -> list[str]: ...
    @operations.setter
    def operations(self, operations: list[str]) -> None: ...
    @property
    def resource_names(self) -> list[str]: ...
    @resource_names.setter
    def resource_names(self, resource_names: list[str]) -> None: ...
    @property
    def resources(self) -> list[str]: ...
    @resources.setter
    def resources(self, resources: list[str]) -> None: ...
    @property
    def scope(self) -> str: ...
    @scope.setter
    def scope(self, scope: str) -> None: ...
