from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1RuntimeClass
from kubernetes_asyncio.client.models import V1RuntimeClassList
from kubernetes_asyncio.client.models import V1Status
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class NodeV1Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def create_runtime_class(self, body: V1RuntimeClass, **kwargs: Any) -> Awaitable[V1RuntimeClass]: ...
    def create_runtime_class_with_http_info(self, body: V1RuntimeClass, **kwargs: Any) -> Awaitable[tuple[V1RuntimeClass, int, CIMultiDictProxy]]: ...
    def delete_collection_runtime_class(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_runtime_class_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_runtime_class(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_runtime_class_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
    def list_runtime_class(self, **kwargs: Any) -> Awaitable[V1RuntimeClassList]: ...
    def list_runtime_class_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1RuntimeClassList, int, CIMultiDictProxy]]: ...
    def patch_runtime_class(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1RuntimeClass]: ...
    def patch_runtime_class_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1RuntimeClass, int, CIMultiDictProxy]]: ...
    def read_runtime_class(self, name: str, **kwargs: Any) -> Awaitable[V1RuntimeClass]: ...
    def read_runtime_class_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1RuntimeClass, int, CIMultiDictProxy]]: ...
    def replace_runtime_class(self, name: str, body: V1RuntimeClass, **kwargs: Any) -> Awaitable[V1RuntimeClass]: ...
    def replace_runtime_class_with_http_info(self, name: str, body: V1RuntimeClass, **kwargs: Any) -> Awaitable[tuple[V1RuntimeClass, int, CIMultiDictProxy]]: ...
