from kubernetes_asyncio.client.models import V1CustomResourceSubresourceScale
from typing import Any

class V1CustomResourceSubresources:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, scale: V1CustomResourceSubresourceScale | None = None, status: Any | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def scale(self) -> V1CustomResourceSubresourceScale: ...
    @scale.setter
    def scale(self, scale: V1CustomResourceSubresourceScale) -> None: ...
    @property
    def status(self) -> Any: ...
    @status.setter
    def status(self, status: Any) -> None: ...
