from typing import Any

class V1GCEPersistentDiskVolumeSource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, fs_type: str | None = None, partition: int | None = None, pd_name: str | None = None, read_only: bool | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def fs_type(self) -> str: ...
    @fs_type.setter
    def fs_type(self, fs_type: str) -> None: ...
    @property
    def partition(self) -> int: ...
    @partition.setter
    def partition(self, partition: int) -> None: ...
    @property
    def pd_name(self) -> str: ...
    @pd_name.setter
    def pd_name(self, pd_name: str) -> None: ...
    @property
    def read_only(self) -> bool: ...
    @read_only.setter
    def read_only(self, read_only: bool) -> None: ...
