from kubernetes_asyncio.client.models import V1beta2DeviceSubRequest
from kubernetes_asyncio.client.models import V1beta2ExactDeviceRequest
from typing import Any

class V1beta2DeviceRequest:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, exactly: V1beta2ExactDeviceRequest | None = None, first_available: list[V1beta2DeviceSubRequest] | None = None, name: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def exactly(self) -> V1beta2ExactDeviceRequest: ...
    @exactly.setter
    def exactly(self, exactly: V1beta2ExactDeviceRequest) -> None: ...
    @property
    def first_available(self) -> list[V1beta2DeviceSubRequest]: ...
    @first_available.setter
    def first_available(self, first_available: list[V1beta2DeviceSubRequest]) -> None: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
