from kubernetes_asyncio.client.models import V1NodeSwapStatus
from typing import Any

class V1NodeSystemInfo:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, architecture: str | None = None, boot_id: str | None = None, container_runtime_version: str | None = None, kernel_version: str | None = None, kube_proxy_version: str | None = None, kubelet_version: str | None = None, machine_id: str | None = None, operating_system: str | None = None, os_image: str | None = None, swap: V1NodeSwapStatus | None = None, system_uuid: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def architecture(self) -> str: ...
    @architecture.setter
    def architecture(self, architecture: str) -> None: ...
    @property
    def boot_id(self) -> str: ...
    @boot_id.setter
    def boot_id(self, boot_id: str) -> None: ...
    @property
    def container_runtime_version(self) -> str: ...
    @container_runtime_version.setter
    def container_runtime_version(self, container_runtime_version: str) -> None: ...
    @property
    def kernel_version(self) -> str: ...
    @kernel_version.setter
    def kernel_version(self, kernel_version: str) -> None: ...
    @property
    def kube_proxy_version(self) -> str: ...
    @kube_proxy_version.setter
    def kube_proxy_version(self, kube_proxy_version: str) -> None: ...
    @property
    def kubelet_version(self) -> str: ...
    @kubelet_version.setter
    def kubelet_version(self, kubelet_version: str) -> None: ...
    @property
    def machine_id(self) -> str: ...
    @machine_id.setter
    def machine_id(self, machine_id: str) -> None: ...
    @property
    def operating_system(self) -> str: ...
    @operating_system.setter
    def operating_system(self, operating_system: str) -> None: ...
    @property
    def os_image(self) -> str: ...
    @os_image.setter
    def os_image(self, os_image: str) -> None: ...
    @property
    def swap(self) -> V1NodeSwapStatus: ...
    @swap.setter
    def swap(self, swap: V1NodeSwapStatus) -> None: ...
    @property
    def system_uuid(self) -> str: ...
    @system_uuid.setter
    def system_uuid(self, system_uuid: str) -> None: ...
