from kubernetes_asyncio.client.models import V1alpha1MatchResources
from kubernetes_asyncio.client.models import V1alpha1ParamRef
from typing import Any

class V1alpha1MutatingAdmissionPolicyBindingSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, match_resources: V1alpha1MatchResources | None = None, param_ref: V1alpha1ParamRef | None = None, policy_name: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def match_resources(self) -> V1alpha1MatchResources: ...
    @match_resources.setter
    def match_resources(self, match_resources: V1alpha1MatchResources) -> None: ...
    @property
    def param_ref(self) -> V1alpha1ParamRef: ...
    @param_ref.setter
    def param_ref(self, param_ref: V1alpha1ParamRef) -> None: ...
    @property
    def policy_name(self) -> str: ...
    @policy_name.setter
    def policy_name(self, policy_name: str) -> None: ...
