from kubernetes_asyncio.client.models import CoreV1EndpointPort
from kubernetes_asyncio.client.models import V1EndpointAddress
from typing import Any

class V1EndpointSubset:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, addresses: list[V1EndpointAddress] | None = None, not_ready_addresses: list[V1EndpointAddress] | None = None, ports: list[CoreV1EndpointPort] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def addresses(self) -> list[V1EndpointAddress]: ...
    @addresses.setter
    def addresses(self, addresses: list[V1EndpointAddress]) -> None: ...
    @property
    def not_ready_addresses(self) -> list[V1EndpointAddress]: ...
    @not_ready_addresses.setter
    def not_ready_addresses(self, not_ready_addresses: list[V1EndpointAddress]) -> None: ...
    @property
    def ports(self) -> list[CoreV1EndpointPort]: ...
    @ports.setter
    def ports(self, ports: list[CoreV1EndpointPort]) -> None: ...
