from kubernetes_asyncio.client.models import V1ConfigMapNodeConfigSource
from typing import Any

class V1NodeConfigSource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, config_map: V1ConfigMapNodeConfigSource | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def config_map(self) -> V1ConfigMapNodeConfigSource: ...
    @config_map.setter
    def config_map(self, config_map: V1ConfigMapNodeConfigSource) -> None: ...
