from kubernetes_asyncio.client.models import V1VolumeError
from typing import Any

class V1VolumeAttachmentStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, attach_error: V1VolumeError | None = None, attached: bool | None = None, attachment_metadata: dict[str, str] | None = None, detach_error: V1VolumeError | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def attach_error(self) -> V1VolumeError: ...
    @attach_error.setter
    def attach_error(self, attach_error: V1VolumeError) -> None: ...
    @property
    def attached(self) -> bool: ...
    @attached.setter
    def attached(self, attached: bool) -> None: ...
    @property
    def attachment_metadata(self) -> dict[str, str]: ...
    @attachment_metadata.setter
    def attachment_metadata(self, attachment_metadata: dict[str, str]) -> None: ...
    @property
    def detach_error(self) -> V1VolumeError: ...
    @detach_error.setter
    def detach_error(self, detach_error: V1VolumeError) -> None: ...
