from typing import Any

class V1LinuxContainerUser:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, gid: int | None = None, supplemental_groups: list[int] | None = None, uid: int | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def gid(self) -> int: ...
    @gid.setter
    def gid(self, gid: int) -> None: ...
    @property
    def supplemental_groups(self) -> list[int]: ...
    @supplemental_groups.setter
    def supplemental_groups(self, supplemental_groups: list[int]) -> None: ...
    @property
    def uid(self) -> int: ...
    @uid.setter
    def uid(self, uid: int) -> None: ...
