from datetime import datetime
from typing import Any

class V1HorizontalPodAutoscalerStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, current_cpu_utilization_percentage: int | None = None, current_replicas: int | None = None, desired_replicas: int | None = None, last_scale_time: datetime | None = None, observed_generation: int | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def current_cpu_utilization_percentage(self) -> int: ...
    @current_cpu_utilization_percentage.setter
    def current_cpu_utilization_percentage(self, current_cpu_utilization_percentage: int) -> None: ...
    @property
    def current_replicas(self) -> int: ...
    @current_replicas.setter
    def current_replicas(self, current_replicas: int) -> None: ...
    @property
    def desired_replicas(self) -> int: ...
    @desired_replicas.setter
    def desired_replicas(self, desired_replicas: int) -> None: ...
    @property
    def last_scale_time(self) -> datetime: ...
    @last_scale_time.setter
    def last_scale_time(self, last_scale_time: datetime) -> None: ...
    @property
    def observed_generation(self) -> int: ...
    @observed_generation.setter
    def observed_generation(self, observed_generation: int) -> None: ...
