from kubernetes_asyncio.client.models import V1CSINodeDriver
from typing import Any

class V1CSINodeSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, drivers: list[V1CSINodeDriver] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def drivers(self) -> list[V1CSINodeDriver]: ...
    @drivers.setter
    def drivers(self, drivers: list[V1CSINodeDriver]) -> None: ...
