from kubernetes_asyncio.client.models import V1IngressBackend
from typing import Any

class V1HTTPIngressPath:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, backend: V1IngressBackend | None = None, path: str | None = None, path_type: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def backend(self) -> V1IngressBackend: ...
    @backend.setter
    def backend(self, backend: V1IngressBackend) -> None: ...
    @property
    def path(self) -> str: ...
    @path.setter
    def path(self, path: str) -> None: ...
    @property
    def path_type(self) -> str: ...
    @path_type.setter
    def path_type(self, path_type: str) -> None: ...
