from datetime import datetime
from typing import Any

class V1TokenRequestStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, expiration_timestamp: datetime | None = None, token: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def expiration_timestamp(self) -> datetime: ...
    @expiration_timestamp.setter
    def expiration_timestamp(self, expiration_timestamp: datetime) -> None: ...
    @property
    def token(self) -> str: ...
    @token.setter
    def token(self, token: str) -> None: ...
