from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1SelfSubjectReview
from kubernetes_asyncio.client.models import V1TokenReview
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class AuthenticationV1Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def create_self_subject_review(self, body: V1SelfSubjectReview, **kwargs: Any) -> Awaitable[V1SelfSubjectReview]: ...
    def create_self_subject_review_with_http_info(self, body: V1SelfSubjectReview, **kwargs: Any) -> Awaitable[tuple[V1SelfSubjectReview, int, CIMultiDictProxy]]: ...
    def create_token_review(self, body: V1TokenReview, **kwargs: Any) -> Awaitable[V1TokenReview]: ...
    def create_token_review_with_http_info(self, body: V1TokenReview, **kwargs: Any) -> Awaitable[tuple[V1TokenReview, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
