from kubernetes_asyncio.client.models import V1ExecAction
from kubernetes_asyncio.client.models import V1GRPCAction
from kubernetes_asyncio.client.models import V1HTTPGetAction
from kubernetes_asyncio.client.models import V1TCPSocketAction
from typing import Any

class V1Probe:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, _exec: V1ExecAction | None = None, failure_threshold: int | None = None, grpc: V1GRPCAction | None = None, http_get: V1HTTPGetAction | None = None, initial_delay_seconds: int | None = None, period_seconds: int | None = None, success_threshold: int | None = None, tcp_socket: V1TCPSocketAction | None = None, termination_grace_period_seconds: int | None = None, timeout_seconds: int | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def _exec(self) -> V1ExecAction: ...
    @_exec.setter
    def _exec(self, _exec: V1ExecAction) -> None: ...
    @property
    def failure_threshold(self) -> int: ...
    @failure_threshold.setter
    def failure_threshold(self, failure_threshold: int) -> None: ...
    @property
    def grpc(self) -> V1GRPCAction: ...
    @grpc.setter
    def grpc(self, grpc: V1GRPCAction) -> None: ...
    @property
    def http_get(self) -> V1HTTPGetAction: ...
    @http_get.setter
    def http_get(self, http_get: V1HTTPGetAction) -> None: ...
    @property
    def initial_delay_seconds(self) -> int: ...
    @initial_delay_seconds.setter
    def initial_delay_seconds(self, initial_delay_seconds: int) -> None: ...
    @property
    def period_seconds(self) -> int: ...
    @period_seconds.setter
    def period_seconds(self, period_seconds: int) -> None: ...
    @property
    def success_threshold(self) -> int: ...
    @success_threshold.setter
    def success_threshold(self, success_threshold: int) -> None: ...
    @property
    def tcp_socket(self) -> V1TCPSocketAction: ...
    @tcp_socket.setter
    def tcp_socket(self, tcp_socket: V1TCPSocketAction) -> None: ...
    @property
    def termination_grace_period_seconds(self) -> int: ...
    @termination_grace_period_seconds.setter
    def termination_grace_period_seconds(self, termination_grace_period_seconds: int) -> None: ...
    @property
    def timeout_seconds(self) -> int: ...
    @timeout_seconds.setter
    def timeout_seconds(self, timeout_seconds: int) -> None: ...
