from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import EventsV1Event
from kubernetes_asyncio.client.models import EventsV1EventList
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1Status
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class EventsV1Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def create_namespaced_event(self, namespace: str, body: EventsV1Event, **kwargs: Any) -> Awaitable[EventsV1Event]: ...
    def create_namespaced_event_with_http_info(self, namespace: str, body: EventsV1Event, **kwargs: Any) -> Awaitable[tuple[EventsV1Event, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_event(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_event_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_event(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_event_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
    def list_event_for_all_namespaces(self, **kwargs: Any) -> Awaitable[EventsV1EventList]: ...
    def list_event_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[EventsV1EventList, int, CIMultiDictProxy]]: ...
    def list_namespaced_event(self, namespace: str, **kwargs: Any) -> Awaitable[EventsV1EventList]: ...
    def list_namespaced_event_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[EventsV1EventList, int, CIMultiDictProxy]]: ...
    def patch_namespaced_event(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[EventsV1Event]: ...
    def patch_namespaced_event_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[EventsV1Event, int, CIMultiDictProxy]]: ...
    def read_namespaced_event(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[EventsV1Event]: ...
    def read_namespaced_event_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[EventsV1Event, int, CIMultiDictProxy]]: ...
    def replace_namespaced_event(self, name: str, namespace: str, body: EventsV1Event, **kwargs: Any) -> Awaitable[EventsV1Event]: ...
    def replace_namespaced_event_with_http_info(self, name: str, namespace: str, body: EventsV1Event, **kwargs: Any) -> Awaitable[tuple[EventsV1Event, int, CIMultiDictProxy]]: ...
