from typing import Any

class V1ServerAddressByClientCIDR:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, client_cidr: str | None = None, server_address: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def client_cidr(self) -> str: ...
    @client_cidr.setter
    def client_cidr(self, client_cidr: str) -> None: ...
    @property
    def server_address(self) -> str: ...
    @server_address.setter
    def server_address(self, server_address: str) -> None: ...
