from kubernetes_asyncio.client.models import V1VolumeNodeResources
from typing import Any

class V1CSINodeDriver:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, allocatable: V1VolumeNodeResources | None = None, name: str | None = None, node_id: str | None = None, topology_keys: list[str] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def allocatable(self) -> V1VolumeNodeResources: ...
    @allocatable.setter
    def allocatable(self, allocatable: V1VolumeNodeResources) -> None: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
    @property
    def node_id(self) -> str: ...
    @node_id.setter
    def node_id(self, node_id: str) -> None: ...
    @property
    def topology_keys(self) -> list[str]: ...
    @topology_keys.setter
    def topology_keys(self, topology_keys: list[str]) -> None: ...
