from kubernetes_asyncio.client.models import V1QueuingConfiguration
from typing import Any

class V1LimitResponse:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, queuing: V1QueuingConfiguration | None = None, type: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def queuing(self) -> V1QueuingConfiguration: ...
    @queuing.setter
    def queuing(self, queuing: V1QueuingConfiguration) -> None: ...
    @property
    def type(self) -> str: ...
    @type.setter
    def type(self, type: str) -> None: ...
