from kubernetes_asyncio.client.models import V2ContainerResourceMetricStatus
from kubernetes_asyncio.client.models import V2ExternalMetricStatus
from kubernetes_asyncio.client.models import V2ObjectMetricStatus
from kubernetes_asyncio.client.models import V2PodsMetricStatus
from kubernetes_asyncio.client.models import V2ResourceMetricStatus
from typing import Any

class V2MetricStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, container_resource: V2ContainerResourceMetricStatus | None = None, external: V2ExternalMetricStatus | None = None, object: V2ObjectMetricStatus | None = None, pods: V2PodsMetricStatus | None = None, resource: V2ResourceMetricStatus | None = None, type: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def container_resource(self) -> V2ContainerResourceMetricStatus: ...
    @container_resource.setter
    def container_resource(self, container_resource: V2ContainerResourceMetricStatus) -> None: ...
    @property
    def external(self) -> V2ExternalMetricStatus: ...
    @external.setter
    def external(self, external: V2ExternalMetricStatus) -> None: ...
    @property
    def object(self) -> V2ObjectMetricStatus: ...
    @object.setter
    def object(self, object: V2ObjectMetricStatus) -> None: ...
    @property
    def pods(self) -> V2PodsMetricStatus: ...
    @pods.setter
    def pods(self, pods: V2PodsMetricStatus) -> None: ...
    @property
    def resource(self) -> V2ResourceMetricStatus: ...
    @resource.setter
    def resource(self, resource: V2ResourceMetricStatus) -> None: ...
    @property
    def type(self) -> str: ...
    @type.setter
    def type(self, type: str) -> None: ...
