from kubernetes_asyncio.client.models import V1ObjectMeta
from kubernetes_asyncio.client.models import V1beta1MutatingAdmissionPolicyBindingSpec
from typing import Any

class V1beta1MutatingAdmissionPolicyBinding:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, api_version: str | None = None, kind: str | None = None, metadata: V1ObjectMeta | None = None, spec: V1beta1MutatingAdmissionPolicyBindingSpec | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def api_version(self) -> str: ...
    @api_version.setter
    def api_version(self, api_version: str) -> None: ...
    @property
    def kind(self) -> str: ...
    @kind.setter
    def kind(self, kind: str) -> None: ...
    @property
    def metadata(self) -> V1ObjectMeta: ...
    @metadata.setter
    def metadata(self, metadata: V1ObjectMeta) -> None: ...
    @property
    def spec(self) -> V1beta1MutatingAdmissionPolicyBindingSpec: ...
    @spec.setter
    def spec(self, spec: V1beta1MutatingAdmissionPolicyBindingSpec) -> None: ...
