from kubernetes_asyncio.client.models import V1SecretReference
from typing import Any

class V1ScaleIOPersistentVolumeSource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, fs_type: str | None = None, gateway: str | None = None, protection_domain: str | None = None, read_only: bool | None = None, secret_ref: V1SecretReference | None = None, ssl_enabled: bool | None = None, storage_mode: str | None = None, storage_pool: str | None = None, system: str | None = None, volume_name: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def fs_type(self) -> str: ...
    @fs_type.setter
    def fs_type(self, fs_type: str) -> None: ...
    @property
    def gateway(self) -> str: ...
    @gateway.setter
    def gateway(self, gateway: str) -> None: ...
    @property
    def protection_domain(self) -> str: ...
    @protection_domain.setter
    def protection_domain(self, protection_domain: str) -> None: ...
    @property
    def read_only(self) -> bool: ...
    @read_only.setter
    def read_only(self, read_only: bool) -> None: ...
    @property
    def secret_ref(self) -> V1SecretReference: ...
    @secret_ref.setter
    def secret_ref(self, secret_ref: V1SecretReference) -> None: ...
    @property
    def ssl_enabled(self) -> bool: ...
    @ssl_enabled.setter
    def ssl_enabled(self, ssl_enabled: bool) -> None: ...
    @property
    def storage_mode(self) -> str: ...
    @storage_mode.setter
    def storage_mode(self, storage_mode: str) -> None: ...
    @property
    def storage_pool(self) -> str: ...
    @storage_pool.setter
    def storage_pool(self, storage_pool: str) -> None: ...
    @property
    def system(self) -> str: ...
    @system.setter
    def system(self, system: str) -> None: ...
    @property
    def volume_name(self) -> str: ...
    @volume_name.setter
    def volume_name(self, volume_name: str) -> None: ...
