from typing import Any

class V1QueuingConfiguration:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, hand_size: int | None = None, queue_length_limit: int | None = None, queues: int | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def hand_size(self) -> int: ...
    @hand_size.setter
    def hand_size(self, hand_size: int) -> None: ...
    @property
    def queue_length_limit(self) -> int: ...
    @queue_length_limit.setter
    def queue_length_limit(self, queue_length_limit: int) -> None: ...
    @property
    def queues(self) -> int: ...
    @queues.setter
    def queues(self, queues: int) -> None: ...
