from kubernetes_asyncio.client.models import V1LabelSelector
from kubernetes_asyncio.client.models import V1NamedRuleWithOperations
from typing import Any

class V1MatchResources:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, exclude_resource_rules: list[V1NamedRuleWithOperations] | None = None, match_policy: str | None = None, namespace_selector: V1LabelSelector | None = None, object_selector: V1LabelSelector | None = None, resource_rules: list[V1NamedRuleWithOperations] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def exclude_resource_rules(self) -> list[V1NamedRuleWithOperations]: ...
    @exclude_resource_rules.setter
    def exclude_resource_rules(self, exclude_resource_rules: list[V1NamedRuleWithOperations]) -> None: ...
    @property
    def match_policy(self) -> str: ...
    @match_policy.setter
    def match_policy(self, match_policy: str) -> None: ...
    @property
    def namespace_selector(self) -> V1LabelSelector: ...
    @namespace_selector.setter
    def namespace_selector(self, namespace_selector: V1LabelSelector) -> None: ...
    @property
    def object_selector(self) -> V1LabelSelector: ...
    @object_selector.setter
    def object_selector(self, object_selector: V1LabelSelector) -> None: ...
    @property
    def resource_rules(self) -> list[V1NamedRuleWithOperations]: ...
    @resource_rules.setter
    def resource_rules(self, resource_rules: list[V1NamedRuleWithOperations]) -> None: ...
