from kubernetes_asyncio.client.models import V1HTTPIngressRuleValue
from typing import Any

class V1IngressRule:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, host: str | None = None, http: V1HTTPIngressRuleValue | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def host(self) -> str: ...
    @host.setter
    def host(self, host: str) -> None: ...
    @property
    def http(self) -> V1HTTPIngressRuleValue: ...
    @http.setter
    def http(self, http: V1HTTPIngressRuleValue) -> None: ...
