from kubernetes_asyncio.client.models import V1beta1OpaqueDeviceConfiguration
from typing import Any

class V1beta1DeviceAllocationConfiguration:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, opaque: V1beta1OpaqueDeviceConfiguration | None = None, requests: list[str] | None = None, source: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def opaque(self) -> V1beta1OpaqueDeviceConfiguration: ...
    @opaque.setter
    def opaque(self, opaque: V1beta1OpaqueDeviceConfiguration) -> None: ...
    @property
    def requests(self) -> list[str]: ...
    @requests.setter
    def requests(self, requests: list[str]) -> None: ...
    @property
    def source(self) -> str: ...
    @source.setter
    def source(self, source: str) -> None: ...
