from datetime import datetime
from kubernetes_asyncio.client.models import V1ObjectReference
from typing import Any

class V1CronJobStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, active: list[V1ObjectReference] | None = None, last_schedule_time: datetime | None = None, last_successful_time: datetime | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def active(self) -> list[V1ObjectReference]: ...
    @active.setter
    def active(self, active: list[V1ObjectReference]) -> None: ...
    @property
    def last_schedule_time(self) -> datetime: ...
    @last_schedule_time.setter
    def last_schedule_time(self, last_schedule_time: datetime) -> None: ...
    @property
    def last_successful_time(self) -> datetime: ...
    @last_successful_time.setter
    def last_successful_time(self, last_successful_time: datetime) -> None: ...
