from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1FlowSchema
from kubernetes_asyncio.client.models import V1FlowSchemaList
from kubernetes_asyncio.client.models import V1PriorityLevelConfiguration
from kubernetes_asyncio.client.models import V1PriorityLevelConfigurationList
from kubernetes_asyncio.client.models import V1Status
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class FlowcontrolApiserverV1Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def create_flow_schema(self, body: V1FlowSchema, **kwargs: Any) -> Awaitable[V1FlowSchema]: ...
    def create_flow_schema_with_http_info(self, body: V1FlowSchema, **kwargs: Any) -> Awaitable[tuple[V1FlowSchema, int, CIMultiDictProxy]]: ...
    def create_priority_level_configuration(self, body: V1PriorityLevelConfiguration, **kwargs: Any) -> Awaitable[V1PriorityLevelConfiguration]: ...
    def create_priority_level_configuration_with_http_info(self, body: V1PriorityLevelConfiguration, **kwargs: Any) -> Awaitable[tuple[V1PriorityLevelConfiguration, int, CIMultiDictProxy]]: ...
    def delete_collection_flow_schema(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_flow_schema_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_priority_level_configuration(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_priority_level_configuration_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_flow_schema(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_flow_schema_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_priority_level_configuration(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_priority_level_configuration_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
    def list_flow_schema(self, **kwargs: Any) -> Awaitable[V1FlowSchemaList]: ...
    def list_flow_schema_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1FlowSchemaList, int, CIMultiDictProxy]]: ...
    def list_priority_level_configuration(self, **kwargs: Any) -> Awaitable[V1PriorityLevelConfigurationList]: ...
    def list_priority_level_configuration_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1PriorityLevelConfigurationList, int, CIMultiDictProxy]]: ...
    def patch_flow_schema(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1FlowSchema]: ...
    def patch_flow_schema_status(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1FlowSchema]: ...
    def patch_flow_schema_status_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1FlowSchema, int, CIMultiDictProxy]]: ...
    def patch_flow_schema_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1FlowSchema, int, CIMultiDictProxy]]: ...
    def patch_priority_level_configuration(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1PriorityLevelConfiguration]: ...
    def patch_priority_level_configuration_status(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1PriorityLevelConfiguration]: ...
    def patch_priority_level_configuration_status_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1PriorityLevelConfiguration, int, CIMultiDictProxy]]: ...
    def patch_priority_level_configuration_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1PriorityLevelConfiguration, int, CIMultiDictProxy]]: ...
    def read_flow_schema(self, name: str, **kwargs: Any) -> Awaitable[V1FlowSchema]: ...
    def read_flow_schema_status(self, name: str, **kwargs: Any) -> Awaitable[V1FlowSchema]: ...
    def read_flow_schema_status_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1FlowSchema, int, CIMultiDictProxy]]: ...
    def read_flow_schema_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1FlowSchema, int, CIMultiDictProxy]]: ...
    def read_priority_level_configuration(self, name: str, **kwargs: Any) -> Awaitable[V1PriorityLevelConfiguration]: ...
    def read_priority_level_configuration_status(self, name: str, **kwargs: Any) -> Awaitable[V1PriorityLevelConfiguration]: ...
    def read_priority_level_configuration_status_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1PriorityLevelConfiguration, int, CIMultiDictProxy]]: ...
    def read_priority_level_configuration_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1PriorityLevelConfiguration, int, CIMultiDictProxy]]: ...
    def replace_flow_schema(self, name: str, body: V1FlowSchema, **kwargs: Any) -> Awaitable[V1FlowSchema]: ...
    def replace_flow_schema_status(self, name: str, body: V1FlowSchema, **kwargs: Any) -> Awaitable[V1FlowSchema]: ...
    def replace_flow_schema_status_with_http_info(self, name: str, body: V1FlowSchema, **kwargs: Any) -> Awaitable[tuple[V1FlowSchema, int, CIMultiDictProxy]]: ...
    def replace_flow_schema_with_http_info(self, name: str, body: V1FlowSchema, **kwargs: Any) -> Awaitable[tuple[V1FlowSchema, int, CIMultiDictProxy]]: ...
    def replace_priority_level_configuration(self, name: str, body: V1PriorityLevelConfiguration, **kwargs: Any) -> Awaitable[V1PriorityLevelConfiguration]: ...
    def replace_priority_level_configuration_status(self, name: str, body: V1PriorityLevelConfiguration, **kwargs: Any) -> Awaitable[V1PriorityLevelConfiguration]: ...
    def replace_priority_level_configuration_status_with_http_info(self, name: str, body: V1PriorityLevelConfiguration, **kwargs: Any) -> Awaitable[tuple[V1PriorityLevelConfiguration, int, CIMultiDictProxy]]: ...
    def replace_priority_level_configuration_with_http_info(self, name: str, body: V1PriorityLevelConfiguration, **kwargs: Any) -> Awaitable[tuple[V1PriorityLevelConfiguration, int, CIMultiDictProxy]]: ...
