from typing import Any

class V1ContainerImage:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, names: list[str] | None = None, size_bytes: int | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def names(self) -> list[str]: ...
    @names.setter
    def names(self, names: list[str]) -> None: ...
    @property
    def size_bytes(self) -> int: ...
    @size_bytes.setter
    def size_bytes(self, size_bytes: int) -> None: ...
