from kubernetes_asyncio.client.models import V1alpha1ApplyConfiguration
from kubernetes_asyncio.client.models import V1alpha1JSONPatch
from typing import Any

class V1alpha1Mutation:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, apply_configuration: V1alpha1ApplyConfiguration | None = None, json_patch: V1alpha1JSONPatch | None = None, patch_type: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def apply_configuration(self) -> V1alpha1ApplyConfiguration: ...
    @apply_configuration.setter
    def apply_configuration(self, apply_configuration: V1alpha1ApplyConfiguration) -> None: ...
    @property
    def json_patch(self) -> V1alpha1JSONPatch: ...
    @json_patch.setter
    def json_patch(self, json_patch: V1alpha1JSONPatch) -> None: ...
    @property
    def patch_type(self) -> str: ...
    @patch_type.setter
    def patch_type(self, patch_type: str) -> None: ...
