from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1CertificateSigningRequest
from kubernetes_asyncio.client.models import V1CertificateSigningRequestList
from kubernetes_asyncio.client.models import V1Status
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class CertificatesV1Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def create_certificate_signing_request(self, body: V1CertificateSigningRequest, **kwargs: Any) -> Awaitable[V1CertificateSigningRequest]: ...
    def create_certificate_signing_request_with_http_info(self, body: V1CertificateSigningRequest, **kwargs: Any) -> Awaitable[tuple[V1CertificateSigningRequest, int, CIMultiDictProxy]]: ...
    def delete_certificate_signing_request(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_certificate_signing_request_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_certificate_signing_request(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_certificate_signing_request_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
    def list_certificate_signing_request(self, **kwargs: Any) -> Awaitable[V1CertificateSigningRequestList]: ...
    def list_certificate_signing_request_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1CertificateSigningRequestList, int, CIMultiDictProxy]]: ...
    def patch_certificate_signing_request(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1CertificateSigningRequest]: ...
    def patch_certificate_signing_request_approval(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1CertificateSigningRequest]: ...
    def patch_certificate_signing_request_approval_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1CertificateSigningRequest, int, CIMultiDictProxy]]: ...
    def patch_certificate_signing_request_status(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1CertificateSigningRequest]: ...
    def patch_certificate_signing_request_status_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1CertificateSigningRequest, int, CIMultiDictProxy]]: ...
    def patch_certificate_signing_request_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1CertificateSigningRequest, int, CIMultiDictProxy]]: ...
    def read_certificate_signing_request(self, name: str, **kwargs: Any) -> Awaitable[V1CertificateSigningRequest]: ...
    def read_certificate_signing_request_approval(self, name: str, **kwargs: Any) -> Awaitable[V1CertificateSigningRequest]: ...
    def read_certificate_signing_request_approval_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1CertificateSigningRequest, int, CIMultiDictProxy]]: ...
    def read_certificate_signing_request_status(self, name: str, **kwargs: Any) -> Awaitable[V1CertificateSigningRequest]: ...
    def read_certificate_signing_request_status_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1CertificateSigningRequest, int, CIMultiDictProxy]]: ...
    def read_certificate_signing_request_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1CertificateSigningRequest, int, CIMultiDictProxy]]: ...
    def replace_certificate_signing_request(self, name: str, body: V1CertificateSigningRequest, **kwargs: Any) -> Awaitable[V1CertificateSigningRequest]: ...
    def replace_certificate_signing_request_approval(self, name: str, body: V1CertificateSigningRequest, **kwargs: Any) -> Awaitable[V1CertificateSigningRequest]: ...
    def replace_certificate_signing_request_approval_with_http_info(self, name: str, body: V1CertificateSigningRequest, **kwargs: Any) -> Awaitable[tuple[V1CertificateSigningRequest, int, CIMultiDictProxy]]: ...
    def replace_certificate_signing_request_status(self, name: str, body: V1CertificateSigningRequest, **kwargs: Any) -> Awaitable[V1CertificateSigningRequest]: ...
    def replace_certificate_signing_request_status_with_http_info(self, name: str, body: V1CertificateSigningRequest, **kwargs: Any) -> Awaitable[tuple[V1CertificateSigningRequest, int, CIMultiDictProxy]]: ...
    def replace_certificate_signing_request_with_http_info(self, name: str, body: V1CertificateSigningRequest, **kwargs: Any) -> Awaitable[tuple[V1CertificateSigningRequest, int, CIMultiDictProxy]]: ...
